* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/1_1_Define_treatment_calendar_yr.log", replace
di in red "Run 1_1_Define_treatment_calendar_yr.do"
							   
******************************************************
********** Define treated and untreated **************
******************************************************

	* Use data prior to dropping any observations
	u "${output}/analysis/SPT_1771_clean.dta", clear
	
	keep npwp kpp tax_yr filing_dt filing_yr
	
	* Keep if information on filing year is known
	assert !missing(filing_yr)
	
	* Merge in MTO flags
	merge m:1 kpp using "${raw}/auxiliary/kpps_mtos_regions_codes.dta", keepusing(mto)
	keep if _merge!=2
	drop _merge
	
	************* 1) Assign treatment status for filing year ***********
	
	* Registered in MTO in filing_yr Y:				mto
	bys npwp filing_yr: egen max_mto = max(mto)
	ren mto 		kpp_is_mto
	ren max_mto		mto
	label var mto	"Registered in MTO in filing_yr"
	
	* mto year
	bys npwp: egen mtoyear = min(cond(mto==1,filing_yr,.))
	
	************** 2) Assign taxpayer's KPP for that year **************
	
	* For taxpayers in multiple KPPs in the same filing year, assign the
	* taxpayer's KPP as:
		* 1) The MTO KPP if ever filed anything there
		duplicates tag npwp filing_yr, gen(dup)
		* br if dup
		drop if dup>0 & kpp_is_mto==0 & mto ==1
		
		* Else randomly pick one
		gen double temprand = runiform()
		sort npwp filing_yr temprand
		by npwp filing_yr: gen ord = _n
		keep if ord==1
		isid npwp filing_yr
		drop temprand ord
	
	******** Store earliest and latest years seen in data ************

	* Earliest filing year and latest filing year (use this later to
	* impute MTO status for in-between filing years)
	
	preserve
		bys npwp: egen earliest_fy = min(filing_yr)
		bys npwp: egen latest_fy = max(filing_yr)
		
		lab var earliest_fy "Earliest filing year"
		lab var latest_fy "Latest filing year"
		
		keep npwp *_fy
		duplicates drop
		
		* Destring so that can tsset later
		destring npwp, replace
		
		tempfile timing
		sa `timing'
	restore

	**** 4) Final file has treatment well-defined for every year ****
	keep npwp filing_yr mto kpp mtoyear
	
	destring npwp, replace
	format npwp %15.0g
	tsset npwp filing_yr
	tsfill, full
	
	* Extrapolate treatment definition for in-between years not filed
	bys npwp:	egen nomissmtoyear = min(mtoyear)
	replace mtoyear = nomissmtoyear
	drop nomissmtoyear
	
	gen mto_post 		= (filing_yr >= mtoyear) if !missing(mtoyear)
	replace mto_post 	= 0 if missing(mtoyear)
	label var mto_post "Registered in MTO in filing_yr or before per SPT 1771"
	
	* Merge timing back
	merge m:1 npwp using `timing', nogen
	
	* Keep from earliest and up to latest year seen in data for each taxpayer
	drop if filing_yr < earliest_fy
	drop if filing_yr > latest_fy
	
	order npwp npwp filing_yr mto_post mto kpp *_fy
	
	label data "Treatment status for npwps in all regions according to SPT 1771 filing dates"
	saveold "${output}/analysis/mto_treatment_calendar_yr_SPT1771.dta", replace

clear
log close
