* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765

log using "${dofile}/logs/1_2_Eligible_taxpayers_selection_yr.log", replace
di in red "Run 1_2_Eligible_taxpayers_selection_yr.do"

****** Toggles ******

local define_eligibility = 1

************************
***** Eligibility ******
************************

if `define_eligibility'==1{
	
	* Last KPP in which taxpayer was as of each selection year
		u "${output}/analysis/mto_treatment_calendar_yr_SPT1771.dta", clear

		keep npwp filing_yr kpp mto_post
		ren filing_yr calendar_yr
		
		destring kpp, replace
		
		keep if calendar_yr<2008
		
		foreach y in 2005 2006 2007 2008{
			local j = `y' -1
			bys npwp: egen last`y' = max(cond(!missing(kpp) & calendar_yr<`y',calendar_yr,.))
			gen kpp`j' = .
			replace kpp`j' = kpp if calendar_yr==last`y'
			bys npwp: egen maxkpp`j' = max(kpp`j')
			drop kpp`j'
		}
		
		drop last* kpp
		renvars max*, predrop(3)
	
	* Find eligible taxpayers
	do "${dofile}/analysis/auxiliary_MTO_kpps_listed_regulation.do"

	* Elegibility for selection dummies
	
	* 2005 selection
	foreach mto in 217{
		egen elig`mto'_2005 	= anymatch(kpp2004), values("${m`mto'_2005}")
		replace elig`mto'_2005 	= 0 if calendar_yr>=2005 | mto_post==1
		bys npwp: egen maxelig = max(elig`mto'_2005)
		replace  elig`mto'_2005 = maxelig
		drop maxelig
	}
	
	* 2006 selection
	foreach mto in 218 415 431 904{
		egen elig`mto'_2006 	= anymatch(kpp2005), values("${m`mto'_2006}")
		replace elig`mto'_2006 	= 0 if calendar_yr>=2006 | mto_post==1
		bys npwp: egen maxelig = max(elig`mto'_2006)
		replace  elig`mto'_2006 = maxelig
		drop maxelig
	}
	
	* 2007 selection
	foreach mto in 7 38 46 62 73 123 308 431 441 511 631 641 651 725 812{
		egen elig`mto'_2007 	= anymatch(kpp2006), values("${m`mto'_2007}")
		replace elig`mto'_2007 	= 0 if calendar_yr>=2007 | mto_post==1
		bys npwp: egen maxelig = max(elig`mto'_2007)
		replace  elig`mto'_2007 = maxelig
		drop maxelig
	}
	
	* 2008 selection
	foreach mto in 38 904{
		egen elig`mto'_2008 	= anymatch(kpp2007), values("${m`mto'_2008}")
		replace elig`mto'_2008 	= 0 if calendar_yr>=2008 | mto_post==1
		bys npwp: egen maxelig = max(elig`mto'_2008)
		replace  elig`mto'_2008 = maxelig
		drop maxelig
	}
	
	keep npwp elig*
	duplicates drop

	egen elig		= rowmax(elig*)
	keep if elig ==1		// Keep if ever eligible for any MTO selection, any year
	drop elig				// Then drop the any-eligible var, will generate mto-year specific one
	
	reshape long elig, i(npwp) j(mto_year) string
	keep if elig==1			// MTO-year specific eligibility. Keep only if eligible for that particular MTO in that particular year
	split mto_year, parse("_")
	ren mto_year1 selection_mto
	ren mto_year2 selection_yr
	drop mto_year
	destring selection_mto selection_yr, replace
	sort npwp selection_yr selection_mto
	
	* Check MTOs that select from the same KPPs in the same year
	duplicates tag npwp selection_yr, gen(dup)
	tab selection_mto if dup
	tab selection_yr if dup
	ren dup eligible_at_many
	format npwp %15.0g
	
	label data "MTO selection eligibility based on KPP as of calendar year"
	saveold "${output}/analysis/MTO_eligible_taxpayers_selection_yr.dta", replace
}
clear
log close
