* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765

log using "${dofile}/logs/1_3_Analysis_file_calendar_yr.log", replace
di in red "Run 1_3_Analysis_file_calendar_yr.do"

***************************************************************
********** Depart from eligible NPWPs dataset *****************
***************************************************************
	
	u "${output}/analysis/MTO_eligible_taxpayers_selection_yr.dta"
	drop elig
	
	* For taxpayers eligible at multiple MTOs, randomly select one
	gen double temprand = runiform()
	sort npwp selection_yr temprand
	by npwp selection_yr: gen ord = _n
	keep if ord==1
	isid npwp selection_yr
	drop eligible_at_many temprand ord
	
	unique npwp
	local npwps = `r(unique)'
	local obs	= `r(N)'
	
	* Merge treatment variable
	forvalues i=-9/8{
		gen calendar_yr = selection_yr + `i'
		
		* Merge in treatment
		ren calendar_yr filing_yr
		merge 1:1 npwp filing_yr using "${output}/analysis/mto_treatment_calendar_yr_SPT1771.dta", ///
		keepusing(mto_post mto kpp)
		keep if _merge==1 | _merge==3
		drop _merge
		
		destring kpp, replace
		
		* Base, let kpp code as of the latest year be origin_kpp
		if `i'<0{
			local j = -`i'
			ren kpp 	 bcy`j'_kpp
			ren mto_post bcy`j'_mto_post
			ren mto 	 bcy`j'_mto
		}
		else{
			ren mto_post ocy`i'_mto_post
			ren mto 	 ocy`i'_mto
			ren kpp 	 ocy`i'_kpp
		}
		drop filing_yr
	}
	
	* Origin KPP - KPP of baseline year
	ren bcy1_kpp origin_kpp
	
	* Confirm no obs lost
	unique npwp
	assert `r(unique)'==`npwps'
	assert `r(N)' == `r(N)'
	
	preserve
		u "${output}/analysis/MPN_detailed_clean.dta", clear

		* Keep payment made within 6 months after end of tax year
		keep if payment_dt <= mdy(6,30,tax_yr+1)
		
		* Keep only ppH and ppN type tax
		keep if regexm(tax_type,"^ppH") | regexm(tax_type,"^ppN")
		
		collapse (sum) taxpaid, by(npwp tax_yr tax_type)
		reshape wide taxpaid, i(npwp tax_yr) j(tax_type) string
		renvars taxpaid*, predrop(7)

		ds npwp tax_yr, not
		foreach var of varlist `r(varlist)'{
			replace `var' = 0 if `var'==.
		}
		
		destring npwp, replace force
		keep if !missing(npwp)
		
		format npwp %15.0g
		tempfile mpn
		sa `mpn'
	restore

	forvalues i=-9/8{
		cap drop tax_yr
		gen tax_yr = selection_yr + `i'
		
		merge 1:1 npwp tax_yr using `mpn',
		keep if _merge==1 | _merge==3
		drop _merge
		
		drop tax_yr
		ds npwp selection_yr selection_mto origin_kpp bcy* ocy*, not
		
		if `i'>=0{
			renvars `r(varlist)', pref("ocy`i'_")
		}
		else if `i'<0{
			local j = -`i'
			renvars `r(varlist)', pref("bcy`j'_")
		}
	}
	
	* Confirm no obs lost
	unique npwp
	assert `r(unique)'==`npwps'
	assert `r(N)' == `r(N)'
	
	* Merge SPT 1771 outcomes for the corresponding calendar year
		preserve
			u "${output}/analysis/SPT_1771_clean.dta", clear
			
			* Variables behind income tax
			ren a2jphn			k_nincome		/* Fiscal net income that should be copied from attachment I */
			ren a2jpnf			k_nincome_a		/* Fiscal net incme from attachment I */	
			ren a2kokr			k_comploss
			ren a2pkp 			k_tincome
			ren a2ps17			k_citdue
			ren a2pp24			k_adjforcred
			ren a2ppht			k_totcitdue
			ren a2phbl			k_pphtotal
			ren a2phkl			k_paidvalue
			
			* Variables behind fiscal net income
			ren a2jphnkom		k_totcomninc	/* Total commercial net income */
			ren a2phfinal		k_ntaxinc
			ren a2jmpenfispos	k_totposadj
			ren a2jmpenfisneg	k_totnegadj
			ren a2nfpmod		k_facilityinv
			
			* Variables behind total commercial net income
			ren a2jphndn		k_domcomninc
			ren a2jphnkomln		k_forcomninc
			
			* Variables behind total domestic commercial net income			
			ren a2jphnus		k_nincbus
			ren a2jphnlus		k_nincsidebus

			* Variable sbehind net income from business
			ren a2jpru 			k_gincome
			ren a2hpp 			k_cgsold
			ren a2byusl			k_otherexpense
			
			** Keep ***
			keep npwp k_* tax_yr kpp filing_dt system_dt correction ///
			
			renvars k_*, predrop(2)
			
			destring npwp, replace
			format npwp %15.0g
			
			* Replace negative gross income with missing
			replace gincome = .n if gincome<0
			
			* Replace correction is original if missing (no cases)
			replace correction = 0 if missing(correction)
			
			* Ever corrected that tax years' filing
			bys npwp tax_yr: egen corrected = max(correction)
			replace corrected  = (corrected >0)
			
			* Filed on time - this should be well defined for every filing	
			gen ontime = (system_dt < mdy(5,1,tax_yr + 1) | filing_dt < mdy(5,1,tax_yr + 1) ) if !missing(system_dt) | !missing(filing_dt)
			bys tax_yr: egen avgontime = mean(ontime)
			gen uniform = runiform() if ontime==.
			replace ontime = (uniform <= avgontime) if ontime==.
			bys npwp tax_yr: egen maxontime = max(ontime)
			drop ontime
			ren maxontime ontime
			
			destring kpp, replace
			
			drop kpp uniform avgontime
			
			* Keep filings filed by 6 months after tax year ends
			keep if filing_dt <= mdy(6,30,tax_yr+1)
		
			* Keep original filing or earliest correction if original not availbale
			bys npwp tax_yr: egen mincorrection = min(correction)
			drop if correction!=mincorrection
			
			* If still duplicates, keep earliest
			bys npwp tax_yr: egen mindate = min(system_dt)
			drop if system_dt!=mindate
			
			* Else randomly pick one
			gen double temprand = runiform()
			sort npwp tax_yr temprand
			by npwp tax_yr: gen ord = _n
			keep if ord==1
			isid npwp tax_yr
			
			drop mindate filing_dt system_dt mincorrection temprand ord
			
			tempfile 1771
			sa `1771'
		restore
		
		forvalues i=-9/8{
			
			cap drop tax_yr
			gen tax_yr = selection_yr + `i'

			merge 1:m npwp tax_yr using `1771'
			keep if _merge==1 | _merge==3
			drop _merge
			
			drop tax_yr
			* Rename
			if `i'<0{
				local j = -`i'
				ds npwp selection_yr selection_mto origin_kpp bcy* ocy*, not 
				renvars `r(varlist)', pref("bcy`j'_")
			}
			else{
				ds npwp selection_yr selection_mto origin_kpp bcy* ocy*, not 
				renvars `r(varlist)', pref("ocy`i'_")
			}
			
		} /* Close j loop */
		
	* Confirm no obs lost
	unique npwp
	assert `r(unique)'==`npwps'
	assert `r(N)' == `r(N)'
	
	order origin_kpp, after(selection_yr)
	label data "MTO Analysis file (all regions): treatment, outcome, baseline"
	saveold "${output}/analysis/MTO_analysisfile_calendar_yr.dta", replace

clear
log close
