* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765

log using "${dofile}/logs/1_4_Extract_SPT_1771_corrections.log", replace
di in red "Run 1_4_Extract_SPT_1771_corrections.do"
/*
	SPT 1771 tax variables to keep 

	A2JPHN			1771 1. Fiscal net income (copied from 1771-I 8)
	A2JPNF			1771-I 8. Fiscal net income (3 - 4 + 5m - 6e - 7)
	A2KOKR			1771 2. Compensation for fiscal loss carried forward
	A2PKP			1771 3. Taxable income (1 - 2)
	A2PS17			1771 4. Income tax due
	A2PP24			1771 5. Adjustment for foreign tax credit refunded that had been credited in the previous year's return (income tax article 24)
	A2PPHT			1771 6. Total tax due (4 + 5)
	A2JPRU			1771-I 1a. Gross income
	A2HPP			1771-I 1b. Cost of good sold (production cost)
	A2BYUSL			1771-I 1c. Other expense
	A2JPHNUS		1771-I 1d. Net income from business (1a - 1b - 1c)
	A2JPHNLUS		1771-I 1g. Net income from side business (1e - 1f)
	A2JPHNDN		1771-I 1h. Total domestic commercial net income (1d + 1g)
	A2JPHNKOMLN		1771-I 2. Foreign commercial net income
	A2JPHNKOM		1771-I 3. Total commercial net income (1h + 2)
	A2PHFINAL		1771-I 4. Income subject to final tax and non-taxable income
	A2JMPENFISPOS	1771-I 5m. Total positive fiscal adjustment (total of 5a to 5l)
	A2JMPENFISNEG	1771-I 6e. Total negative fiscal adjustment (total of 6a to 6d)
	A2NFPMOD		1771-I 7. Facilities of investment allowance (as reduction of net income)
				
*/

****************************************************
********** Identifying corrections *****************
****************************************************


	u "${output}/analysis/SPT_1771_clean.dta", clear
	
	* Variables behind income tax
	ren a2jphn			k_nincome		/* Fiscal net income that should be copied from attachment I */
	ren a2jpnf			k_nincome_a		/* Fiscal net incme from attachment I */	
	ren a2kokr			k_comploss
	ren a2pkp 			k_tincome
	ren a2ps17			k_citdue
	ren a2pp24			k_adjforcred
	ren a2ppht			k_totcitdue
	
	* Variables behind fiscal net income
	ren a2jphnkom		k_totcomninc	/* Total commercial net income */
	ren a2phfinal		k_ntaxinc
	ren a2jmpenfispos	k_totposadj
	ren a2jmpenfisneg	k_totnegadj
	ren a2nfpmod		k_facilityinv
	
	* Variables behind total commercial net income
	ren a2jphndn		k_domcomninc
	ren a2jphnkomln		k_forcomninc
	
	* Variables behind total domestic commercial net income			
	ren a2jphnus		k_nincbus
	ren a2jphnlus		k_nincsidebus

	* Variable sbehind net income from business
	ren a2jpru 			k_gincome
	ren a2hpp 			k_cgsold
	ren a2byusl			k_otherexpense
	
	** Keep ***
	keep npwp k_* tax_yr kpp filing_dt system_dt correction ///
	
	renvars k_*, predrop(2)
	
	destring npwp, replace
	format npwp %15.0g
		
	* Does not bind, but just in case
	replace correction = 0 if correction==.
	replace gincome = .n if gincome<0
	
	destring npwp, replace
	format npwp %15.0g
	
	*************************************************
	
	* Express Rp variables in billion Rp
	ds npwp tax_yr kpp correction *_dt, not
	  
	foreach var of varlist `r(varlist)'{
		replace `var' = `var'/10^9
	}
	
	********** Dummies for any corrections ********** 
	
	* Corrections filed in the filing year
	gen double filing_yr = year(filing_dt)
	gen double system_yr = year(system_dt)
	replace filing_yr = system_yr if missing(filing_yr) | system_yr< filing_yr
	
	* 4 cases when system_yr or fiing_yr are missing - assume  filed by next year
	replace filing_yr = tax_yr +1 if missing(filing_yr)
	
	foreach year in filing tax{
		
		bys npwp `year'_yr: egen anycorr_`year'_yr = max(correction)
		replace anycorr_`year'_yr = (anycorr_`year'_yr >0)
		
		* Any corrections in filing_yr
		preserve
			keep npwp `year'_yr anycorr_`year'_yr
			duplicates drop
			
			saveold "${output}/analysis/SPT_1771_anycorr_`year'_yr.dta", replace
		restore
	}
	
	* Original filings
	preserve
		keep if correction==0
		bys npwp tax_yr: egen minfiling = min(filing_dt)
		keep if minfiling==filing_dt
		
		gen double temprand = runiform()
		sort npwp tax_yr temprand
		by npwp tax_yr: gen ord = _n
		keep if ord==1
		isid npwp tax_yr
		drop temprand ord
		
		tempfile original
		sa `original'
	restore
	
	* Corrected amounts in each calendar year
	preserve
		keep if correction>0
		
		ren filing_dt correction_dt
		ren filing_yr correction_yr
		ren kpp	 correction_kpp
		
		saveold "${output}/analysis/SPT_1771_correction_filings.dta", replace
		
		* For corrected totals, keep latest correction
		bys npwp correction_yr tax_yr: egen maxcorr = max(correction)
		keep if maxcorr==correction
		drop maxcorr
		
		drop system_yr system_dt anycorr*
		renvars gincome 	citdue totcitdue tincome nincome ///
			cgsold        nincsidebus   totcomninc   totnegadj    ///
			otherexpense  domcomninc    ntaxinc       facilityinv ///
			nincbus       forcomninc    totposadj     comploss, postf(_c)
		
		order npwp correction_dt correction_yr tax_yr correction
		
		merge m:1 npwp tax_yr using `original'
		keep if _merge==1 | _merge==3
		drop _merge
		
		foreach var of varlist gincome citdue totcitdue tincome nincome ///
			cgsold        nincsidebus   totcomninc   totnegadj    ///
			otherexpense  domcomninc    ntaxinc       facilityinv ///
			nincbus       forcomninc    totposadj     comploss{
			gen double cordif_`var' = `var'_c - `var'
			bys npwp correction_yr: egen double tot_corr_`var' = sum(cordif_`var')
			bys npwp correction_yr: egen double tot_corrpre_`var' = sum(cond(tax_yr<2006,cordif_`var',.))
			label var tot_corr_`var' "Tot recoveries of `var' filed this correction year"
			label var tot_corr_`var' "Tot pre-2007 recoveries of `var' filed this correction year"
		}
		
		keep npwp correction_yr tot_corr_* tot_corrpre_*
		duplicates drop
		
		saveold "${output}/analysis/SPT_1771_correction_totals.dta", replace
	restore

clear
log close
