* SIKKA are confidential anonymized data on DGT's employees
* NIP is the anonymized (randomly generated) employee ID
set seed 98765
log using "${dofile}/logs/1_6_Extract_KPP_staffing.log", replace
di in red "Running 1_6_Extract_KPP_staffing.do"

local kpp_totals	= 1
local stats			= 1


if `kpp_totals'==1{
	
	u "${output}/analysis/LK03_panel.dta", clear
	
	* Delete month-year observations when employee is not yet at DGT
	keep if !missing(position_start_date)
	
	* Merge exit data (Non-LK)
	merge 1:1 nip year month using "${output}/analysis/NONLK_panel.dta", keepusing(exit date)
	keep if _merge==1 | _merge==3
	drop _merge
	
	* Delete month-year observations after employee has permanently left DGT
	bys nip: egen dateexit = max(date)
	bys nip: egen anyexit = max(exit)
	drop if mdy(month,1,year)>dateexit
	
	* Merge demographics - demo file has some duplicates
	preserve
		u "${output}/analysis/LK01_clean.dta", clear
		keep nip dob female
		sort nip dob
		by nip: keep if _n == 1
		
		tempfile nips
		sa `nips'
	restore
	
	merge m:1 nip using `nips'
	keep if _merge==1 | _merge==3
	drop _merge
	
	* Merge NIP's education history
	merge 1:1 nip year month using "${output}/analysis/LK04_panel.dta", keepusing(educ_degree)
	keep if _merge==1 | _merge==3
	drop _merge
	
	* Merge salary - 
	merge 1:1 nip year month using "${output}/analysis/LK_panel_tunjangan.dta", keepusing(salary_calc tunjangan tunjangan_imputed)
	keep if _merge==1 | _merge==3
	drop _merge
	
	* Merge evaluations (many to one as there is unique valuation for year)
	preserve
		u "${output}/analysis/LK16_clean.dta", clear
		
		tab dp3_year
		keep if inrange(dp3_year,2003,2011)
		
		ren dp3_year		year
		ren kesetiaan 		dp3_loyalty
		ren prestasi_kerja 	dp3_performance
		ren tanggung_jawab	dp3_responsibility
		ren ketaatan		dp3_obedience
		ren kejujuran		dp3_honesty
		ren kerjasama		dp3_cooperation
		ren prakarsa		dp3_initiative
		ren total_dp3		dp3_total
		
		tempfile dp3
		sa `dp3'
	restore
	
	merge m:1 nip year using `dp3', keep(1 3) nogen
	
	sum dp3*
	
	replace tunjangan = tunjangan_imputed if missing(tunjangan)
	drop tunjangan_imputed
	
	ren salary_calc salary
	
	gen double totalcomp = salary + tunjangan
	
	/* Convert to real numbers */
	**************************************
	* Deflate Rp denominated #s to 2007 Rp
	**************************************
	preserve
		insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
		replace date = substr(date,1,4)
		destring date, replace
		replace date = date-1	// End of year 
		ren idngdp deflator		// end-of-2014 Rp
		ren date year
		
		* Get deflator relative to 2007 Rp
		gen double def07 = deflator if year==2007
		egen def07m = max(def07)
		drop def07
		
		gen double deflator2007 = (deflator/def07m)*100
		drop def07m
		
		// Rescale so that it's 1 in 2007
		replace deflator2007=deflator2007/100
		
		keep year deflator2007
		tempfile deflator
		sa `deflator'
	restore
	
	merge m:1 year using `deflator'
	keep if _merge==3
	drop _merge
	
	foreach var of varlist salary tunjangan totalcomp{
		gen double `var'Rp07 = `var'/deflator2007
	}
	
	*********** Compute variables for KPP level stats ***********
	gen double age = (mdy(month,1,year) - dob)/365 if !missing(dob)
	sum age, detail
	
	keep if inrange(age,18,75)
	
	* Account representative dummy
	tab structural_position
	gen ar 			= (structural_position == 1)
	
	* Tax auditor dummy
	tab functional_group
	tab functional_position
	gen auditor		= (functional_group == 2)

	* Education: college or more
	gen college = (educ_degree>=7)
	
	* Experience in DGT
	bys nip: egen first_date = min(position_start_date)
	gen dgt_years = (mdy(month,1,year) - first_date)/365
	gen dgt_pre2002 = (first_date < mdy(1,1,2002))
	
	* Vars to keep
	ren eselon_3 kpp_name
	
	* Keep only tax offices that have a name. KPP name lowercase for matching with .csv names
	keep if !missing(kpp_name)
	replace kpp_name = lower(kpp_name)
	
	keep nip year month kpp_name dp3* age female ar auditor college dgt_years dgt_pre2002 salary tunjangan totalcomp *Rp07
	
	tempfile niplevel
	sa `niplevel'
	
	****************************************************
	********* Match many-to-one with KPP codes *********
	****************************************************
	
	insheet using "${raw}/auxiliary/match_SIKKA_KPPs_codes_updated_reviewed.csv", clear
	
	keep if keep_match!=0 | manual_edit!=.
	replace kpp_code = manual_edit if !missing(manual_edit)
	keep kpp_name kpp_code
	duplicates drop
	
	* Keep only if has a KPP code (e.g. is in SIDJP)
	merge 1:m kpp_name using `niplevel'
	keep if _merge==3
	drop _merge
	
	* Staff quality and salary for ARs and auditors only
	foreach staff in auditor ar{
		foreach x in female age dgt_years college ///
			salary tunjangan totalcomp ///
			salaryRp07 tunjanganRp07 totalcompRp07 ///
			dp3_loyalty ///
			dp3_performance	///
			dp3_responsibility ///
			dp3_obedience ///
			dp3_honesty ///
			dp3_cooperation ///
			dp3_initiative ///
			dp3_total {
			gen double `staff'_`x' = `x' if `staff' ==1
		}
	}
	
	tempfile all
	sa `all'
	******************************************************************************************
	********* pre-2007 performance characteristics of NIPs in MTO/PTO in 2007/2008 ***********
	******************************************************************************************
	preserve
		keep if inlist(year,2007,2008) & ar==1 | auditor==1
		drop year
		ds kpp*, v(32)
		destring kpp_code, replace
		ren kpp_code kpp
		
		gen double mto13		= inlist(kpp, 38, 46, 62, 123, 308, 441, 511, 631, 641, 651, 725, 812)
		gen double mto19		= mto13 | inlist(kpp,73, 217, 218, 415, 431, 904)
		
		* Keep only PTOs or the 13 MTOs created in 2007, in case codes for other MTOs show up earlier
		drop if mto19==1 & mto13==0
		
		* Drop if any special KPPs or LTOs
		drop if inlist(kpp,51,91,92,93) | inlist(kpp,52,53,54,55,56,57,58,59,81)
		
		keep nip mto13 ar auditor
		collapse (max) mto13, by(nip ar auditor)
		gduplicates drop
		
		ren mto13 staffed_in_mto07_08
		
		tempfile taggedstaff
		sa `taggedstaff'
	restore
	
	merge m:1 nip ar auditor using `taggedstaff', keep(3) nogen
	keep if year==2006
	
	tempfile allstaff
	sa `allstaff'
	
	collapse (mean) dp3* age dgt_years female college dgt_pre2002 salaryRp07 tunjanganRp07 totalcompRp07, by(staffed_in_mto07_08 year)
	gen staff = "all"
	tempfile staff
	sa `staff'
	
	u `allstaff', clear
	keep if ar==1
	collapse (mean) dp3* age dgt_years female college dgt_pre2002 salaryRp07 tunjanganRp07 totalcompRp07, by(staffed_in_mto07_08 year)
	gen staff = "ar"
	
	tempfile ar
	sa `ar'
	
	u `allstaff', clear
	keep if auditor==1
	collapse (mean) dp3* age dgt_years female college dgt_pre2002 salaryRp07 tunjanganRp07 totalcompRp07, by(staffed_in_mto07_08 year)
	gen staff = "auditor"
	
	append using `staff'
	append using `ar'
	
	order staff year  staffed
	outsheet using "${output}/analysis/csv/Baseline_demos_mto_staff.csv", comma replace
	
	************************************************************
	********* Aggregate year by year characteristics ***********
	************************************************************
	
	u `all', clear
	* Collase at KPP code (many KPP names share the same code (small deviation from names))
	drop kpp_name
	collapse (count) nip ///
			 (sum) female ar auditor college dgt_pre2002 ///
			 (mean) age dgt_years salary tunjangan totalcomp ///
			 (mean)	salaryRp07 tunjanganRp07 totalcompRp07 ///
			 (mean) dp3* ///
			 (mean) auditor_* ar_*, by(year month kpp_code)
	
	ren kpp_code kpp
	
	saveold "${output}/analysis/SIKKA_for_MTO_by_KPP_code.dta", replace
}

if `stats'==1{
	
	* Keep only the taxpayers in the MTO regions
	u "${raw}/auxiliary/kpps_mtos_regions_codes.dta", clear
	bys region: egen hasmto19 = max(mto)
	keep if hasmto19==1		/* Keep KPP in regions with MTO */
	
	destring kpp, replace
	gen double mto13		= inlist(kpp,7, 38, 46, 62, 123, 308, 441, 511, 631, 641, 651, 725, 812)
	
	bys region: egen hasmto13 = max(mto13)
	
	keep kpp hasmto19 hasmto13
	
	duplicates drop
	tempfile kpps
	sa `kpps'
	
	u "${output}/analysis/SIKKA_for_MTO_by_KPP_code.dta", clear
	
	keep if inrange(year,2008,2011) & month==12
	
	tempfile staff
	sa `staff'
	
	* Tax data for total taxpayers
	u "${output}/analysis/mto_treatment_calendar_yr_SPT1771.dta", clear
	
	des
	keep if inrange(filing_yr,2008,2011)
	destring kpp, replace
	keep if !missing(kpp)
	ren filing_yr year
	
	* Keep only KPPs in regions where there is MTO
	merge m:1 kpp using `kpps'
	keep if _merge==3
	drop _merge
	
	cap drop mto
	
	* MTO flags
	gen double mto13		= inlist(kpp,7, 38, 46, 62, 123, 308, 441, 511, 631, 641, 651, 725, 812)
	gen double mto19		= mto13 | inlist(kpp,73, 217, 218, 415, 431, 904)
	
	* Drop if any special KPPs or LTOs
	drop if inlist(kpp,51,91,92,93) | inlist(kpp,52,53,54,55,56,57,58,59,81)
	
	drop npwp
	gen npwp=1
	keep npwp kpp mto13 mto19 hasmto13 hasmto19 year
	
	collapse (sum) npwp, by(kpp mto13 mto19 hasmto13 hasmto19 year)
	
	merge 1:1 kpp year using `staff'
	keep if _merge==3
	drop _merge

	* Annual ratios of NIP to NPWP by KPP by year
	gen double npwp_to_nip 		= npwp/nip
	gen double npwp_to_ar 		= npwp/ar
	gen double npwp_to_auditor	= npwp/auditor
	
	* Average by MTO vs non-MTO over 2008-2011 period (excluding additional MTOs)
	preserve
		drop if mto13==0 & mto19==1
		drop if hasmto13==0 & hasmto19==1
		collapse 	(sum)  npwp nip ar auditor college female ///
					(mean) age dgt_years salary tunjangan totalcomp ///
					(mean) salaryRp07 tunjanganRp07 totalcompRp07 npwp_to_* ///
					(mean) dp3* ///
					(mean) auditor_* ar_*, by(mto13 year) 
					
		outsheet using "${output}/analysis/csv/MTO_staff_ratios.csv", comma replace
	restore
	
}
clear
log close
