* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/1_7_Extract_calendar_payments.log", replace
di in red "Running 1_7_Extract_calendar_payments.do"

******************* Total amount paid in the calendar year  *******************

	u "${output}/analysis/MPN_detailed_clean.dta", clear
	
	destring npwp, replace force
	keep if !missing(npwp)
	
	format npwp %15.0g
	
	assert !missing(payment_dt)
	
	gen double year = year(payment_dt)
	gen double month = month(payment_dt)
	
	replace tax_type = subinstr(tax_type,"individual","ind",.)
	replace tax_type = subinstr(tax_type,"corporate","corp",.)
	replace tax_type = subinstr(tax_type,"domestic","dom",.)
	replace tax_type = subinstr(tax_type,"import","imp",.)

	replace tax_type = "ppH_OTHER" if inlist(tax_type,"ppH_22","ppH_final","ppH_22_imp","ppH_oilgas","ppH_nonoilgas","ppH_2529_ind")
	replace tax_type = "ppH_DIVINT" if inlist(tax_type,"ppH_23","ppH_interest")
	replace tax_type = "ppH_PAYROLL" if inlist(tax_type,"ppH_21","ppH_26")

	replace tax_type = "ppH_notCIT" if inlist(tax_type,"ppH_PAYROLL","ppH_DIVINT","ppH_OTHER")

	replace tax_type = "ppN" if regexm(tax_type,"ppN")

	keep if inlist(tax_type,"ppH_2529_corp","ppH_notCIT","ppN")	
	
	gen double taxpaid_preDec = taxpaid if month<12
	
	`tools'collapse (sum) taxpaid taxpaid_preDec, by(year npwp tax_type)
	replace taxpaid = taxpaid/10^9
	replace taxpaid_preDec = taxpaid_preDec/10^9

	ren taxpaid allpay_
	ren taxpaid_preDec allpaypreDec_
	reshape wide allpay_ allpaypreDec_, i(npwp year) j(tax_type) string

	foreach var of varlist allpay*{
		replace `var' = 0 if missing(`var')
	}

	label data "Total taxes paid in the calendar year regardless for which tax year"
	saveold "${output}/analysis/calendar_tax_payments.dta", replace
	
***************** Total amount paid for tax year x after 6 months + past ********

	u "${output}/analysis/MPN_detailed_clean.dta", clear
	
	destring npwp, replace force
	keep if !missing(npwp)
	
	format npwp %15.0g

	assert !missing(payment_dt)
	gen double year = year(payment_dt)
	keep if payment_dt > mdy(6,30,tax_yr+1)

	replace tax_type = subinstr(tax_type,"individual","ind",.)
	replace tax_type = subinstr(tax_type,"corporate","corp",.)
	replace tax_type = subinstr(tax_type,"domestic","dom",.)
	replace tax_type = subinstr(tax_type,"import","imp",.)


	replace tax_type = subinstr(tax_type,"individual","ind",.)
	replace tax_type = subinstr(tax_type,"corporate","corp",.)
	replace tax_type = subinstr(tax_type,"domestic","dom",.)
	replace tax_type = subinstr(tax_type,"import","imp",.)

	replace tax_type = "ppH_OTHER" if inlist(tax_type,"ppH_22","ppH_final","ppH_22_imp","ppH_oilgas","ppH_nonoilgas","ppH_2529_ind")
	replace tax_type = "ppH_DIVINT" if inlist(tax_type,"ppH_23","ppH_interest")
	replace tax_type = "ppH_PAYROLL" if inlist(tax_type,"ppH_21","ppH_26")

	replace tax_type = "ppH_notCIT" if inlist(tax_type,"ppH_PAYROLL","ppH_DIVINT","ppH_OTHER")

	replace tax_type = "ppN" if regexm(tax_type,"ppN")

	keep if inlist(tax_type,"ppH_2529_corp","ppH_notCIT","ppN")	

	`tools'collapse (sum) taxpaid, by(year npwp tax_type)
	replace taxpaid = taxpaid/10^9

	destring npwp, replace
	format npwp %15.0g

	ren taxpaid latepay_
	reshape wide latepay_, i(npwp year) j(tax_type) string

	foreach var of varlist latepay*{
		replace `var' = 0 if missing(`var')
	}

	label data "Total taxes paid for year x after 6 months past the end of year x"
	saveold "${output}/analysis/late_tax_payments.dta", replace
	
clear
log close
