* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/2_2_Balancing_weights_robustness_dont_drop_100mil.log", replace
di in red "Run 2_2_Balancing_weights_robustness_dont_drop_100mil.do"

* Toggles that switch different parts of the code on and off
local setup				= 1	
local weights			= 1		

global minyear 	= 2003
global maxyear 	= 2011

************************************
***** 1. Set up analysis file ******
************************************

if `setup'==1{
	
	u "${output}/analysis/MTO_analysisfile_calendar_yr.dta", clear
	
	* Discard taxpayers that were eligible for MTOs selecting in 2006
	foreach y in 2006 2007 2008{
		gen select`y' = (selection_yr==`y')
		bys npwp: egen elig`y' = max(select`y')
	}
	
	keep if (elig2007==1 | elig2008==0) & elig2006==0
	drop select20* elig20*
	
	* Keep MTOs created in 2007 (this drops Jakarta Pusat and Bekasi, created in 2004 and 2006)
	keep if inlist(selection_mto,725, 441, 38, 62, 7, 46, 812, 651, 123, 308, 511, 641, 631)
	
	* Keep selection years 2007 and 2008
	keep if inlist(selection_yr,2007,2008)
	
	* Discard taxpayers eligible for selection at multiple MTOs
	qui unique selection_mto, by(npwp) gen(d)
	bys npwp: egen m = max(d)
	drop if m>1
	
	* 2008 expansiom is only important for Jakarta Barat (38). Keep 2008 expansion for that MTO
	drop if selection_yr==2007 & selection_mto==38
	drop if selection_yr==2008 & selection_mto!=38
		
	* Make sure origin_kpp never missing
	misstable sum bcy*_kpp
	
	foreach i in 5 4 3 2{
		replace origin_kpp = bcy`i'_kpp if missing(origin_kpp)
	}
	
	assert !missing(origin_kpp)
	
	* Keep calendear years 2003-2011 (ocy0 = 2007 or 2008)
	drop bcy6* bcy7* bcy8* bcy9* ///
		 ocy5* ocy6* ocy7* ocy8* 
	
	tab selection_mto
	
	* Fill in in-between years of observed treatment
	* If year x is missing, assign treatment status in year x to the treatment status of year x+1
	* br npwp selection_yr bcy*_mto ocy*_mto 

	* Outcome years
	/*
		Replace 2007-2010 with 2008-2011 for selection year 2007
		Replace 2008-2010 with 2009-2011 for selection year 2008
	*/
	
	foreach i in 3 2 1 0{
		local o = `i' + 1
		replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2007
	}
	
	foreach i in 2 1 0{
		local o = `i' + 1
		replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2008
	}
	
	* Baseline years 
	/*
		Replace 2004-2006 with 2003-2005 for selection year 2007
		Replace 2004-2007 with 2003-2006 for selection year 2008
	*/
	
	foreach i in 3 2 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2007
	}
	
	foreach i in 4 3 2 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2008
	}
	
	******************** Ever MTO treatment ********************
	forvalues i=0/4{
		replace ocy`i'_mto_post = 1 if ocy`i'_mto== 1 & missing(ocy`i'_mto_post)
		replace ocy`i'_mto_post = 0 if ocy`i'_mto== 0 & missing(ocy`i'_mto_post)
	}
	
	* 2007 selection
	egen inMTOby2008_07 = rowmax(ocy0_mto_post ocy1_mto_post) if selection_yr==2007
	egen inMTOby2009_07 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post) if selection_yr==2007
	egen inMTOby2010_07 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post) if selection_yr==2007
	egen inMTOby2011_07 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post ocy4_mto_post) if selection_yr==2007
	
	* 2008 selection
	egen inMTOby2008_08 = rowmax(ocy0_mto_post) if selection_yr==2008
	egen inMTOby2009_08 = rowmax(ocy0_mto_post ocy1_mto_post) if selection_yr==2008
	egen inMTOby2010_08 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post) if selection_yr==2008
	egen inMTOby2011_08 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post) if selection_yr==2008
	
	forvalues y=2008/2011{
		gen inMTOby`y' = inMTOby`y'_07
		replace inMTOby`y' = inMTOby`y'_08 if selection_yr==2008
	}
	
	egen inMTOby2007 = rowmax(ocy0_mto_post) if selection_yr==2007
	replace inMTOby2007 = 0 if selection_yr==2008

	drop *_07 *_08
	
	* Ever in a pre-2007 MTO
	forvalues i=1/5{
		replace bcy`i'_mto_post = 1 if bcy`i'_mto== 1 & missing(bcy`i'_mto_post)
		replace bcy`i'_mto_post = 0 if bcy`i'_mto== 0 & missing(bcy`i'_mto_post)
	}
	
	* Ever in a pre-2007 MTO
	egen double mtopre  = rowmax(bcy*_mto_post)

	** Merge KLU code: fixed for taxpayer over time
	merge m:1 npwp using "${output}/analysis/npwp_klu_mapping.dta", keepusing(klu_1721)
	keep if _merge==1 | _merge==3
	drop _merge
	
	tostring klu_1721, gen(klu2)
	replace klu2 = substr(klu2,1,2)
	destring klu2, gen(k)
	drop klu2
	ren k klu2
	
	replace klu2 = 99 if klu2==.

	replace klu_1721 = 99999 if klu_1721==.
	
	tab klu2
	
	/* Comment this out for robustness that does not drop v. small taxpayers
	* 2003-5 gross income > 100 million Rp (10,000 USD at 2007 exchange ratio)
	forvalues i=2/4{
		drop if bcy`i'_gincome < 10^8 	& 	selection_yr==2007
		
		local j = `i'-1
		drop if bcy`j'_gincome < 10^8 	& 	selection_yr==2008
	}
	*/
	
	* Some names are too long - rename
	renvars *ppH_2529_corporate, subst("corporate" "corp")
	renvars *ppH_2529_individual, subst("individual" "ind")
	renvars *pp*domestic, subst("domestic" "dom")
	renvars *pp*import, subst("import" "imp")
	
	*******************************************
	********** Reshape long on year ***********
	*******************************************
	
	gen double bcy1_kpp = origin_kpp
	keep npwp selection_yr selection_mto inMTOby* origin_kpp bcy* ocy*  klu2 klu_1721 
	order npwp selection_yr selection_mto inMTOby* origin_kpp bcy* ocy*  klu2 klu_1721
	
	preserve
		keep if _n==1
		keep bcy1*
		renvars _all, predrop(5)
		
		ds _all, v(32)
		local prepostvars = "`r(varlist)'"
	restore
	
	foreach x in `prepostvars'{
		renvars *y?*_`x', pref(`x')
		renvars *y?_`x', subst("_`x'" "")
	}

	qui reshape long `prepostvars' , ///
			i(npwp selection_yr) ///
			j(year) string
	
	* Recode year
	split year, parse("y")
	destring year2, replace
	drop year 
	gen double year = .
	replace year = selection_yr - year2 if year1=="bc"
	replace year = selection_yr + year2 if year1=="oc"
	drop year1 year2
	
	** Years restriction **
	keep if year>=${minyear} & year<=${maxyear}

	drop mto_post
	order npwp year kpp mto inMTOby2008 selection*
	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_nodrop100mil.dta", replace
}


******************************************************
******* 2. Manual cleaning and matching weights ******
******************************************************

if `weights'==1{
	
	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_nodrop100mil.dta", clear
	
	* Express Rp variables in billion Rp
	ds npwp selection_yr selection_mto year inMTOby* ///
	   kpp mto origin_kpp ontime corrected correction  klu2 klu_1721, not
	
	di "`r(varlist)'"
	foreach var of varlist `r(varlist)'{
		replace `var' = `var'/10^9
	}
	
	* Summarize SPT 1771 after cleaning so we see what this looks like
	gen evermto = inMTOby2008
	do "${dofile}/analysis/auxiliary_SPT_1771_detailed_cleaning.do"			/* This drops obs if outlier or SPT 1771 incorrect filing issues */
	
	drop p9999* p0001* istop* isbot*
	drop evermto

	* Make aggregate variables
	egen double ppH_total = rowtotal(ppH*)
	egen double ppN_total = rowtotal(ppN*)
	gen double  ppHN_total = ppH_total + ppN_total

	order npwp selection_yr selection_mto year origin_kpp inMTOby2008 kpp mto 
	
	tempfile mainall
	sa `mainall'
	
	*************************************************************************
	******************** 3. Treatment probability estimation ****************
	*************************************************************************

	u `mainall', clear
	
	* Keep treatment and baseline data
	keep npwp year inMTOby2008 selection_mto selection_yr gincome ppHN_total tincome
	
	* Match 2008 Jakarta Barat selection using 2005 data
	replace selection_yr = 2007 if selection_yr==2008
	
	keep if inrange(year,2003,2005)
	
	* Note: since now restriction is that payments and filings be paid or filed
	* 		by June of following tax year, all data in the setup file has
	*		2003-2005 payment and filing dates prior to selection date
	
	gen double base =.
	replace base = selection_yr - year
	drop year
	
	reshape wide gincome ppHN_total tincome, i(npwp inMTOby2008 selection_mto selection_yr) j(base)
	
	*************************************************************************
	**************** Taxpayers in the same support **************************
	*************************************************************************
	
	foreach base in 2{
		foreach var in gincome ppHN_total{
			
			mat support`base'`var' = J(3,10,.)		// 3 Rows: 99, 1, intersection
			forvalues i=0/1{
				qui egen double p975`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(97.5)
				qui egen double p025`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(2.5)
				
				qui sum p975`var'`i'
				local p975`var'`i' = `r(mean)'
				
				qui sum p025`var'`i'
				local p025`var'`i' = `r(mean)'
				
				mat support`base'`var'[`i'+1, 1] = `p025`var'`i''
				mat support`base'`var'[`i'+1, 2] = `p975`var'`i''
				mat support`base'`var'[`i'+1, 3] = `i'
			}
			
			gen double lb`var'`base' = max(`p025`var'1',`p025`var'0')		/* Lower bound of common support */
			gen double ub`var'`base' = min(`p975`var'1',`p975`var'0')		/* Upper bound of common support */
			
			mat support`base'`var'[3, 1]  = max(`p025`var'1',`p025`var'0')
			mat support`base'`var'[3, 2]  = min(`p975`var'1',`p975`var'0')
			
			preserve
				clear
				svmat support`base'`var'
				gen var = "`var'"
				gen baseyear = 2007-`base'
				ren support`base'`var'1 p025
				ren support`base'`var'2 p975
				ren support`base'`var'3 mto
				
				keep var mto  baseyear p025 p975
				order var baseyear mto  p025 p975 
				
				tempfile s`base'`var'
				save `s`base'`var''
			restore
		}	
		
		
		drop p975* p025*
	}
	
	gen double comsup2 = ( gincome2 > lbgincome2 & gincome2< ubgincome2 ) & ///
							( ppHN_total2 > lbppHN_total2 & ppHN_total2 < ubppHN_total2 ) & ///
							!missing(gincome2) & !missing(ppHN_total2)
	
	******************* Entropy balancing weights *******************
	
	* Selection MTO 
	qui tab selection_mto, gen(fe_r)
	
	* 2005 entropy weights		(base 2)
	ebalance inMTOby2008 gincome2  ///
					 ppHN_total2 fe_r* if comsup2==1, ///
	targets(1) generate(eweight2)
	
	preserve
		keep npwp eweight*
		
		tempfile eweights
		sa `eweights'
	restore
	
	**************************************************
	****** Merge estimated scores with main file *****
	**************************************************
	
	u `mainall', clear
	merge m:1 npwp using `eweights'
	keep if _merge==1 | _merge==3
	drop _merge
	
	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_nodrop100mil_weights.dta", replace	
}
clear
log close
