* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/2_3_Balancing_weights_robustness_comm_support_99_1.log", replace
di in red "2_3_Balancing_weights_robustness_comm_support_99_1.do"

* Toggles that switch different parts of the code on and off
local setup				= 1	
local weights			= 1		

global minyear 	= 2003
global maxyear 	= 2011

******************************************************
******* 2. Manual cleaning and matching weights ******
******************************************************

if `weights'==1{
	
	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_nodrop100mil.dta", clear
	
	* Express Rp variables in billion Rp
	ds npwp selection_yr selection_mto year inMTOby* ///
	   kpp mto origin_kpp ontime corrected correction klu2 klu_1721, not
	
	di "`r(varlist)'"
	foreach var of varlist `r(varlist)'{
		replace `var' = `var'/10^9
	}
	
	* Summarize SPT 1771 after cleaning so we see what this looks like
	gen evermto = inMTOby2008
	do "${dofile}/analysis/auxiliary_SPT_1771_detailed_cleaning.do"	/* This drops obs if outlier or SPT 1771 incorrect filing issues */
	
	drop p9999* p0001* istop* isbot*
	drop evermto

	* Make aggregate variables
	egen double ppH_total = rowtotal(ppH*)
	egen double ppN_total = rowtotal(ppN*)
	gen double  ppHN_total = ppH_total + ppN_total

	order npwp selection_yr selection_mto year origin_kpp inMTOby2008 kpp mto 
	
	tempfile mainall
	sa `mainall'
	
	*************************************************************************
	******************** 3. Treatment probability estimation ****************
	*************************************************************************

	u `mainall', clear
	
	* Keep treatment and baseline data
	keep npwp year inMTOby2008 selection_mto selection_yr gincome ppHN_total tincome
	
	* Match 2008 Jakarta Barat selection using 2005 data
	replace selection_yr = 2007 if selection_yr==2008
	
	keep if inrange(year,2003,2005)
	
	* Note: since now restriction is that payments and filings be paid or filed
	* 		by June of following tax year, all data in the setup file has
	*		2003-2005 payment and filing dates prior to selection date
	
	gen double base =.
	replace base = selection_yr - year
	drop year
	
	reshape wide gincome ppHN_total tincome, i(npwp inMTOby2008 selection_mto selection_yr) j(base)
	
	*************************************************************************
	**************** Taxpayers in the same support **************************
	*************************************************************************
	
	foreach base in 2{
		foreach var in gincome ppHN_total{
			
			mat support`base'`var' = J(3,10,.)		// 3 Rows: 99, 1, intersection
			forvalues i=0/1{
				qui egen double p99`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(99)
				qui egen double p01`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(1)
				
				qui sum p99`var'`i'
				local p99`var'`i' = `r(mean)'
				
				qui sum p01`var'`i'
				local p01`var'`i' = `r(mean)'
				
				mat support`base'`var'[`i'+1, 1] = `p01`var'`i''
				mat support`base'`var'[`i'+1, 2] = `p99`var'`i''
				mat support`base'`var'[`i'+1, 3] = `i'
			}
			
			gen double lb`var'`base' = max(`p01`var'1',`p01`var'0')		/* Lower bound of common support */
			gen double ub`var'`base' = min(`p99`var'1',`p99`var'0')		/* Upper bound of common support */
			
			mat support`base'`var'[3, 1]  = max(`p01`var'1',`p01`var'0')
			mat support`base'`var'[3, 2]  = min(`p99`var'1',`p99`var'0')
			
			preserve
				clear
				svmat support`base'`var'
				gen var = "`var'"
				gen baseyear = 2007-`base'
				ren support`base'`var'1 p01
				ren support`base'`var'2 p99
				ren support`base'`var'3 mto
				
				keep var mto  baseyear p01 p99
				order var baseyear mto  p01 p99 
				
				tempfile s`base'`var'
				save `s`base'`var''
			restore
		}	
		
		
		drop p99* p01*
	}
	
	
	gen double comsup2 = ( gincome2 > lbgincome2 & gincome2< ubgincome2 ) & ///
							( ppHN_total2 > lbppHN_total2 & ppHN_total2 < ubppHN_total2 ) & ///
							!missing(gincome2) & !missing(ppHN_total2)
							

	******************* Entropy balancing weights *******************
	
	* Selection MTO 
	qui tab selection_mto, gen(fe_r)

	* 2005 entropy weights		(base 2)
	ebalance inMTOby2008 gincome2  ///
					 ppHN_total2 fe_r* if comsup2==1, ///
	targets(1) generate(eweight2) 
	
	preserve
		keep npwp eweight*
		
		tempfile eweights
		sa `eweights'
	restore
	
	**************************************************
	****** Merge estimated scores with main file *****
	**************************************************
	
	u `mainall', clear
	merge m:1 npwp using `eweights'
	keep if _merge==1 | _merge==3
	drop _merge
	
	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_weights_comm_support_99_1.dta", replace	
}

clear
log close
