* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/2_4_Balancing_weights_robustness_add20056.log", replace
di in red "Run 2_4_Balancing_weights_robustness_add20056.do"

* Toggles that switch different parts of the code on and off
local setup				= 1
local weights			= 1		

global minyear 	= 2003
global maxyear 	= 2011

************************************
***** 1. Set up analysis file ******
************************************

if `setup'==1{
	
	u "${output}/analysis/MTO_analysisfile_calendar_yr.dta", clear
	
	* Keep MTOs created in 2005-2007 (this drops Jakarta Pusat created in 2004)
	keep if selection_mto!=73
	
	* Keep selection years 2005-2008
	keep if inrange(selection_yr,2005,2008)
	
	* Discard taxpayers eligible for selection at multiple MTOs
	qui unique selection_mto, by(npwp) gen(d)
	bys npwp: egen m = max(d)
	drop if m>1
	
	tab selection_mto
	tab selection_mto selection_yr
	
	******* MTOs that expand per regulations *******
	* Denpassar (904) 		- Created in 2006, expanded in 2008 (large expansion - many more eligible)
	* Jakarta Barat (038)	- Created in 2007, expanded in 2008 (large expansion - many more eligible
	* Bekasi (431)			- Created in 2006, expanded in 2007 (small expansion)
	
	drop if selection_yr==2006 & selection_mto==904		/* Use the largest selection set - 2008 */ 
	drop if selection_yr==2007 & selection_mto==38		/* Use the largest selection set - 2008 */ 
	drop if selection_yr==2007 & selection_mto==431		/* Use the largest selection set - 2006 */ 
	
	tab selection_mto selection_yr
	
	* Make sure origin_kpp never missing
	misstable sum bcy*_kpp
	
	foreach i in 5 4 3 2{
		replace origin_kpp = bcy`i'_kpp if missing(origin_kpp)
	}
	
	assert !missing(origin_kpp)
	
	tab selection_mto
	
	* Fill in in-between years of observed treatment
	* If year x is missing, assign treatment status in year x to the treatment status of year x+1
	* br npwp selection_yr bcy*_mto ocy*_mto 

	* Outcome years
	/*
		Replace 2005-2010 with 2006-2011 for selection year 2005
		Replace 2006-2010 with 2007-2011 for selection year 2006
		Replace 2007-2010 with 2008-2011 for selection year 2007
		Replace 2008-2010 with 2009-2011 for selection year 2008
	*/	
		* 2005 selection
		foreach i in 5 4 3 2 1 0{
			local o = `i' + 1
			replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2005
		}
		
		* 2006 selection
		foreach i in 4 3 2 1 0{
			local o = `i' + 1
			replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2006
		}
	
		* 2007 selection
		foreach i in 3 2 1 0{
			local o = `i' + 1
			replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2007
		}
		
		* 2007 selection
		foreach i in 2 1 0{
			local o = `i' + 1
			replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2008
		}
	
	* Baseline years 
	/*	
		Replace 2004 	  with 2003 	 for selection year 2005
		Replace 2004-2005 with 2003-2004 for selection year 2006
		Replace 2004-2006 with 2003-2005 for selection year 2007
		Replace 2004-2007 with 2003-2006 for selection year 2008
	*/
	
	* 2005 selection
	foreach i in 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2005
	}
	
	* 2006 selection
	foreach i in 2 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2006
	}
	
	* 2007 selection
	foreach i in 3 2 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2007
	}
	
	* 2008 selection
	foreach i in 4 3 2 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2008
	}
	
	******************** MTO treatment by selection year + 1 ********************
	forvalues i=0/6{
		replace ocy`i'_mto_post = 1 if ocy`i'_mto== 1 & missing(ocy`i'_mto_post)
		replace ocy`i'_mto_post = 0 if ocy`i'_mto== 0 & missing(ocy`i'_mto_post)
	}
	
	egen double inMTObyocy1 =  rowmax(ocy0_mto_post ocy1_mto_post)
	egen double inMTObyocy2 =  rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post)
	egen double inMTObyocy3 =  rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post)
	egen double inMTObyocy4 =  rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post ocy4_mto_post)
	egen double inMTObyocy5 =  rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post ocy4_mto_post ocy5_mto_post)
	
	* Ever in a pre-2007 MTO
	forvalues i=1/5{
		replace bcy`i'_mto_post = 1 if bcy`i'_mto== 1 & missing(bcy`i'_mto_post)
		replace bcy`i'_mto_post = 0 if bcy`i'_mto== 0 & missing(bcy`i'_mto_post)
	}
	
	* Ever in a pre-2007 MTO
	egen double mtopre  = rowmax(bcy*_mto_post)
	
	** Merge KLU code: fixed for taxpayer over time
	merge m:1 npwp using "${output}/analysis/npwp_klu_mapping.dta", keepusing(klu_1721)
	keep if _merge==1 | _merge==3
	drop _merge
	
	tostring klu_1721, gen(klu2)
	replace klu2 = substr(klu2,1,2)
	destring klu2, gen(k)
	drop klu2
	ren k klu2
	
	replace klu2 = 99 if klu2==.

	replace klu_1721 = 99999 if klu_1721==.
	
	tab klu2
	
	* Has well defined MTO status (filed any SPT 1771 in 2007-2011)
	keep if !missing(inMTObyocy1)

	* Drop if in a pre-assignment MTO any time before selection year
	drop if mtopre==1

	* 3 baseline years gross income > 100 million Rp (10,000 USD at 2007 exchange ratio)
	forvalues i=2/4{
		drop if bcy`i'_gincome < 10^8 
	}
	
	* Some names are too long - rename
	renvars *ppH_2529_corporate, subst("corporate" "corp")
	renvars *ppH_2529_individual, subst("individual" "ind")
	renvars *pp*domestic, subst("domestic" "dom")
	renvars *pp*import, subst("import" "imp")
	
	******************************************************************
	********** Reshape long on years relative to treatment ***********
	******************************************************************
	
	gen double bcy1_kpp = origin_kpp
	keep npwp selection_yr selection_mto inMTOby* origin_kpp bcy* ocy*  klu2 klu_1721 
	order npwp selection_yr selection_mto inMTOby* origin_kpp bcy* ocy*  klu2 klu_1721
	
	preserve
		keep if _n==1
		keep bcy1*
		renvars _all, predrop(5)
		
		ds _all, v(32)
		local prepostvars = "`r(varlist)'"
	restore
	
	foreach x in `prepostvars'{
		renvars *y?*_`x', pref(`x')
		renvars *y?_`x', subst("_`x'" "")
	}

	qui reshape long `prepostvars' , ///
			i(npwp selection_yr) ///
			j(year) string
	
	* Recode year
	split year, parse("y")
	destring year2, replace
	drop year 
	gen double year_cal = .
	replace year_cal = selection_yr - year2 if year1=="bc"
	replace year_cal = selection_yr + year2 if year1=="oc"
	
	gen double year_rel = .
	replace year_rel = 0 - year2 if year1=="bc"
	replace year_rel = 0 + year2 if year1=="oc"
	
	drop year1 year2
	
	** Keep data for calendar years for which we have data **
	keep if year_cal>=${minyear} & year_cal<=${maxyear}
	
	drop mto_post
	order npwp year_rel year_cal kpp mto inMTObyocy1 selection*
	saveold "${output}/analysis/MTO_analysisfile_stacked_${minyear}_${maxyear}.dta", replace
}


******************************************************
******* 2. Manual cleaning and matching weights ******
******************************************************

if `weights'==1{
	
	u "${output}/analysis/MTO_analysisfile_stacked_${minyear}_${maxyear}.dta", clear
	
	* Express Rp variables in billion Rp
	ds npwp selection_yr selection_mto year_cal year_rel inMTOby* ///
	   kpp mto origin_kpp ontime corrected correction klu2 klu_1721, not
	
	di "`r(varlist)'"
	foreach var of varlist `r(varlist)'{
		replace `var' = `var'/10^9
	}
	
	* Summarize SPT 1771 after cleaning so we see what this looks like
	gen evermto = inMTObyocy1
	do "${dofile}/analysis/auxiliary_SPT_1771_detailed_cleaning.do"		/* This drops obs if outlier or SPT 1771 incorrect filing issues */

	drop p9999* p0001* istop* isbot*
	drop evermto

	* Make aggregate variables
	egen double ppH_total = rowtotal(ppH*)
	egen double ppN_total = rowtotal(ppN*)
	gen double  ppHN_total = ppH_total + ppN_total

	order npwp selection_yr selection_mto year_rel year_cal origin_kpp inMTObyocy1 kpp mto 
	
	tempfile mainall
	sa `mainall'
	
	*************************************************************************
	******************** 3. Treatment probability estimation ****************
	*************************************************************************

	u `mainall', clear
	
	* Keep treatment and baseline data
	keep npwp year_rel year_cal inMTObyocy1 selection_mto selection_yr gincome ppHN_total
	
	sum year_rel, detail
	tab selection_yr year_rel
	
	/* 	 -2 = 2005 for 2007 selection
	*/
	keep if inrange(year_rel,-4,-2)		
	
	tab selection_yr year_cal
	
	gen double base =.
	replace base = 0 - year_rel
	drop year_rel
	
	* Use real gross income and real total taxes paid for matching now that
	* matching is relative so don't want to have issues of inflation
	
	**************************************
	* Deflate Rp denominated #s to 2007 Rp
	**************************************
	preserve
		insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
		replace date = substr(date,1,4)
		destring date, replace
		replace date = date-1	// End of year 
		ren idngdp deflator		// end-of-2014 Rp
		ren date year_cal
		
		* Get deflator relative to 2007 Rp
		gen double def07 = deflator if year==2007
		egen def07m = max(def07)
		drop def07
		
		gen double deflator2007 = (deflator/def07m)*100
		drop def07m
		
		// Rescale so that it's 1 in 2007
		replace deflator2007=deflator2007/100
		
		keep year_cal deflator2007
		tempfile deflator
		sa `deflator'
	restore
	
	merge m:1 year_cal using `deflator'
	keep if _merge==3
	drop _merge
	
	foreach var of varlist gincome ppHN_total{
		replace `var' = `var'/deflator2007
				
	}
	
	keep gincome ppHN_total npwp inMTObyocy1 selection_mto selection_yr base
	reshape wide gincome ppHN_total, i(npwp inMTObyocy1 selection_mto selection_yr) j(base)
	
	*************************************************************************
	**************** Taxpayers in the same support **************************
	*************************************************************************

	foreach base in 2{
		foreach var in gincome ppHN_total{
			
			mat support`base'`var' = J(3,10,.)		// 3 Rows: 99, 1, intersection
			forvalues i=0/1{
				qui egen double p975`var'`i' = pctile(`var'`base') if inMTObyocy1==`i', p(97.5)
				qui egen double p025`var'`i' = pctile(`var'`base') if inMTObyocy1==`i', p(2.5)
				
				qui sum p975`var'`i'
				local p975`var'`i' = `r(mean)'
				
				qui sum p025`var'`i'
				local p025`var'`i' = `r(mean)'
				
				mat support`base'`var'[`i'+1, 1] = `p025`var'`i''
				mat support`base'`var'[`i'+1, 2] = `p975`var'`i''
				mat support`base'`var'[`i'+1, 3] = `i'
			}
			
			gen double lb`var'`base' = max(`p025`var'1',`p025`var'0')		/* Lower bound of common support */
			gen double ub`var'`base' = min(`p975`var'1',`p975`var'0')		/* Upper bound of common support */
			
			mat support`base'`var'[3, 1]  = max(`p025`var'1',`p025`var'0')
			mat support`base'`var'[3, 2]  = min(`p975`var'1',`p975`var'0')
			
			preserve
				clear
				svmat support`base'`var'
				gen var = "`var'"
				gen baseyear = `base'
				ren support`base'`var'1 p025
				ren support`base'`var'2 p975
				ren support`base'`var'3 mto
				
				keep var mto  baseyear p025 p975
				order var baseyear mto  p025 p975 
				
				tempfile s`base'`var'
				save `s`base'`var''
			restore
		}	
		
		
		drop p975* p025*
	}
	
	
	gen double comsup2 = ( gincome2 > lbgincome2 & gincome2< ubgincome2 ) & ///
							( ppHN_total2 > lbppHN_total2 & ppHN_total2 < ubppHN_total2 ) & ///
							!missing(gincome2) & !missing(ppHN_total2)
							
	******************* Entropy balancing weights *******************
	
	* Selection MTO 
	qui tab selection_mto, gen(fe_r)
	qui tab selection_yr, gen(fe_y)
	
	* 2005 entropy weights		(base 2)
	ebalance inMTObyocy1 gincome2  ///
					 ppHN_total2 fe_r* fe_y* if comsup2==1, ///
	targets(1) generate(eweight2)
	
	preserve
		keep npwp eweight*
		
		tempfile eweights
		sa `eweights'
	restore
	
	**************************************************
	****** Merge estimated scores with main file *****
	**************************************************
	
	u `mainall', clear
	merge m:1 npwp using `eweights'
	keep if _merge==1 | _merge==3
	drop _merge
	
	saveold "${output}/analysis/MTO_analysisfile_stacked_${minyear}_${maxyear}_weights.dta", replace	
}
clear
log close
