* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/2_6_Balancing_weights_robustness_placebo.log", replace
di in red "Run 2_6_Balancing_weights_robustness_placebo.do"

* Toggles that switch different parts of the code on and off	
local weights			= 1		
local analysis			= 1
local graphs			= 1

global minyear 	= 2003
global maxyear 	= 2011

if `weights'==1{
	
	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}.dta", clear
	
	* Express Rp variables in billion Rp
	ds npwp selection_yr selection_mto year inMTOby* ///
	kpp mto origin_kpp ontime corrected correction klu2 klu_1721, not
	
	di "`r(varlist)'"
	foreach var of varlist `r(varlist)'{
		replace `var' = `var'/10^9
	}
	
	* Assign same % treatment in placebo exercise as in MTO treatment
	unique npwp if inMTOby2008
	local mtoids = `r(unique)'
	unique npwp
	local allids = `r(unique)'
	
	local pctMTO = `mtoids'/`allids'
	
	* Summarize SPT 1771 after cleaning so we see what this looks like
	cap drop evermto
	gen evermto = inMTOby2008
	qui do "${dofile}/analysis/auxiliary_SPT_1771_detailed_cleaning.do"		/* This drops obs if outlier or SPT 1771 incorrect filing issues */
	
	drop p9999* p0001* istop* isbot*
	drop evermto
	
	/* Observations to be excluded for placebo exercise */
	bys npwp: egen evermto = max(mto)

	* Make aggregate variables
	egen double ppH_total = rowtotal(ppH*)
	egen double ppN_total = rowtotal(ppN*)
	gen double  ppHN_total = ppH_total + ppN_total

	order npwp selection_yr selection_mto year origin_kpp kpp inMTOby2008  mto 

	* MTO prediction formula
	preserve
		keep npwp year inMTOby2008 selection_mto selection_yr gincome ppHN_total
		
		keep if year==2005 
		
		foreach var of varlist gincome* ppHN_total*{
			gen double sn`var' = ln(`var'*10^9+1)
		}
		
		
		foreach var of varlist sngincome* snppHN_total*{
			mkspline spline`var' 3 = `var', pctile marginal
		}
		
		* Interaction
		gen double inter = sngincome*snppHN_total
		
		* Drop KPP Madya Medan 
		qui tab selection_mto, gen(fe_r)
		sum fe_r* if selection_mto==123
		drop fe_r5
		
		logit inMTOby2008 spline* inter  fe_r*  
	
		qui predict phatMTO if e(sample), pr
		
		keep npwp phatMTO
		tempfile prediction
		sa `prediction'
	restore
	
	*********** Assign placebo MTO treatment ***********
	/* 	Focus on taxpayers never treated by MTO and assign placebo MTO treatment
		as an increasing function of their MTO phat
	*/
	merge m:1 npwp using `prediction', keep(3) nogen
	drop if evermto==1
	
	* Generate placebo MTO - get same # MTO in MTO by 2008 taxpayers as in the data prior
	* to computation of 
	preserve
		keep if !missing(phatMTO)
		keep npwp  phatMTO
		duplicates drop
		
		* Rescale phatMTO to have mean 11%
		sum phatMTO, detail
		replace phatMTO = phatMTO*0.11/`r(mean)'
		
		* 1) Take the scaled probabilities for each taxpayer, phat_i
		sum phatMTO, detail
		
		* 2) Define a random number [in 0,1] for each taxpayer, rand_i
		gen double runiform = runiform(0,1)

		* 3) Assign fake treatment
		gen double fakeMTO = ( runiform<=phatMTO )
		
		* 4) Check roughly 11% were assigned fakeMTO
		sum fakeMTO
		
		tempfile placebo
		sa `placebo'
	restore
	
	merge m:1 npwp using `placebo', keep(3) nogen
	
	tempfile mainall
	sa `mainall'
	
	*************************************************************************
	******************** 3. Treatment probability estimation ****************
	*************************************************************************

	u `mainall', clear
	
	* Keep treatment and baseline data
	keep npwp year fakeMTO selection_mto selection_yr gincome ppHN_total tincome
	
	* Match 2008 Jakarta Barat selection using 2005 data
	replace selection_yr = 2007 if selection_yr==2008
	
	keep if inrange(year,2003,2005)
	
	* Note: since now restriction is that payments and filings be paid or filed
	* 		by June of following tax year, all data in the setup file has
	*		2003-2005 payment and filing dates prior to selection date
	
	gen double base =.
	replace base = selection_yr - year
	drop year
	
	reshape wide gincome ppHN_total tincome, i(npwp fakeMTO selection_mto selection_yr) j(base)
	
	*************************************************************************
	**************** Taxpayers in the same support **************************
	*************************************************************************

	foreach base in 2{
		foreach var in gincome ppHN_total{
			
			mat support`base'`var' = J(3,10,.)		// 3 Rows: 99, 1, intersection
			forvalues i=0/1{
				qui egen double p975`var'`i' = pctile(`var'`base') if fakeMTO==`i', p(97.5)
				qui egen double p025`var'`i' = pctile(`var'`base') if fakeMTO==`i', p(2.5)
				
				qui sum p975`var'`i'
				local p975`var'`i' = `r(mean)'
				
				qui sum p025`var'`i'
				local p025`var'`i' = `r(mean)'
				
				mat support`base'`var'[`i'+1, 1] = `p025`var'`i''
				mat support`base'`var'[`i'+1, 2] = `p975`var'`i''
				mat support`base'`var'[`i'+1, 3] = `i'
			}
			
			gen double lb`var'`base' = max(`p025`var'1',`p025`var'0')		/* Lower bound of common support */
			gen double ub`var'`base' = min(`p975`var'1',`p975`var'0')		/* Upper bound of common support */
			
			mat support`base'`var'[3, 1]  = max(`p025`var'1',`p025`var'0')
			mat support`base'`var'[3, 2]  = min(`p975`var'1',`p975`var'0')
			
			preserve
				clear
				svmat support`base'`var'
				gen var = "`var'"
				gen baseyear = 2007-`base'
				ren support`base'`var'1 p025
				ren support`base'`var'2 p975
				ren support`base'`var'3 mto
				
				keep var mto  baseyear p025 p975
				order var baseyear mto  p025 p975 
				
				tempfile s`base'`var'
				save `s`base'`var''
			restore
		}	
		
		
		drop p975* p025*
	}
	
	
	gen double comsup2 = ( gincome2 > lbgincome2 & gincome2< ubgincome2 ) & ///
							( ppHN_total2 > lbppHN_total2 & ppHN_total2 < ubppHN_total2 ) & ///
							!missing(gincome2) & !missing(ppHN_total2)
							
	local support_graphs = 1
	if `support_graphs'==1{
		
		gen double lngincome2 = ln(gincome2*10^9)
		gen double lnppHN_total2 = ln(ppHN_total2*10^9)
		gen double lntincome2 = ln(tincome2*10^9)
		
		label var lngincome2 "2005 Log gross income"
		label var lntincome2 "2005 Log taxable income"
		
		* Probability of MTO as function of gross income, taxable income, total taxes paid
		
		**** Merge in bins from main MTO probability graphs to keep same scale ***
		merge 1:1 npwp using "${output}/analysis/regcoeffs/MTO_input_variable_bins_genxq.dta", keep(3) nogen
		
		binscatter fakeMTO lngincome2, scheme(s1color) color(gs8) title("") ///
		ytitle("Probability of placebo treatment")  yscale(titlegap(*5)) ///
		xtitle("2005 Log gross income")  xq(bin_lngincome2) legend(off) linetype(none) ///
		xlabel(18(2)26) 
		graph export "${output}/analysis/graphs/ProbMTO_lngincome2005_placebo.eps", replace

		binscatter fakeMTO lnppHN_total2, scheme(s1color) color(gs8) title("") ///
		ytitle("Probability of placebo treatment")  yscale(titlegap(*5)) ///
		xtitle("2005 Log total taxes paid")  xq(bin_lnppHN_total2) legend(off) linetype(none) ///
		xlabel(10(5)25)
		graph export "${output}/analysis/graphs/ProbMTO_lnppHN_total2005_placebo.eps", replace
	
		* Drop vars that won't be used for clarity
		drop tincome* ln*
	}
	******************* Entropy balancing weights *******************
	
	* Drop selection MTO with no variation in fakeMTO (no match possible)

	* Selection MTO 
	qui tab selection_mto, gen(fe_r)
	
	
	* 2005 entropy weights		(base 2)
	cap erase balance_table2.dta
	ebalance fakeMTO gincome2  ///
					 ppHN_total2 fe_r* if comsup2==1, ///
	targets(1) generate(eweight2) 
	
	preserve
		keep npwp eweight*
		
		tempfile eweights
		sa `eweights'
	restore

	**************************************************
	****** Merge estimated scores with main file *****
	**************************************************
	
	u `mainall', clear
	merge m:1 npwp using `eweights'
	keep if _merge==1 | _merge==3
	drop _merge

	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_placebo.dta", replace	

}
clear
log close
