* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/3_3_MTO_WDD_regressions_robustness_comm_support_99_1.log", replace
di in red "Run 3_3_MTO_WDD_regressions_robustness_comm_support_99_1.do.do"

* Toggles that switch different parts of the code on and off
local addoutcomes	= 1
local analysis		= 1

global minyear 	= 2003
global maxyear 	= 2011
global baseyear = 2005
global treatyear = 2006

	************************************
	*********** Add outcomes ***********
	************************************
	
if `addoutcomes'==1{

	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_weights_comm_support_99_1.dta", clear
	
	* CIT refund
	gen double refund = -paidvalue if paidvalue <0
	replace refund = 0 if missing(refund)
	
	* No taxes paid are zero taxes paid
	misstable sum  ppH* ppN*
	foreach var of varlist ppH* ppN*{
		qui replace `var' = 0 if missing(`var')
	}
	
	*******************************************
	*********** Merge SPT 1721 data ***********
	*******************************************
	
	* IMPORTANTL Rp figures are already in IDR billion
	merge 1:1 npwp year using "${output}/analysis/SPT_1721_annual_clean_analysis.dta"
	keep if _merge==1 | _merge==3
	drop _merge
	
	* 2008 data is mostly missing, replace with missing so 2008 is never used
	foreach var of varlist num* inc*{
		replace `var'=. if year==2008
	}

	* Total employment
	gen double num_workers  	= num_perm + num_temp
	gen double wagebill			= inc_perm + inc_temp
	
	* Mean wage
	gen double wage 		= wagebill/num_workers 
	
	**************************************
	* Deflate Rp denominated #s to 2007 Rp
	**************************************
	preserve
		insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
		replace date = substr(date,1,4)
		destring date, replace
		replace date = date-1	// End of year 
		ren idngdp deflator		// end-of-2014 Rp
		ren date year
		
		* Get deflator relative to 2007 Rp
		gen double def07 = deflator if year==2007
		egen def07m = max(def07)
		drop def07
		
		gen double deflator2007 = (deflator/def07m)*100
		drop def07m
		
		// Rescale so that it's 1 in 2007
		replace deflator2007=deflator2007/100
		
		keep year deflator2007
		tempfile deflator
		sa `deflator'
	restore
	
	merge m:1 year using `deflator'
	keep if _merge==3
	drop _merge
	
	foreach var of varlist wage* inc_perm inc_temp ///
				nincome tincome gincome cgsold pphtotal citdue totcitdue paidvalue ///
				nincbus nincsidebus domcomninc forcomninc totcomninc ntaxinc  ///
				adjforcred totposadj totnegadj facilityinv comploss otherexpense ///
				ppH* ppN* refund {
				
				gen double `var'Rp07 = `var'/deflator2007
				
	}
	
	tab year inMTOby2008
	unique npwp
	unique npwp if inMTOby2008==1
	
	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes_comm_support_99_1.dta", replace
}
****************************************************************************
****************************** Regressions *********************************
****************************************************************************

if `analysis'==1{

	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes_comm_support_99_1.dta", clear
	
	* Shorten entropy weight names
	renvars eweight*, subst("eweight" "e")
	gen w01 = 1 if !missing(e2)
	
	******************************************
	********** Regression variables **********
	******************************************

	local minyear = ${minyear}
	local maxyear = ${maxyear}
	
	* Instruments year by year
	forvalues i=`minyear'/`maxyear'{
		gen double inMTOby2008_`i' = inMTOby2008*(year==`i')
		gen double y`i' = (year == `i')
	}

	* Endogenous (use variable mto : in MTO in year x)
	gen double inMTO = mto
	
	* 2007 delayed flagging of MTO - know per 2007 regulations they are in MTO
	replace inMTO = 1 if year==2007 & inMTOby2008==1 & selection_yr==2007
	
	* Ommit base year instruments and endogenous variable
	renvars inMTOby2008_${baseyear}  y${baseyear}, pref("ommit_")
	
	gen double post = (year>=${treatyear})
	gen double inMTOby2008post = inMTOby2008*post
	
	*********************************************************************************
	**************** IV regression with 1 endogenous variable, 1 instrument *********
	*********************************************************************************
	
	* Adjustment: for CIT paid calculation below, replace totcitdue as zero if missing so payments not missing
		gen double totcitdue_nRp07 = totcitdueRp07
		replace totcitdue_nRp07 = 0 if missing(totcitdue_nRp07)

		qui gen double ppH_2529_2223Rp07    	 = ppH_2529_corpRp07 + ppH_22Rp07 + ppH_22_impRp07 + ppH_23Rp07
		qui gen double ppH_CITpaidRp07		  	= min(ppH_2529_2223Rp07, max(totcitdue_nRp07,ppH_2529_corpRp07))
		qui gen double ppH_CITpaid_adjRp07		= ppH_CITpaidRp07  - refundRp07
		
		* Other income taxes
		qui gen double ppH_OTHERRp07  	 		= ppH_finalRp07 + ppH_oilgasRp07  + ppH_nonoilgasRp07 + ppH_2529_indRp07 + (ppH_2529_2223Rp07 - ppH_CITpaidRp07)
		qui gen double ppH_PAYROLLRp07 	 		= ppH_21Rp07 + ppH_26Rp07
		qui gen double ppH_PENALTIESRp07 		= ppH_interestRp07
		qui gen double ppH_notCITRp07	 		= ppH_PAYROLLRp07 + ppH_OTHERRp07 + ppH_PENALTIESRp07
		
		qui gen double ppH_total_adjRp07		= ppH_totalRp07 - refundRp07 
		qui gen double ppHN_total_adjRp07	= ppHN_totalRp07 - refundRp07 
		
	* Line-by-line regressions
	local dettotcitdueRp07  "tincomeRp07 gincomeRp07 totcitdueRp07"
	local dettaxpaidRp07	"ppH_CITpaid_adjRp07 ppH_notCITRp07 ppN_totalRp07 ppHN_total_adjRp07"
	local detemployRp07		"num_workers num_perm num_temp wagebillRp07 inc_permRp07 inc_tempRp07 wageRp07"
	
	foreach weight in w01 e2{
	foreach set in dettotcitdueRp07 dettaxpaidRp07 detemployRp07{
		foreach var of varlist ``set''{
			
				estimates clear
				if "`set'"=="detemployRp07"{
					ivreghdfe `var'  (inMTO =  	inMTOby2008post ) ///		
								  [pw=`weight'] if year!=2008, absorb(npwp  year )  savefirst saverf cluster(npwp)
				}
				else{
					ivreghdfe `var'  (inMTO =  inMTOby2008post) [pw=`weight'], absorb(npwp  year) savefirst saverf cluster(npwp)
				}
				
				********************************
				local iv_b 	= _b[inMTO]
				local iv_se	= _se[inMTO]
				
				count if e(sample)
				local allobs= r(N)
				count if e(sample) & inMTOby2008==1
				local mtoobs= r(N)
				
				mat `var'`weight' = 	(`iv_b', `iv_se', `allobs',`mtoobs')
				
				* Save coefficients
				preserve
					clear
					svmat `var'`weight'
					gen var = "`var'"
					gen set = "`set'"
					gen weight = "`weight'"
					
					ren `var'`weight'1 iv_b
					ren `var'`weight'2 iv_se
					ren `var'`weight'3 obs_all
					ren `var'`weight'4 obs_mto
					
					tempfile `var'`weight'
					sa ``var'`weight''
				restore
						
				estimates clear
			
			} /* vars boolean */	
		} /* Set boolean */
	} /* Close weight */
	
	* Appendfor all vars 
	
	preserve
		u `tincomeRp07e2', clear
		
		foreach weight in w01 e2{
			foreach x in `dettotcitdueRp07' `dettaxpaidRp07' `detemployRp07'{
				append using ``x'`weight''
			} /* x */
		} /* weight */
		
		order set var, first
		
		duplicates drop
		outsheet using "${output}/analysis/csv/MTO_DD_comm_support_99_1.csv", comma replace
	restore
		
		
} /* Close analysis */

clear
log close
