* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/3_4_MTO_WDD_regressions_robustness_add20056.log", replace
di in red "3_4_MTO_WDD_regressions_robustness_add20056.do"

* Toggles that switch different parts of the code on and off
local addoutcomes	= 1
local analysis		= 1
local graphregs		= 1

global minyear 		= 2003
global maxyear 		= 2011
global minrelyear	= -4
global maxrelyear	= 4

global baserelyear	= -2

* All weights for robustness
local  allweights "e2"
local  graphweights "e2"

* Program to store coefficients from annual regressions	
	* Local 1: variable
	
	global coeffscons = ${maxrelyear}-${minrelyear}
	
	cap program drop storeiv
	program define storeiv
		
		mat bmain 	= b[1..${coeffscons},1]
		mat semain	= se[1..${coeffscons},1]
		
		count if esample==1 & inMTObyocy1==1
		local Nmto = r(N)
		count if esample==1
		local N = r(N)
		
		unique npwp if esample==1 & inMTObyocy1==1
		local umto = r(unique)
		unique npwp if esample==1
		local uall = r(unique)
		
		mat emp = J(${coeffscons}-4,1,.)
		mat N = `Nmto' \ `N' \ `umto' \ `uall' \ emp
		matrix `1'	  	= (bmain, semain, N)
		
		matrix colnames `1' = b`1' se`1'  N`1'
		
		mat list `1'
		
		preserve
			clear
			svmat `1'
			ren `1'1 	b
			ren `1'2 	se
			ren `1'3 	N
			
			gen inMTObyocy1=1
			gen year_rel = ${minrelyear} + _n -1
			replace year_rel = year_rel+1 if year>=${baserelyear}
			
			saveold "${output}/analysis/regcoeffs/MTO_DD_`1'_reduced_add20056.dta", replace
		restore
	end
	
	************************************
	*********** Add outcomes ************
	************************************
	
if `addoutcomes'==1{
	
	u "${output}/analysis/MTO_analysisfile_stacked_${minyear}_${maxyear}_weights.dta", clear
	
	* CIT refund
	gen double refund = -paidvalue if paidvalue <0
	replace refund = 0 if missing(refund)
	
	* Payments are zero if taxpayer didn't pay
	foreach var of varlist ppH* ppN*{
		replace `var' = 0 if missing(`var')
	}

	* Because of reshaping long on year - will be missing for years you leave data
	keep if !missing(mto)
	ren year_cal year
	order npwp year year_rel selection_mto inMTOby*, first
	
	*******************************************
	*********** Merge SPT 1721 data ***********
	*******************************************
	
	* IMPORTANT Rp figures are already in billion Rp
	merge 1:1 npwp year using "${output}/analysis/SPT_1721_annual_clean_analysis.dta"
	keep if _merge==1 | _merge==3
	drop _merge
	
	* 2008 data is mostly missing, replace with missing so 2008 is never used
	foreach var of varlist num* inc*{
		replace `var'=. if year==2008
	}

	* Total employment
	gen double num_workers  	= num_perm + num_temp
	gen double wagebill			= inc_perm + inc_temp
	
	* Mean wage
	gen double wage 		= wagebill/num_workers 
	
	**************************************
	* Deflate Rp denominated #s to 2007 Rp
	**************************************
	preserve
		insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
		replace date = substr(date,1,4)
		destring date, replace
		replace date = date-1	// End of year 
		ren idngdp deflator		// end-of-2014 Rp
		ren date year
		
		* Get deflator relative to 2007 Rp
		gen double def07 = deflator if year==2007
		egen def07m = max(def07)
		drop def07
		
		gen double deflator2007 = (deflator/def07m)*100
		drop def07m
		
		// Rescale so that it's 1 in 2007
		replace deflator2007=deflator2007/100
		
		keep year deflator2007
		tempfile deflator
		sa `deflator'
	restore
	
	merge m:1 year using `deflator'
	keep if _merge==3
	drop _merge
	
	foreach var of varlist wage* inc_perm inc_temp ///
				nincome tincome gincome cgsold pphtotal citdue totcitdue paidvalue  ///
				nincbus nincsidebus domcomninc forcomninc totcomninc ntaxinc  ///
				adjforcred totposadj totnegadj facilityinv comploss otherexpense ///
				ppH* ppN* refund {
				
				gen double `var'Rp07 = `var'/deflator2007
				
	}
	
	tab year inMTObyocy1
	unique npwp
	unique npwp if inMTObyocy1==1
	
	saveold "${output}/analysis/MTO_analysisfile_stacked_${minyear}_${maxyear}_addoutcomes.dta", replace
}
****************************************************************************
****************************** Regressions *********************************
****************************************************************************

if `analysis'==1{

	u "${output}/analysis/MTO_analysisfile_stacked_${minyear}_${maxyear}_addoutcomes.dta", clear
	
	* Shorten entropy weight names
	renvars eweight*, subst("eweight" "e")
	gen w0 = 1
	
	******************************************
	********** Regression variables **********
	******************************************

	local minrelyear 	= ${minrelyear}
	local maxrelyear	= ${maxrelyear}
	
	* Instruments relative year by relative year
	forvalues i=0/`maxrelyear'{
		gen double inMTObyocy1_o`i' = inMTObyocy1*(year_rel==`i')
		gen double y_o`i'=(year_rel==`i')
	}
	
	local min = -`minrelyear'
	forvalues j=1/`min'{
		gen double inMTObyocy1_b`j' = inMTObyocy1*(year_rel==-`j')
		gen double y_b`j'=(year_rel==-`j')
	}

	* Endogenous (use variable mto : in MTO in year x)
	gen double inMTO = mto
	
	* Delayed flagging of MTO for 2007 selection year - know from regulations they shoudl be flagged
	replace inMTO = 1 if year_rel==0 & inMTObyocy1==1 
	
	* Year by year endogenous variable
	forvalues i=0/`maxrelyear'{
		gen double end_inMTO_o`i' = (year_rel==`i' & inMTO==1) if !missing(inMTO)
	}
	local min = -`minrelyear'
	forvalues j=1/`min'{
		gen end_inMTO_b`j' = (year_rel==-`j' & inMTO==1) if !missing(inMTO)
	}
	
	* Ommit base year instruments and endogenous variable
	renvars inMTObyocy1_b2 end_inMTO_b2  y_b2, pref("ommit_")
	
	gen double post = (year_rel>=0)
	gen double inMTObyocy1post = inMTObyocy1*post
	
	*********************************************************************************
	**************** IV regression with 1 endogenous variable, 1 instrument *********
	*********************************************************************************

	local ivregs_1endog = 1
	
	if `ivregs_1endog'==1{
		
		* Adjustment: for CIT paid calculation below, replace totcitdue as zero if missing so payments not missing
		gen double totcitdue_nRp07 = totcitdueRp07
		replace totcitdue_nRp07 = 0 if missing(totcitdue_nRp07)

		qui gen double ppH_2529_2223Rp07    	 = ppH_2529_corpRp07 + ppH_22Rp07 + ppH_22_impRp07 + ppH_23Rp07
		qui gen double ppH_CITpaidRp07		  	= min(ppH_2529_2223Rp07, max(totcitdue_nRp07,ppH_2529_corpRp07))
		qui gen double ppH_CITpaid_adjRp07		= ppH_CITpaidRp07  - refundRp07
		
		* Other income taxes
		qui gen double ppH_OTHERRp07  	 		= ppH_finalRp07 + ppH_oilgasRp07  + ppH_nonoilgasRp07 + ppH_2529_indRp07 + (ppH_2529_2223Rp07 - ppH_CITpaidRp07)
		qui gen double ppH_PAYROLLRp07 	 		= ppH_21Rp07 + ppH_26Rp07
		qui gen double ppH_PENALTIESRp07 		= ppH_interestRp07
		qui gen double ppH_notCITRp07	 		= ppH_PAYROLLRp07 + ppH_OTHERRp07 + ppH_PENALTIESRp07
		
		qui gen double ppH_total_adjRp07		= ppH_totalRp07 - refundRp07 
		qui gen double ppHN_total_adjRp07	= ppHN_totalRp07 - refundRp07 
		
		* Line-by-line regressions
		local dettotcitdueRp07  "tincomeRp07 gincomeRp07 totcitdueRp07"
		local dettaxpaidRp07	"ppH_CITpaid_adjRp07 ppH_notCITRp07 ppN_totalRp07 ppHN_total_adjRp07"
		local detemployRp07		"num_workers num_perm num_temp wagebillRp07 inc_permRp07 inc_tempRp07 wageRp07"
		
		foreach set in dettotcitdueRp07 dettaxpaidRp07 detemployRp07{
			foreach var of varlist ``set''{
					
					estimates clear
					if "`set'"=="detemploy" | "`set'"=="detemployRp07"{
						ivreghdfe `var'  (inMTO =  	inMTObyocy1post ) ///		
									  [pw=e2] if year!=2008, absorb(npwp  year_rel)  cluster(npwp)
					}
					else{
						ivreghdfe `var'  (inMTO =  inMTObyocy1post) [pw=e2], absorb(npwp   year_rel) cluster(npwp)
					}
					
					count if e(sample)
					local allobs= r(N)
					count if e(sample) & inMTObyocy1==1
					local mtoobs= r(N)
					
					********************************
					local iv_b 	= _b[inMTO]
					local iv_se	= _se[inMTO]
							
					mat `var'e2 = 	(`iv_b', `iv_se', `allobs',`mtoobs')
					
					* Save coefficients
					preserve
						clear
						svmat `var'e2
						gen var = "`var'"
						gen set = "`set'"
						gen weight = "e2"
						
						ren `var'e21 iv_b
						ren `var'e22 iv_se
						ren `var'e23 obs_all
						ren `var'e24 obs_mto
						
						tempfile `var'e2
						sa ``var'e2'
					restore
							
					estimates clear
				
				} /* vars boolean */	
			} /* Set boolean */
		
				* Appendfor all vars 
		
		preserve
			u `tincomeRp07e2', clear
		
			foreach x in `dettotcitdueRp07' `dettaxpaidRp07' `detemployRp07'{
				append using ``x'e2'
			} /* x */
			
			order set var, first
			
			duplicates drop
			outsheet using "${output}/analysis/csv/MTO_DD_add20056.csv", comma replace
		restore
			
	} /* close ivregs_1endog */
	
	*********************************************************
	******* IV regression multi instrument for graphs *******
	*********************************************************
	
	local ss_plots = 1
	if `ss_plots'==1{
	
		************ RF and IV  ************
					
		foreach var of varlist gincomeRp07 ppHN_total_adjRp07 {
				
			areg `var' 	inMTObyocy1_b4 		inMTObyocy1_b3 ///
						inMTObyocy1_b1 		inMTObyocy1_o0 ///
						inMTObyocy1_o1  	inMTObyocy1_o2 ///
						inMTObyocy1_o3    	inMTObyocy1_o4  ///
						[pw=e2], absorb(npwp)  vce(cluster npwp)
			
			gen double esample = e(sample)
			
			* Reduced form
			cap mat drop b
			cap mat drop se
			mat b 	= e(b)'		
			mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
			storeiv `var'

			estimates clear
			
			drop esample
				
		}	/* var*/
	} /* Close second stage plots boolean */
	
} /* Close analysis */

	*****************************************
	************* 3. Plot graphs ************
	*****************************************
	
if `graphregs'==1{

	* Reported values
	local gincomeRp07 				"Gross income (2007 IDR billion)"
	local ppHN_total_adjRp07 			"VAT + Income tax payments (2007 IDR billion)"

		foreach x in ppHN_total_adjRp07  gincomeRp07 {

			u "${output}/analysis/regcoeffs/MTO_DD_`x'_reduced_add20056.dta", clear
			keep if inrange(year_rel,${minrelyear},${maxrelyear})

			gen n = _n
			
			sort year_rel
			expand 2 in 1
			
			replace year_rel=${baserelyear} if _n==1
			
			foreach var of varlist b se{
				replace `var'=0 if year_rel==${baserelyear}
			}
			
			gen double lb = b-1.96*se
			gen double ub = b+1.96*se

			sort year
			twoway  (rarea lb ub year, sort lwidth(none) color(gs8%30)) ///
					(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)), ///
			scheme(s1mono)  yline(0, lpattern(dash) lcolor(gs10)) ///
			xtitle("Tax Year Relative to Treatment") ///
			ytitle("``x''", size(medium)) yscale(titlegap(*5)) xlabel(${minrelyear}(1)${maxrelyear}) legend(off) 
			graph export "${output}/analysis/graphs/MTO_DD_`x'_reduced_add20056.pdf", replace
		
	  } /* Close var loop */

} /* Close graph boolean */
clear
log close
