* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/3_6_MTO_WDD_regressions_robustness_placebo.log", replace
di in red "Run 3_6_MTO_WDD_regressions_robustness_placebo.do"

* Toggles that switch different parts of the code on and off	
local analysis			= 1
local graphs			= 1

global minyear 	= 2003
global maxyear 	= 2011
global baseyear = 2005
global treatyear = 2006

* All weights for robustness
local  allweights "e2"
local  graphweights "e2"

* Program to store coefficients from annual regressions	
	* Local 1: variable
	
	global coeffscons = ${maxyear}-${minyear}
	
	cap program drop storeiv
	program define storeiv
		
		mat bmain 	= b[1..${coeffscons},1]
		mat semain	= se[1..${coeffscons},1]
		
		count if esample==1 & fakeMTO==1
		local Nmto = r(N)
		count if esample==1
		local N = r(N)
		
		unique npwp if esample==1 & fakeMTO==1
		local umto = r(unique)
		unique npwp if esample==1
		local uall = r(unique)
		
		mat emp = J(${coeffscons}-4,1,.)
		mat N = `Nmto' \ `N' \ `umto' \ `uall' \ emp
		matrix `1' 	  	= (bmain, semain, N)
		
		matrix colnames `1' = b`1' se`1'  N`1'
		
		mat list `1'
		
		preserve
			clear
			svmat `1'
			ren `1'1 	b
			ren `1'2 	se
			ren `1'3 	N
			
			gen fakeMTO=1
			gen year = ${minyear} + _n -1
			replace year = year+1 if year>=${baseyear}
			
			saveold "${output}/analysis/regcoeffs/MTO_DD_`1'_reduced_placebo.dta", replace
		restore
	end
	
****************** Analysis ******************

if `analysis'==1{

	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_placebo.dta", clear
	
	* CIT refund
	gen double refund = -paidvalue if paidvalue <0
	replace refund = 0 if missing(refund)
	
	* No taxes paid are zero taxes paid
	misstable sum  ppH* ppN*
	foreach var of varlist ppH* ppN*{
		qui replace `var' = 0 if missing(`var')
	}
	
	**************************************
	* Deflate Rp denominated #s to 2007 Rp
	**************************************
	preserve
		insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
		replace date = substr(date,1,4)
		destring date, replace
		replace date = date-1	// End of year 
		ren idngdp deflator		// end-of-2014 Rp
		ren date year
		
		* Get deflator relative to 2007 Rp
		gen double def07 = deflator if year==2007
		egen def07m = max(def07)
		drop def07
		
		gen double deflator2007 = (deflator/def07m)*100
		drop def07m
		
		// Rescale so that it's 1 in 2007
		replace deflator2007=deflator2007/100
		
		keep year deflator2007
		tempfile deflator
		sa `deflator'
	restore
	
	merge m:1 year using `deflator'
	keep if _merge==3
	drop _merge
	
	foreach var of varlist ///
				nincome tincome gincome cgsold pphtotal citdue totcitdue  ///
				nincbus nincsidebus domcomninc forcomninc totcomninc ntaxinc  ///
				adjforcred totposadj totnegadj facilityinv comploss otherexpense ///
				ppH* ppN* refund {
				
				gen double `var'Rp07 = `var'/deflator2007
				
	}
	
	* Shorten entropy weight names
	renvars eweight*, subst("eweight" "e")
	gen w0 = 1
	
	******************************************
	********** Regression variables **********
	******************************************

	local minyear = ${minyear}
	local maxyear = ${maxyear}
	
	* Instruments year by year
	forvalues i=`minyear'/`maxyear'{
		gen double fakeMTO_`i' = fakeMTO*(year==`i')
		gen double y`i' = (year == `i')
	}

	* Endogenous (use variable mto : in MTO in year x)
	gen double inMTO = mto
	
	* 2007 delayed flagging of MTO - know per 2007 regulations they are in MTO
	replace inMTO = 1 if year==2007 & fakeMTO==1 & selection_yr==2007
	
	* Year by year endogenous variable
	forvalues y=`minyear'/`maxyear'{
		gen double end_inMTO`y' = (year==`y' & inMTO==1) if !missing(inMTO)
	}
	
	* Ommit base year instruments and endogenous variable
	renvars fakeMTO_${baseyear} end_inMTO${baseyear}  y${baseyear}, pref("ommit_")
		
	gen double post = (year>=${treatyear})
	gen double fakeMTOpost = fakeMTO*post
	
		* Regression for key graph
		qui gen double ppHN_total_adjRp07	= ppHN_totalRp07 - refundRp07
		
		areg ppHN_total_adjRp07  fakeMTO_2003 	fakeMTO_2004 ///
								fakeMTO_2006 	fakeMTO_2007 ///
								fakeMTO_2008  	fakeMTO_2009 ///
								fakeMTO_2010    fakeMTO_2011 y20*  ///
					[pw=e2], absorb(npwp)  `clustoption'
			
		gen esample = e(sample)
		
		* Reduced form
		cap mat drop b
		cap mat drop se
		mat b 	= e(b)'		
		mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
		storeiv ppHN_total_adjRp07
		drop esample
	
		estimates clear

}
	*****************************************
	************* 3. Plot graphs ************
	*****************************************
	
if `graphs'==1{

	* Get actual MTO effects to plot in background so that ranges are the same as in real MTO effects
	preserve
		u "${output}/analysis/regcoeffs/MTO_DD_ppHN_total_adjRp07_reduced.dta", clear
			gen n = _n
			sort year
			expand 2 in 1		
			replace year=${baseyear} if _n==1			
			foreach var of varlist b se{
				replace `var'=0 if year==${baseyear}
			}
			
			gen double lb_mto = b-1.96*se
			gen double ub_mto = b+1.96*se
			
			ren b b_mto
			tempfile realmto
			sa `realmto'
	restore
	u "${output}/analysis/regcoeffs/MTO_DD_ppHN_total_adjRp07_reduced_placebo.dta", clear
	
	gen n = _n
	
	sort year
	expand 2 in 1
	
	replace year=${baseyear} if _n==1
	
	foreach var of varlist b se{
		replace `var'=0 if year==${baseyear}
	}
	
	gen double lb = b-1.96*se
	gen double ub = b+1.96*se
	
	sum year
	local minyear = `r(min)'
	local maxyear = `r(max)'
	
	sort year
	
	merge 1:1 year using `realmto', nogen
	
	twoway  (rarea lb ub year, sort lwidth(none) color(gs8%30)) ///
			(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)) ///
			(connected lb_mto ub_mto year, color(none none) msize(tiny tiny) ), ///
	scheme(s1mono) yline(0, lpattern(dash) lcolor(gs10)) ///
	ytitle("VAT + Income tax payments (2007 IDR billion)", size(medium)) yscale(titlegap(*5)) ///
	xtitle("Tax Year")  xlabel(`minyear'(1)`maxyear') legend(off) 
	
	graph export "${output}/analysis/graphs/MTO_DD_ppHN_total_adjRp07_reduced_placebo.pdf", replace
		
} /* Close graph boolean */
clear
log close
