* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/3_7_MTO_WDD_regressions_robustness_large_small_PTOs.log", replace
di in red "Run 3_7_MTO_WDD_regressions_robustness_large_small_PTOs.do"

global minyear 	= 2003
global maxyear 	= 2011
global baseyear = 2005

u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear

* Shorten entropy weight names
renvars eweight*, subst("eweight" "e")

* Draft revision request - Large vs smal PTO firms
sum gincomeRp07 if inMTOby2008==0 & year==${baseyear}, detail
gen temp = (gincomeRp07 > `r(p50)' & year==${baseyear})
bys npwp: egen largePTO = max(temp)
drop temp

* Name too long, just replace
qui replace ppHN_totalRp07		= ppHN_totalRp07  - refundRp07

foreach var of varlist ppHN_totalRp07 {
	gen double `var'_largePTO = `var'  if largePTO==1
	gen double `var'_smallPTO = `var'  if largePTO==0
}

********************
** Averages graph **
********************

collapse (mean) ppHN_totalRp07 *largePTO *smallPTO [pw=e2], by(year inMTOby2008)

twoway (connect ppHN_totalRp07 year if inMTOby2008==1) ///
	   (connect ppHN_totalRp07_largePTO year if inMTOby2008==0) ///
	   (connect ppHN_totalRp07_smallPTO year if inMTOby2008==0), ///
scheme(s1mono)  ///
legend(		label(1 "In first MTO cohort") ///
			label(2 "Not in first MTO cohort (50% largest firms)") ///
			label(3 "Not in first MTO cohort (50% smallest firms)") ///
		cols(1) ) ///
ytitle("VAT + Income tax payments (2007 IDR billion)", size(small)) yscale(titlegap(*5)) ///
xlabel(${minyear}(1)${maxyear}) 
graph export "${output}/analysis/graphs/ppHN_totalRp07_e2_averages_large_small_PTOs.eps", replace

clear
log close
