* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/3_9_MTO_WDD_regressions_robustness_by_baseline_size.log", replace
di in red "Run 3_9_MTO_WDD_regressions_robustness_by_baseline_size.do"

global minyear 	= 2003
global maxyear 	= 2011
global baseyear = 2005
global treatyear = 2006


u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear

* Shorten entropy weight names
renvars eweight*, subst("eweight" "e")
gen w0 = 1

******************************************
********** Regression variables **********
******************************************

local minyear = ${minyear}
local maxyear = ${maxyear}

* Instruments year by year
forvalues i=`minyear'/`maxyear'{
	gen double inMTOby2008_`i' = inMTOby2008*(year==`i')
	gen double y`i' = (year == `i')
}

* Endogenous (use variable mto : in MTO in year x)
gen double inMTO = mto

* 2007 delayed flagging of MTO - know per 2007 regulations they are in MTO
replace inMTO = 1 if year==2007 & inMTOby2008==1 & selection_yr==2007

* Ommit base year instruments and endogenous variable
renvars inMTOby2008_${baseyear}   y${baseyear}, pref("ommit_")

gen double post = (year>=${treatyear})
gen double inMTOby2008post = inMTOby2008*post

/* Regression including interaction on firm baseline size:
	Firm size:
		gross income
		taxable income
*/

foreach var of varlist gincomeRp07 tincomeRp07{
	gen double temp = `var' if year==${baseyear}
	bys npwp: egen `var'_base = max(temp)
	drop temp
	
	gen double `var'_int = `var'_base*inMTOby2008post
}

/********* There doesn't actuall seem to be much heterogeneity in MTO effect by firm size *********/

* Key outcome
gen double ppHN_total_adjRp07 = ppHN_totalRp07  - refundRp07

foreach basevar in gincomeRp07 tincomeRp07{		
	areg ppHN_total_adjRp07  inMTOby2008post `basevar'_int i.year [pw=e2] , absorb(npwp) vce(cluster npwp)
	
	count if e(sample)
	local N = `r(N)'
	
	preserve
		clear
		set obs 1
		gen sizevar = "`basevar'"
		gen weight	= "e2"
		gen double b_inMTOby2008post		= _b[inMTOby2008post]
		gen double se_inMTOby2008post		= _se[inMTOby2008post]
		gen double b_intsize				= _b[`basevar'_int]
		gen double se_intsize				= _se[`basevar'_int]
		gen double N						=`N'
		
		tempfile f`basevar'
		sa `f`basevar''
	restore
}
			
* Append all
clear
u `fgincomeRp07', clear
append using `ftincomeRp07'

outsheet using "${output}/analysis/csv/MTO_DD_pooled_by_basesize.csv", comma replace
clear
log close
