* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/4_1_Probability_of_assessment.log", replace
di in red "do 4_1_Probability_of_assessment.do"

global minyear = 2003
global maxyear = 2011

global minyear 		= 2003
global maxyear 		= 2011
global treatyear	= 2006


u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear

gen double evermto 	= inMTOby2008
gen double MTOpost	=inMTOby2008*(year>=${treatyear}) 

************* Regressions for slope change **********************
foreach var of varlist   ppHN_total num_workers num_perm{
	
	gen double `var'MTO 		= inMTOby2008*`var'
	gen double `var'MTOpost 	= `var'MTO*(year>=${treatyear})
	
	gen double ln`var'			= ln(`var')
	gen double ln`var'MTO 		= inMTOby2008*ln(`var')
	gen double ln`var'MTOpost 	= ln`var'MTO*(year>=${treatyear})
	
	*** Log specifications ***
		areg assessment_STP ln`var' ln`var'MTO ln`var'MTOpost MTOpost i.year [pw=eweight2], ///
							absorb(npwp) vce(cluster npwp)
		
		cap mat drop b
		cap mat drop se
		mat b 	= e(b)'
		mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
		
		mat STPln`var'b 		= b[1..4,1]
		mat STPln`var'se		= se[1..4,1]
		
		* Count observations
		unique npwp if !missing(assessment_STP) & !missing(ln`var') & !missing(ln`var'MTO) & !missing(eweight2)
		local allobs = `r(N)'
		local IDs = `r(unique)'
		
		unique npwp if !missing(assessment_STP) & !missing(ln`var') & !missing(ln`var'MTO) & !missing(eweight2) & inMTOby2008==1
		local mtoobs = `r(N)'
		local IDs_mto = `r(unique)'
		
		mat STPln`var'obs = [`allobs',`mtoobs',`IDs',`IDs_mto']
		
		areg assessment_SKPKB ln`var' ln`var'MTO ln`var'MTOpost MTOpost i.year [pw=eweight2], ///
							absorb(npwp) vce(cluster npwp)
		
		mat b 	= e(b)'
		mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
							
		mat SKPKBln`var'b 		= b[1..4,1]
		mat SKPKBln`var'se		= se[1..4,1]
		
		* Count observations
		unique npwp if !missing(assessment_SKPKB) & !missing(ln`var') & !missing(ln`var'MTO) & !missing(eweight2)
		local allobs = `r(N)'
		local IDs = `r(unique)'
		
		unique npwp if !missing(assessment_SKPKB) & !missing(ln`var') & !missing(ln`var'MTO) & !missing(eweight2) & inMTOby2008==1
		local mtoobs = `r(N)'
		local IDs_mto = `r(unique)'
		
		mat SKPKBln`var'obs = [`allobs',`mtoobs',`IDs',`IDs_mto']
		
		drop `var'MTO `var'MTOpost ln`var'MTO ln`var'MTOpost
						
} /* Close regressions */

** Compile coefficients ****
preserve
	
	foreach out in STP SKPKB{
		foreach var in  lnppHN_total lnnum_workers lnnum_perm {
			
			clear
			svmat `out'`var'b
			ren `out'`var'b1	b
			gen sizevar 	= ""
			replace sizevar = "`var'" if _n==1
			replace sizevar = "`var'MTO" if _n==2
			replace sizevar = "`var'MTOpost" if _n==3
			replace sizevar = "MTOpost_`var'reg" if _n==4
			gen outcome		= "assessment_`out'"
			
			svmat `out'`var'se
			ren `out'`var'se1 se
			
			svmat `out'`var'obs
			ren `out'`var'obs1 N
			ren `out'`var'obs2 N_mto
			ren `out'`var'obs3 IDs
			ren `out'`var'obs4 IDs_mto
			
			gen spec = "`out'`var'"
			
			tempfile f`out'`var'
			sa `f`out'`var''
						
		}
	}
	
	u `fSTPlnppHN_total', clear
	foreach out in STP SKPKB{
		foreach var in  lnppHN_total lnnum_workers lnnum_perm {
			append using `f`out'`var''			
		}
	}
	
	duplicates drop
	
	order spec outcome sizevar b se
	sort spec outcome sizevar
	outsheet using "${output}/analysis/csv/assessment_slope_change.csv", comma replace
restore

************* Quantifying slope in Figure 5 **********************

foreach var in   lnppHN_total lnnum_workers lnnum_perm {
	
	gen double `var'MTO = `var'*inMTOby2008

	foreach out in STP SKPKB{
		
		reg assessment_`out' `var' `var'MTO inMTOby2008 i.year if year>=${treatyear} [pw=eweight2]
		
		mat b 	= e(b)'
		mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
		
		mat `out'fig5`var'b 		= b[1..3,1]
		mat `out'fig5`var'se		= se[1..3,1]
		
		* Count observations
		unique npwp if !missing(assessment_`out') & !missing(`var') & !missing(`var'MTO) & !missing(eweight2) & year>=${treatyear}
		local allobs = `r(N)'
		local IDs = `r(unique)'
		
		unique npwp if !missing(assessment_`out') & !missing(`var') & !missing(`var'MTO) & !missing(eweight2) & inMTOby2008==1 & year>=${treatyear}
		local mtoobs = `r(N)'
		local IDs_mto = `r(unique)'
		
		mat `out'fig5`var'obs = [`allobs',`mtoobs',`IDs',`IDs_mto']
		
		test `var'=`var'MTO
		local pval`out'`var' = `r(p)'
		
	}
}

preserve
	foreach var in  lnppHN_total lnnum_workers lnnum_perm {
					
			foreach out in STP SKPKB{

					clear
					svmat `out'fig5`var'b
					ren `out'fig5`var'b1 b
					svmat `out'fig5`var'se
					ren `out'fig5`var'se1 se
					
					svmat `out'fig5`var'obs
					ren `out'fig5`var'obs1 N
					ren `out'fig5`var'obs2 N_mto
					ren `out'fig5`var'obs3 IDs
					ren `out'fig5`var'obs4 IDs_mto
					
					gen pval = `pval`out'`var''
					gen regressor = ""
					replace regressor = "`var'" if _n==1
					replace regressor = "`var'MTO" if _n==2
					replace regressor = "MTO_`var'reg" if _n==3
					gen outcome = "assessment_`out'"
					
					gen specvar = "`var'"
					
					tempfile f`out'fig5`var'
					sa `f`out'fig5`var''
			}
	}
	
	u `fSTPfig5lnppHN_total', clear
	foreach var in  lnppHN_total lnnum_workers lnnum_perm {		
			foreach out in STP SKPKB{
					append using `f`out'fig5`var''
			}
			
	}
	
	duplicates drop
	order outcome specvar regressor 
	sort outcome specvar regressor
	
	outsheet using "${output}/analysis/csv/assessment_size_post2006_reg.csv", comma replace
restore

************************* P(assessment letter | stuff ) *************************

cap drop lnppHN_total lnnum_perm
gen double lnppHN_total 	= ln(ppHN_total*10^9)
gen double lnnum_perm		= ln(num_perm)

local titleassessment_STP		"VAT tax collection letter"
local titleassessment_SKPKB		"VAT underpayment letter"

gen double post = (year >= ${treatyear})

ren eweight2 				e2

sum lnnum_perm [w=e2], detail
local labmaxlnnum_perm = int(`r(max)')+0.01

sum lnppHN_total [w=e2], detail
local labmaxlnppHN_total = int(`r(p99)') + 2
local labminlnppHN_total = int(`r(p1)')  - 2

local assessment_STPr 	"ylabel(0.1(0.05)0.35)"
local assessment_SKPKBr "ylabel(0.05(0.05)0.2)"


foreach lhs in assessment_STP assessment_SKPKB{

	****** Log permanent workers ******
	twoway  (lpolyci `lhs' lnnum_perm [aw=e2] ///
					if evermto==1 & post==1  & lnnum_perm<=`labmaxlnnum_perm', ///
					clcolor(blue) acolor(gs5%20) alwidth(none) bwidth(2)  ) ///
			(lpolyci `lhs' lnnum_perm [aw=e2] ///
					if evermto==0 & post==1  & lnnum_perm<=`labmaxlnnum_perm', ///
					clcolor(red) acolor(gs10%20) alwidth(none) bwidth(2) ), ///
			scheme(s1color) xlabel(0(2)`labmaxlnnum_perm')   ///
			title("") ///
			ytitle("Probability of `title`lhs''")  yscale(titlegap(*5)) ``lhs'r' ///
			xtitle("Log(Permanent Workers)") /// 
			legend(order(2 4) label(2 "MTO") ///
			label(4 "Not MTO")) 
	graph export "${output}/analysis/graphs/lpoly_`lhs'_lnnum_perm.pdf", replace

	
	****** Log total taxes paid ******
	twoway  (lpolyci `lhs' lnppHN_total [aw=e2] ///
					if evermto==1 & post==1  & lnppHN_total<`labmaxlnppHN_total' & lnppHN_total> `labminlnppHN_total', ///
					clcolor(blue) acolor(gs5%20) alwidth(none) bwidth(2)  ) ///
			(lpolyci `lhs' lnppHN_total [aw=e2] ///
					if evermto==0 & post==1  & lnppHN_total<`labmaxlnppHN_total' & lnppHN_total> `labminlnppHN_total', ///
					clcolor(red) acolor(gs10%20) alwidth(none) bwidth(2) ), ///
			scheme(s1color)  xlabel(`labminlnppHN_total'(2)`labmaxlnppHN_total') ///
			title("") ///
			ytitle("Probability of `title`lhs''")  yscale(titlegap(*5)) ``lhs'r' ///
			xtitle("Log(Total Taxes Paid)") /// 
			legend(order(2 4) label(2 "MTO") ///
			label(4 "Not MTO")) 
	graph export "${output}/analysis/graphs/lpoly_`lhs'_lnppHN_total.pdf", replace
		
} /* LHS */
	
clear
log close
