* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/4_2_Probability_of_audit.log", replace
di in red "do 4_2_Probability_of_audit.do"

global minyear 		= 2003
global maxyear 		= 2011


u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear

gen double evermto = inMTOby2008

************* Quantifying slope in Figure 5 **********************

foreach var of varlist ppHN_total num_workers num_perm{
	gen double ln`var'			= ln(`var')
}

foreach var in  lnppHN_total lnnum_workers lnnum_perm {
	
	gen double `var'MTO = `var'*inMTOby2008

	foreach out in audited{
		
		reg `out' `var' `var'MTO inMTOby2008 i.year if year>=2009 [pw=eweight2]
		
		mat b 	= e(b)'
		mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
		
		mat `out'fig5`var'b 		= b[1..3,1]
		mat `out'fig5`var'se		= se[1..3,1]
		
		* Count observations
		unique npwp if !missing(`out') & !missing(`var') & !missing(`var'MTO) & !missing(eweight2) & year>=2009
		local allobs = `r(N)'
		local IDs = `r(unique)'
		
		unique npwp if !missing(`out') & !missing(`var') & !missing(`var'MTO) & !missing(eweight2) & inMTOby2008==1 & year>=2009
		local mtoobs = `r(N)'
		local IDs_mto = `r(unique)'
		
		mat `out'fig5`var'obs = [`allobs',`mtoobs',`IDs',`IDs_mto']
		
		test `var'=`var'MTO
		local pval`out'`var' = `r(p)'
		
	}
}

preserve
	
	foreach var in  lnppHN_total lnnum_workers lnnum_perm {
					
			foreach out in audited{

					clear
					svmat `out'fig5`var'b
					ren `out'fig5`var'b1 b
					svmat `out'fig5`var'se
					ren `out'fig5`var'se1 se
					
					svmat `out'fig5`var'obs
					ren `out'fig5`var'obs1 N
					ren `out'fig5`var'obs2 N_mto
					ren `out'fig5`var'obs3 IDs
					ren `out'fig5`var'obs4 IDs_mto
					
					gen pval = `pval`out'`var''
					gen regressor = ""
					replace regressor = "`var'" if _n==1
					replace regressor = "`var'MTO" if _n==2
					replace regressor = "MTO_`var'reg" if _n==3
					gen outcome = "`out'"
					
					gen specvar= "`var'"
					
					tempfile f`out'fig5`var'
					sa `f`out'fig5`var''
			}
	}
	
	u `fauditedfig5lnppHN_total', clear
	foreach var in  lnppHN_total lnnum_workers lnnum_perm {		
			foreach out in audited{
					append using `f`out'fig5`var''
			}
			
	}
	
	duplicates drop
	order outcome specvar regressor 
	sort outcome specvar regressor
	
	outsheet using "${output}/analysis/csv/audited_size_post2009_reg.csv", comma replace
restore

************************* P(audit | stuff ) *************************
gen post2009 = (cond(!missing(gincome),year>=2009,.))

bys npwp: egen haspost = max(post2009)
keep if haspost==1

cap drop lnppHN_total lnnum_perm
gen double lnppHN_total 	= ln(ppHN_total*10^9)
gen double lnnum_perm		= ln(num_perm)

ren eweight2 				e2

sum lnnum_perm [w=e2], detail
local labmaxlnnum_perm = int(`r(max)')+0.01

sum lnppHN_total [w=e2], detail
local labmaxlnppHN_total = int(`r(p99)') + 2
local labminlnppHN_total = int(`r(p1)')  - 2

****** Log permanent workers ******
twoway  (lpolyci audited lnnum_perm [aw=e2] ///
					if evermto==1   & lnnum_perm<`labmaxlnnum_perm', ///
					clcolor(blue) acolor(gs5%20) alwidth(none) bwidth(2)  ) ///
		(lpolyci audited lnnum_perm [aw=e2] ///
				if evermto==0   & lnnum_perm<`labmaxlnnum_perm', ///
				clcolor(red) acolor(gs10%20) alwidth(none) bwidth(2) ), ///
		scheme(s1color) xlabel(0(2)`labmaxlnnum_perm') ///
		title("") ///
		ytitle("Probability of audit")  yscale(titlegap(*5)) ///
		xtitle("Log(Permanent Workers)") /// 
		legend(order(2 4) label(2 "MTO") ///
		label(4 "Non-MTO")) 
		
	graph export "${output}/analysis/graphs/lpoly_audited_lnnum_perm.pdf", replace


****** Log Total taxes paid ******

twoway  (lpolyci audited lnppHN_total [aw=e2] ///
					if evermto==1   & lnppHN_total<`labmaxlnppHN_total' & lnppHN_total> `labminlnppHN_total', ///
					clcolor(blue) acolor(gs5%20) alwidth(none) bwidth(4)  ) ///
		(lpolyci audited lnppHN_total [aw=e2] ///
				if evermto==0   & lnppHN_total<`labmaxlnppHN_total' & lnppHN_total> `labminlnppHN_total', ///
				clcolor(red) acolor(gs10%20) alwidth(none) bwidth(4) ), ///
		scheme(s1color)  xlabel(`labminlnppHN_total'(2)`labmaxlnppHN_total') ///
		title("") ///
		ytitle("Probability of audit")  yscale(titlegap(*5)) ///
		xtitle("Log(Total Taxes Paid)") /// 
		legend(order(2 4) label(2 "MTO") ///
		label(4 "Non-MTO")) 
graph export "${output}/analysis/graphs/lpoly_audited_lnppHN_total.pdf", replace

	
clear
log close
