* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/6_1_Stats_for_counterfactual.log", replace
di in red "do 6_1_Stats_for_counterfactual.do"

global minyear = 2003
global maxyear = 2011

* Count matrix for whole sample
matrix counts 	= J(10,3,.)
matrix zm		= J(10,3,.)
matrix N		= J(10,3,.)

* Count matrix for analysis sample
matrix sample_stats = J(1,9,.)

local get06tincome		= 1
local alltaxpayers 		= 1
local analysis_sample	= 1		/* This is the output that will be used in the counterfactual exercise */

**********************************
******* Counting program *********
**********************************

* Local `1': matrix row

cap program drop store
program define store

	* Counts
	unique npwp
	mat counts[`1',1] = `r(unique)'
	
	unique npwp if evermto_upto11  ==1
	mat counts[`1',2] = `r(unique)'
	
	unique npwp if evermto_upto13  ==1
	mat counts[`1',3] = `r(unique)'
	
	* Average 2006 taxable income
	preserve
		keep npwp tincome evermto*
		keep if tincome>=0.1 & !missing(tincome)
		duplicates drop
		
		sum tincome
		mat zm[`1',1] = `r(mean)'
		
		sum tincome if evermto_upto11  ==1
		mat zm[`1',2] = `r(mean)'
		
		sum tincome if evermto_upto13  ==1
		mat zm[`1',3] = `r(mean)'
	restore
	
	* Count N above 0.1 2006 taxable income
	preserve
		keep npwp tincome evermto*
		keep if tincome>=0.1 & !missing(tincome)
		duplicates drop
	
		unique npwp
		mat N[`1',1] = `r(unique)'
		
		unique npwp if evermto_upto11  ==1
		mat N[`1',2] = `r(unique)'
		
		unique npwp if evermto_upto13  ==1
		mat N[`1',3] = `r(unique)'
	restore
end


***************************************************************
** 1. Get 2006 taxable income distribution for all taxpayers **
***************************************************************

if `get06tincome'==1{

	u "${output}/analysis/SPT_1771_clean.dta", clear
	keep npwp tax_yr kpp filing_dt correction system_dt a2pkp 
	
	keep if tax_yr==2006
	ren a2pkp 		tincome
	
	* Keep filings filed by 6 months after tax year ends
	keep if filing_dt <= mdy(6,30,tax_yr+1)

	* Keep original filing or earliest correction if original not availbale
	bys npwp tax_yr: egen mincorrection = min(correction)
	drop if correction!=mincorrection
	
	* If still duplicates, keep earliest
	bys npwp tax_yr: egen mindate = min(system_dt)
	drop if system_dt!=mindate
	
	* Else randomly pick one
	gen double temprand = runiform()
	sort npwp tax_yr temprand
	by npwp tax_yr: gen ord = _n
	keep if ord==1
	isid npwp tax_yr
			
	keep npwp tincome
	
	destring npwp, replace
	format npwp %15.0g

	saveold "${output}/temp_data/spt1771_2006_tincome.dta", replace
	
}
***************************************************************
******** Counts and sample averages for all taxpayers *********
***************************************************************

if `alltaxpayers'==1{

   * First, get MTO code for each region
		u "${raw}/auxiliary/kpps_mtos_regions_codes.dta", clear
		keep kpp mto region_mto
		
		keep if mto==1
		destring kpp, replace
		ren kpp mto_code
		keep mto_code region_mto
		duplicates drop
		
		* Pekanbaru and Batam are 2 MTOS under the same region.
		* Create different code so that merging can be proper.
		replace mto_code=999 if inlist(mto_code,217,218)
		
		duplicates drop

		tempfile mtokpp
		sa `mtokpp'
		
		u "${raw}/auxiliary/kpps_mtos_regions_codes.dta", clear
		merge m:1 region_mto using `mtokpp'
		keep if _merge==3
		
		keep kpp region_mto mto_code
		
		tempfile mto_code
		sa `mto_code'
	
	* Get SPT 1771 data
		u "${output}/analysis/SPT_1771_clean.dta", clear
		
		keep npwp filing_yr
		tab filing_yr

		destring npwp, replace
		format npwp %15.0g

		duplicates drop
		
		* Note: this definition of MTO does not inclued LTOs and special offices as MTOs
		merge 1:1 npwp filing_yr using "${output}/analysis/mto_treatment_calendar_yr_SPT1771.dta", keepusing(kpp mto_post)
		keep if _merge==3
		drop _merge
		
		* Get the regions
		merge m:1 kpp using `mto_code', keepusing(mto_code) keep(3) nogen
		
		* Flag observations in 2007 selection sample
		gen select2007 = inlist(mto_code, 7,46,62,73,123,308,441,511,631,641,651,725,812)
		
		bys npwp: egen evermto_all 	= max(mto_post)
		bys npwp: egen evermto_upto11 	= max(cond(filing_yr<=2011,mto_post,.))
		bys npwp: egen evermto_upto13 	= max(cond(filing_yr<=2013,mto_post,.))
		
		* Merge in 2006 taxable income for zm_matrix
		
		merge m:1 npwp using "${output}/temp_data/spt1771_2006_tincome.dta"
		keep if _merge==1 | _merge==3
		drop _merge
		
		* Express tincome in billion Rp
		replace tincome = tincome/10^9
		
		******* Start counting and computing zm N ********
		* All taxpayers (years 2003 - 2017)
		store 1
		
		* All taxpayers registered as of 2006
		keep if filing_yr<=2006
		store 2
		
		* Save IDs of these taxpayers for total tax revenue calculations
		preserve
			keep npwp evermto_upto11
			duplicates drop
			
			saveold "${output}/temp_data/IDs_19_regions_as_of_2006.dta", replace
		restore
		
		* All taxoayers in regions with MTOs created in 2007 and not selecting in 2008
		keep if select2007==1
		store 3
	
	* Save counts 
		clear
		
		svmat counts
		svmat zm
		svmat N
		
		gen var =""
		replace var = "All taxpayers in 19 regions registered anytime" if _n==1
		replace var = "All taxpayers in 19 regions registered as of 2006" if _n==2
		replace var = "All taxpayers in 13 regions with 2007 MTO creation" if _n==3
		
		ren counts1 ids_all
		ren counts2 ids_mto_to11
		ren counts3 ids_mto_to13
		
		ren zm1		zm_all
		ren zm2		zm_mto_to11
		ren zm3		zm_mto_to13
		
		ren N1		Nzbar_all
		ren N2		Nzbar_to11
		ren N3		Nzbar_to13
		
		order var, first
		
		saveold "${output}/temp_data/SPT1771_taxpayer_counts_allsample.dta", replace
}

***************************************************************
******** Counts and sample averages for analysis sample *******
***************************************************************

if `analysis_sample'==1{
	
	********* Compute zm and N as of 2006 for analyis sample *********
	* From same analysis file used in MTO and tax elasticity estimation

	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
	
	* IV weights file does not have variable evermto. Define based on inMTO by 2008
	gen double evermto = inMTOby2008
	
	* Keep if has the weights
	keep if !missing(eweight2)
	
	* Total counts
		unique npwp
		mat sample_stats[1,1] = r(unique)
		
		unique npwp if evermto==1
		mat sample_stats[1,2] = r(unique)
		
		mat sample_stats[1,3] = .		// Analysis file does not contain MTO taxpayers for 2012-2013
	
	* Taxable income means
		keep npwp year tincome evermto
		keep if year==2006 & !missing(tincome)
		
		* Keep if above 0.1
		keep if tincome>=0.1
		
		sum tincome
		mat sample_stats[1,4] = r(mean)
		
		sum tincome if evermto==1
		mat sample_stats[1,5] = r(mean)
		
		mat sample_stats[1,6] = .
	
	* Taxable income above 100 million counts
		unique npwp 
		mat sample_stats[1,7] = r(unique)
		
		unique npwp if evermto==1
		mat sample_stats[1,8] = r(unique)
		
		mat sample_stats[1,9] = .

	* Save
	 clear
	 svmat  sample_stats
	
	 ren sample_stats1	ids_all	
	 ren sample_stats2	ids_mto_to11	
	 ren sample_stats3	ids_mto_to13	
	 ren sample_stats4	zm_all	
	 ren sample_stats5	zm_mto_to11	
	 ren sample_stats6	zm_mto_to13	
	 ren sample_stats7	Nzbar_all	
	 ren sample_stats8	Nzbar_to11	
	 ren sample_stats9	Nzbar_to13	
	 
	 gen var = "Analysis sample"
	 
	 tempfile samp
	 sa `samp'
	 
	 * Append all sample
	 u "${output}/temp_data/SPT1771_taxpayer_counts_allsample.dta", clear
	 append using `samp'
	 
	 keep if !missing(var)

	saveold "${output}/analysis/regcoeffs/SPT1771_taxpayer_counts_zm_N.dta", replace
}

clear
log close
