* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/6_2_Stats_for_counterfactual.log", replace
di in red "do 6_2_Stats_for_counterfactual.do"

global minyear = 2003
global maxyear = 2011

local alltaxes "ppH_CITpaid_adj ppH_total_adj"

********** Get MTO treatment effect on income tax payments **********

	* MTO pooled regression treatment effect estimates
	* Use Nominal Rp (ETI estimated using nominal) and clustered at npwp
	* Use second stage estimates
	u using "${output}/analysis/regcoeffs/MTO_DD_for_counterfactual.dta", clear

	ren b iv_b
	ren se iv_se
	
	gen double iv_lb = iv_b -1.96*iv_se
	gen double iv_ub = iv_b +1.96*iv_se
	keep var iv_b iv_lb iv_ub
	
	* Keep point estimates and se
	foreach tax in `alltaxes'{
	foreach x in b lb ub{
		levelsof iv_`x' if var=="`tax'", local(`x'_MTO_`tax') clean
	}
	}
******** Get ETI estimates *********

	insheet using "${output}/analysis/csv/etihomo.csv", clear
	
	tostring lyear controls weight fe cut, replace
	gen spec = lyear + controls + weight + fe + cut
	levelsof spec, local(specs) clean
	
	tempfile all
	sa `all'
	
	foreach etispec in `specs'{
	
		u `all', clear
		keep if spec=="`etispec'" 

		keep coeff iv_netmtr
		levelsof iv_netmtr if coeff=="se", local(se) 
		
		keep if coeff=="b"
		
		* Generate 95% CI
		gen double eub = iv_netmtr+1.96*`se'
		gen double elb = iv_netmtr-1.96*`se'

		tab eub
		tab elb

		ren iv_netmtr eb
		keep eb elb eub

		levelsof eb, local(eb)
		levelsof elb, local(elb)
		levelsof eub, local(eub)

	******** Get zm and N estimates for analysis sample and whole sample *********

		u "${output}/analysis/regcoeffs/SPT1771_taxpayer_counts_zm_N.dta", clear
		renvars Nzbar_to*, subst("Nzbar_to" "nzbar_mto_to")
		ren Nzbar_all nzbar_all
		keep var *_all *mto_to11
		
		* Focus on analysis sample or all as of 2006
		keep if regexm(var,"Analysis")>0 | regexm(var,"as of 2006")>0
		
		ren var sample
		
		gen etispec 							= "`etispec'"
		
		foreach x in b lb ub{
			foreach tax in `alltaxes'{
				gen double MTO_`tax'_`x' 		= ``x'_MTO_`tax''
			}	
			gen double eti_`x'						= `e`x''
		}
		

	******** Compute dR_MTO ********

		foreach tax in `alltaxes'{
			foreach x in b lb ub{
				gen double dR_MTO_`tax'_`x' = MTO_`tax'_`x'*ids_mto_to11
			}
		}
		
	********** Compute dt that would give same effect as MTO **********
		
		gen t 		= .3		/* Highest MTR in 2006 */
		gen zbar  	= 0.1		/* Highest marginal taxable income bracket */
		
		* Rehsape long on spec, and taxpayers who will experience the tax raise
		reshape long zm_ nzbar_, i(etispec sample) j(taxed) string
		ren zm_ zm
		ren nzbar_ N
		
		* nzbar: taxpayers above zbar, who would experience the tax increase				
		order etispec sample taxed ids* zbar zm N eti_b eti_lb eti_ub MTO_* dR_MTO*
		
		* reshape long on eti 
		reshape long eti_ , i(etispec sample taxed) j(eti_stat) string
		ren eti_ eti
		
		* reshape long on MTO effect 
		reshape long MTO_ dR_MTO_, i(etispec sample taxed eti) j(MTO_stat) string
		ren MTO_ 	MTO_effect
		ren dR_MTO	dR_MTO
		
		* Tax rate that would match MTO effect
		gen double dt = dR_MTO/(N*(zm - zbar)*(1 - eti*(zm/(zm-zbar))*(t/(1-t))))

		* Compute dt that would match effect in behavioral response
		gen double dt_cut = -dR_MTO/(N*eti*zm*(t/(1-t)))

		drop ids_all
		order t zbar, last
		
		gen double 	pareto 				= zm/(zm-zbar)
		gen double	mdeadweight			= eti*pareto*t/(1-t)
		gen double  excessdeadweight	= eti*pareto*t/(1- t- eti*pareto*t)
		
		order etispec sample taxed MTO_stat eti_stat ids* N zm t zbar
		
		di in red "f`etispec'"
		tempfile f`etispec'
		sa `f`etispec''
	}
	
	clear
	u `f20091110', clear
	foreach spec in `specs'{
		append using `f`spec''
	}
	
	duplicates drop
	
	outsheet using "${output}/analysis/csv/Counterfactual.csv", comma replace

clear
log close
