/*	
	All analyses are based on anonymized data
	Variable "npwp" is a randomly generated taxpayer ID

	Estimate of budget per taxpayer for MTO vs not MTO
	
	- Use 2016 budget
	- Keep KPP Madya and KPP Pratama budget lines
	- Sum total by Madya vs Pratama
	
*/
set seed 98765
log using "${dofile}/logs/7_Budget.log", replace
di in red "do 7_Budget.do"


local clean_budget 	= 1
local per_taxpayer	= 1


if `clean_budget'==1{
	
	import excel using "${raw}/dipa-induk-ditjen-pajak-2016.xlsx", clear
	
	ren D code
	ren H name
	ren T staff
	ren W goods
	ren AB capital
	ren AD other
	ren AI total
	
	keep code name staff goods capital other total
	
	* Remove regional offices, LTO, special offices
	/* Keep only KPP Madya or KPP Pratama */
	
	replace name = upper(name)
	keep if regexm(name,"MADYA")>0 | regexm(name,"PRATAMA")>0
	
	* A few entries in capital column were imported with many digits as floating point error
	*br if length(capital)>10
	
	replace capital = "81.912" if name=="KANTOR PELAYANAN PAJAK PRATAMA JAKARTA TAMANSARI SATU"
	replace capital = "65.1" if name=="KANTOR PELAYANAN PAJAK PRATAMA JAKARTA KALIDERES"
	replace capital = "75.040" if name=="KANTOR PELAYANAN PAJAK PRATAMA SUMEDANG"
	replace capital = "637.743" if name=="KANTOR PELAYANAN PAJAK PRATAMA PASURUAN"
	replace capital = "608.156" if name=="KANTOR PELAYANAN PAJAK PRATAMA SIDOARJO BARAT"
	replace capital = "92.719" if name =="KANTOR PELAYANAN PAJAK PRATAMA SINGKAWANG"
	
	* Values are in thousands of Rupiah per PDF
	foreach var of varlist staff goods capital other total{
		replace `var' = subinstr(`var',".","",.)
		
		* Convert to billion
		destring `var', replace
		replace `var' = `var'/10^6
	}
	
	gen double mto = (regexm(name,"MADYA")>0)
	
	order mto, before(name)
	
	saveold "${raw}/budget2016.dta", replace
}

if `per_taxpayer'==1{
	
	u "${raw}/budget2016.dta", clear
	
	collapse (sum) staff goods capital other total, by(mto)
	
	tempfile tot16
	sa `tot16'
	
	* Get latest total number of taxpayers in MTO per latest SPT 1771 data
	u "${output}/analysis/mto_treatment_calendar_yr_SPT1771.dta", clear
	keep mto npwp filing_yr
	
	* Use total number of taxpayers in MTO as of same budget year
	keep if filing_yr==2016
	
	* Keep only if know MTO assignment
	keep if mto==0 | mto==1
	
	keep npwp mto
	ren mto mto
	
	* Add to this number taxpayers from MPN data
	**** New MPN data with filing dates *****
	preserve
		u "${output}/analysis/MPN_detailed_clean.dta", clear
		
		destring npwp, replace force
		keep if !missing(npwp)
		format npwp %15.0g
		assert !missing(payment_dt)
		gen double year = year(payment_dt)
		
		keep if year==2016
		keep npwp
		duplicates drop
		tempfile newmpn
		sa `newmpn'	
	restore
	
	merge 1:1 npwp using `newmpn', nogen
	replace mto = 0 if missing(mto)
	
	**** Coarse MPN data without filing dates but with MTO flag: count ever MTO *****
	preserve
		u "${output}/analysis/MPN_clean.dta", clear
		des
		
		destring npwp, replace force
		keep if !missing(npwp)
		format npwp %15.0g
		
		keep npwp evermto

		bys npwp: gegen Evermto = max(evermto)
		drop evermto
		ren Evermto evermto
		
		keep if evermto==1
		keep npwp
		gduplicates drop
		tempfile evertag
		sa `evertag'
	restore
	
	merge 1:1 npwp using `evertag', nogen
	replace mto = 1 if mto==.
	
	* Collapse all 
	gen taxpayers = 1
	collapse (sum) taxpayers, by(mto)
	
	merge 1:1 mto using `tot16', nogen
	
	* The year here is the year that will be used for deflating the budget data
	gen year = 2016 
	gen budget_currency = "current"
	
	tempfile current
	sa `current'
	
	**************************************
	* Deflate Rp denominated #s to 2007 Rp
	**************************************
	preserve
		insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
		replace date = substr(date,1,4)
		destring date, replace
		replace date = date-1	// End of year 
		ren idngdp deflator		// end-of-2014 Rp
		ren date year
		
		* Get deflator relative to 2007 Rp
		gen double def07 = deflator if year==2007
		egen def07m = max(def07)
		drop def07
		
		gen double deflator2007 = (deflator/def07m)*100
		drop def07m
		
		// Rescale so that it's 1 in 2007
		replace deflator2007=deflator2007/100
		
		keep year deflator2007
		tempfile deflator
		sa `deflator'
	restore
	
	merge m:1 year using `deflator'
	keep if _merge==3
	drop _merge
	
	foreach var of varlist staff goods capital other total{
		replace `var' = `var'/deflator2007
	}
	drop deflator
	
	drop budget_currency
	gen budget_currency = "Rp07"
	
	append using `current'
	
	order mto year budget_currency taxpayers total
	
	outsheet using "${output}/analysis/csv/Budget_per_taxpayer.csv", comma replace
}
clear
log close
