* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/8_Descriptive_statistics_all_taxpayers.log", replace
di in red "do 8_Descriptive_statistics_all_taxpayers.do"

global minyear 		= 2003
global maxyear 		= 2011
	
**************** 2005 stats ****************

	local MPN		=	1
	local SPT_1771 	= 	1
	local SPT_1721	=	1
	
	****************** Base year characteristics of all taxpayers ******************
	* Region
	import excel using "${raw}/auxiliary/KPP_codes.xlsx", sheet(compiled_codes) first clear
	
	gen mto = regexm(upper(tax_office),"MADYA")>0
	ren kpp_code kpp
	destring kpp, replace

	keep kpp mto region
	
	tempfile region
	sa `region'
	
	* Industry code names
	import excel using "${raw}/auxiliary/KLU code 2-digit descriptions_2003_2012.xlsx", sheet(match_final) first clear
	keep if year==2003
	keep klu_code_2_digit klu_code_description
	ren klu_code_2_digit klu2
	destring klu2, replace
	tempfile klu
	sa `klu'
	
	* Get deflator
	insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
	replace date = substr(date,1,4)
	destring date, replace
	replace date = date-1	// End of year 
	ren idngdp deflator		// end-of-2014 Rp
	ren date year
	
	* Get deflator relative to 2007 Rp
	gen double def07 = deflator if year==2007
	egen def07m = max(def07)
	drop def07
	
	gen double deflator2007 = (deflator/def07m)*100
	drop def07m
	
	// Rescale so that it's 1 in 2007
	replace deflator2007=deflator2007/100
	
	keep year deflator2007
	tempfile deflator
	sa `deflator'
	
	******** In MTO by 2011 **********
	u "${output}/analysis/SPT_1771_clean.dta", clear
	
	destring npwp, replace
	format npwp %12.0g
	
	keep if inrange(filing_yr,2003,2011)
	
	* Merge geography to get MTO status
	destring kpp, replace force
	merge m:1 kpp using `region', keep(3) nogen
	
	bys npwp: egen evermto_by_2011 = max(mto)
	
	* Keep single office observation
	drop if evermto_by_2011==1 & mto==0
	gen double temprand = runiform()
	sort npwp  temprand
	by npwp: gen ord = _n
	keep if ord==1
	isid npwp 
		
	keep npwp kpp region evermto_by_2011 temprand ord
	
	tempfile mto
	sa `mto'
	**************** Geography and industry ****************

	* Geography
	u `mto', clear
	
		* Add share of total taxes paid in base year
		preserve
			u "${output}/analysis/MPN_detailed_clean.dta", clear
			
			keep if tax_yr==2005
			destring npwp, replace force
			keep if !missing(npwp)
			format npwp %15.0g
			
			replace taxpaid = taxpaid/10^9
			format taxpaid %15.0g
			
			collapse (sum) taxpaid, by(npwp)
			tempfile taxes
			sa `taxes'
		restore
		
		merge 1:1 npwp using `taxes', keep(1 3) nogen
		
		replace evermto_by_2011=0 if evermto_by_2011==.
		
		collapse (count) npwp (sum) taxpaid, by(region evermto_by_2011)
		outsheet using "${output}/analysis/csv/descriptives_2005_MTO_PTO_geography_all_taxpayers.csv", comma replace

	* Industry
		* Merge KLU
		u `mto', clear
		merge m:1 npwp using "${output}/analysis/npwp_klu_mapping.dta", keep(1 3) nogen
		
		* Industry
		tostring klu_1721, gen(klu2)
		replace klu2 = substr(klu2,1,2)
		destring klu2, gen(k)
		drop klu2
		ren k klu2
		merge m:1 klu2 using `klu', keep(1 3) nogen
		
		keep if !missing(klu2) 
		
		* Add share of total taxes paid in base year
		preserve
			u "${output}/analysis/MPN_detailed_clean.dta", clear
			
			keep if tax_yr==2005
			destring npwp, replace force
			keep if !missing(npwp)
			format npwp %15.0g
			
			replace taxpaid = taxpaid/10^9
			format taxpaid %15.0g
			
			collapse (sum) taxpaid, by(npwp tax_yr)
			tempfile taxes
			sa `taxes'
		restore
		
		merge 1:1 npwp using `taxes', keep(1 3) nogen
		
		replace evermto_by_2011=0 if evermto_by_2011==.
			
		collapse (count) npwp (sum) taxpaid, by(klu2 klu_code_description evermto_by_2011)
		
		outsheet using "${output}/analysis/csv/descriptives_2005_MTO_PTO_industry_all_taxpayers.csv", comma replace
	
	*********************************** MPN base year ***********************************
	if `MPN'==1{
		u "${output}/analysis/MPN_detailed_clean.dta", clear
		
		keep if tax_yr==2005
		destring npwp, replace force
		keep if !missing(npwp)
		format npwp %15.0g
		
		replace taxpaid = taxpaid/10^9
		format taxpaid %15.0g
		
		* Merge MTO treatment status
		merge m:1 npwp using `mto', keep(1 3) nogen keepusing(evermto_by_2011 kpp)
		
		replace evermto_by_2011=0 if evermto_by_2011==.
		
		keep npwp evermto_by_2011 tax_yr tax_type taxpaid
		
		ren tax_yr year
		merge m:1 year using `deflator', keep(3) nogen
		
		replace tax_type = subinstr(tax_type,"individual","ind",.)
		replace tax_type = subinstr(tax_type,"corporate","corp",.)
		replace tax_type = subinstr(tax_type,"domestic","dom",.)
		replace tax_type = subinstr(tax_type,"import","imp",.)

		replace tax_type = "ppH_OTHER" if inlist(tax_type,"ppH_22","ppH_final","ppH_22_imp","ppH_oilgas","ppH_nonoilgas","ppH_2529_ind","ppH_23","ppH_interest")
		replace tax_type = "ppH_PAYROLL" if inlist(tax_type,"ppH_21","ppH_26")

		replace tax_type = "ppN_OTHER" if regexm(tax_type,"ppN") & regexm(tax_type,"dom")==0 & regexm(tax_type,"imp")==0

		keep if inlist(tax_type,"ppH_2529_corp","ppH_OTHER","ppH_PAYROLL","ppN_OTHER","ppN_dom","ppN_imp")
		
		foreach var of varlist taxpaid{		
			gen double `var'Rp07 = `var'/deflator2007		
		}
		
		* Collapse across payment dates first
		collapse (sum) *Rp07, by(npwp evermto_by_2011 tax_type)
		
		* Get total taxes by taxpayer
		preserve
			keep if regexm(tax_type,"ppN") 
			collapse (sum) taxpaid, by(npwp evermto_by_2011 )
			gen tax_type = "ppN_total"
			tempfile ppn
			sa `ppn'
		restore
		
		preserve
			collapse (sum) taxpaid, by(npwp evermto_by_2011)
			gen tax_type = "ppHN_total"
			tempfile pphn
			sa `pphn'
		restore
		
		append using `ppn'
		append using `pphn'
		
		* Now collapse by tax type level and MTO status
		collapse (count) npwp (mean) *Rp07, by(evermto_by_2011 tax_type)
		
		outsheet using "${output}/analysis/csv/descriptives_2005_MTO_PTO_MPN_all_taxpayers.csv", comma replace
	}
	
	*********************************** SPT 1771 base year ***********************************
	if `SPT_1771'==1{
		u "${output}/analysis/SPT_1771_clean.dta", clear
		
		destring npwp, replace
		format npwp %12.0g
		
		* Merge MTO treatment status
		drop kpp
		merge m:1 npwp using `mto', keep(1 3) nogen keepusing(evermto_by_2011 kpp)
		
		replace evermto_by_2011=0 if evermto_by_2011==.

		keep if tax_yr==2005

		gen double temprand = runiform()
		sort npwp  temprand
		by npwp: gen ord = _n
		keep if ord==1
		isid npwp 
		drop temprand ord
		
		ren tax_yr year
		
		merge m:1 year using `deflator', keep(3) nogen
		
		* Variables behind income tax
		ren a2jphn			k_nincome		/* Fiscal net income that should be copied from attachment I */
		ren a2jpnf			k_nincome_a		/* Fiscal net incme from attachment I */	
		ren a2kokr			k_comploss
		ren a2pkp 			k_tincome
		ren a2ps17			k_citdue
		ren a2pp24			k_adjforcred
		ren a2ppht			k_totcitdue
		ren a2phbl			k_pphtotal
		ren a2phkl			k_paidvalue
		
		* Variables behind fiscal net income
		ren a2jphnkom		k_totcomninc	/* Total commercial net income */
		ren a2phfinal		k_ntaxinc
		ren a2jmpenfispos	k_totposadj
		ren a2jmpenfisneg	k_totnegadj
		ren a2nfpmod		k_facilityinv
		
		* Variables behind total commercial net income
		ren a2jphndn		k_domcomninc
		ren a2jphnkomln		k_forcomninc
		
		* Variables behind total domestic commercial net income			
		ren a2jphnus		k_nincbus
		ren a2jphnlus		k_nincsidebus

		* Variable sbehind net income from business
		ren a2jpru 			k_gincome
		ren a2hpp 			k_cgsold
		ren a2byusl			k_otherexpense
		
		keep k_* npwp evermto_by_2011 deflator2007
		renvars k_*, predrop(2)
		
		foreach var of varlist  ///
				nincome tincome gincome cgsold pphtotal citdue totcitdue paidvalue ///
				nincbus nincsidebus domcomninc forcomninc totcomninc ntaxinc  ///
				adjforcred totposadj totnegadj facilityinv comploss otherexpense {
				
				replace `var' = `var'/10^9
				gen double `var'Rp07 = `var'/deflator2007
				
		}

		collapse (count) npwp (mean) *Rp07, by(evermto_by_2011)
		
		outsheet using "${output}/analysis/csv/descriptives_2005_MTO_PTO_SPT_1771_all_taxpayers.csv", comma replace
	}
	
	**************************** SPT 1721 base year ******************************
	if `SPT_1721'==1{
		* IMPORTANT: Rp figures are already in IDR billion
		u "${output}/analysis/SPT_1721_annual_clean_analysis.dta", clear
		
		* Merge MTO treatment status
		merge m:1 npwp using `mto', keep(1 3) nogen keepusing(evermto_by_2011 kpp)
		replace evermto_by_2011 = 0 if missing(evermto_by_2011)
		
		replace evermto_by_2011=0 if evermto_by_2011==.
		
		keep if year==2005
				
		gen double temprand = runiform()
		sort npwp  temprand
		by npwp: gen ord = _n
		keep if ord==1
		isid npwp 
		drop temprand ord
		
		* Total employment
		gen double num_workers  	= num_perm + num_temp
		gen double wagebill			= inc_perm + inc_temp
		
		* Mean wage
		gen double wage_perm 	= inc_perm/num_perm 
		gen double wage_temp 	= inc_temp/num_temp 
		gen double wage 		= wagebill/num_workers 
		
		* Deflate and compute summary
		merge m:1 year using `deflator', keep(1 3) nogen
		
		foreach var of varlist wage* inc*{
			gen double `var'Rp07 = `var'/deflator2007
		}
		
		collapse (count) npwp (mean) num* *Rp07, by(evermto_by_2011)
		outsheet using "${output}/analysis/csv/descriptives_2005_MTO_PTO_SPT_1721_all_taxpayers.csv", comma replace
}

clear
log close
