# All analyses are based on anonymized data
# Variable "npwp" is a randomly generated taxpayer ID
# clear everything
rm(list = ls())

library(plotly)
library(Hmisc)

############ Set parameters ############ 
# Paths
inpath  <-"../output/analysis/regcoeffs"
outpath <-"../output/analysis/graphs"

##########################################
# Real Microdata
realdata <- read.csv(paste(inpath,"/real_data_for_eti_scatter.csv",sep=""))
realdata <- na.omit(realdata)

###### Stats on real rates for draft ###### 

# Get NPWP weights
weights <-realdata[c("npwp","eweight2","inMTOby2008")]

############ Binned simulated data ############ 
simdata <- read.csv(paste(inpath,"/simulated_data_for_eti_heatmap.csv",sep=""))

# Express MTR change in percentage points
simdata$MTRchange1 <- simdata$MTRchange1*100
simdata$MTRchange2 <- simdata$MTRchange2*100

# Check real data distribution
describe(realdata$gincome)
describe(realdata$tincome)

# Plot configurations
describe(simdata$MTRchange1)
# colorbar min and max
cmin <- round(min(simdata$MTRchange1),digits=0) 
cmax <- round(max(simdata$MTRchange1),digits=0)
# Legend line style
lstyle <-list(font = list(color="black"))

# Set working directory to graph output folder 
setwd(outpath)

  ################# Simulated data heatmap - All variation ####################

  ytickmax <-1000
  ytickby  <-100
  xtickmax <-100
  xtickby  <-10
  
  realdata        <- realdata[which(realdata$gincome<=101 & realdata$tincome<=1001),]
  realdata_mto    <- realdata[which(realdata$gincome<=101 & realdata$tincome<=1001 & realdata$inMTOby2008==1),]
  realdata_not    <- realdata[which(realdata$gincome<=101 & realdata$tincome<=1001 & realdata$inMTOby2008==0),]
  simdata        <- simdata[which(simdata$bingincome<=101 & simdata$bintincome<=1001),]
  
  ########### Overlay scatterplot on heatmap #####
  
  #### 2008-2009 #####
  p_2008_mto <- plot_ly() %>%
    add_trace(type="scatter",
              stream=list(maxpoints=10000),
              mode="markers",
              x=realdata_mto$gincome, 
              y=realdata_mto$tincome,
              marker = list(color="pink", 
                            size=5*realdata_mto$eweight2,
                            maxdisplayed=10000,
                            line = list(color = "pink")
              ),
              opacity=1,
              name="In first MTO cohort") %>%
    add_trace(type="scatter",
              stream=list(maxpoints=10000),
              mode="markers",
              x=realdata_not$gincome, 
              y=realdata_not$tincome,
              marker = list(color="black", 
                            size=5*realdata_not$eweight2,
                            maxdisplayed=10000,
                            line = list(color = "black")
              ),
              opacity=0.5,
              name="Not in first MTO cohort") %>%
    add_trace(type="heatmap",
              x=simdata$bingincome,
              y = simdata$bintincome,
              z=simdata$MTRchange1,
              colorscale="Portland") %>%
    colorbar(title = "Predicted change \n in MTR (pp)",
             titlefont=list(color="black"),
             limits=c(cmin-1,cmax+1),
             tickvals=c(cmin,-8,0,9,cmax),
             tickfont=list(color="black")
    )%>%
    layout(xaxis = list(title = '2008 Gross Income',
                        showgrid=FALSE,
                        zeroline=FALSE,
                        tickvals=c(seq(0,xtickmax,by=xtickby),4.8),
                        tickmode='array',
                        overlaying = "y",
                        side="bottom",
                        color="black"),
           yaxis = list(title = '2008 Taxable Income',
                        tickvals=seq(0,ytickmax,by=ytickby),
                        showgrid=FALSE,
                        zeroline=FALSE,
                        tickmode='array',
                        overlaying = "y",
                        side="left",
                        color="black"),
           margin=list(l=75,b=75),
           legend = lstyle)
   
  # Save graph manually using viewer
  # Save as eti_variation_2008_2009_mto_not.png
  # Use width=800, height=600
  p_2008_mto
     
  #### 2009-2010 #####
  p_2009_mto <- plot_ly() %>%
    add_trace(type="scatter",
              stream=list(maxpoints=10000),
              mode="markers",
              x=realdata_mto$gincome, 
              y=realdata_mto$tincome,
              marker = list(color="pink", 
                            size=5*realdata_mto$eweight2,
                            maxdisplayed=10000,
                            line = list(color = "pink")
              ),
              opacity=1,
              name="In first MTO cohort") %>%
    add_trace(type="scatter",
              stream=list(maxpoints=10000),
              mode="markers",
              x=realdata_not$gincome, 
              y=realdata_not$tincome,
              marker = list(color="black", 
                            size=5*realdata_not$eweight2,
                            maxdisplayed=10000,
                            line = list(color = "black")
              ),
              opacity=0.5,
              name="Not in first MTO cohort") %>%
    add_trace(type="heatmap",
              x=simdata$bingincome,
              y = simdata$bintincome,
              z=simdata$MTRchange2,
              colorscale="Portland") %>%
    colorbar(title = "Predicted change \n in MTR (pp)",
             titlefont=list(color="black"),
             limits=c(cmin-1,cmax+1),
             tickvals=c(cmin,-8,0,9,cmax),
             tickfont=list(color="black")
    )%>%
    layout(xaxis = list(title = '2008 Gross Income',
                        showgrid=FALSE,
                        zeroline=FALSE,
                        tickvals=c(seq(0,xtickmax,by=xtickby),4.8),
                        tickmode='array',
                        overlaying = "y",
                        side="bottom",
                        color="black"),
           yaxis = list(title = '2008 Taxable Income',
                        tickvals=seq(0,ytickmax,by=ytickby),
                        showgrid=FALSE,
                        zeroline=FALSE,
                        tickmode='array',
                        overlaying = "y",
                        side="left",
                        color="black"),
           margin=list(l=75,b=75),
           legend = lstyle)
   
      # Save graph manually using viewer
      # Save as eti_variation_2009_2010_mto_not.png
      # Use width=800, height=600
          p_2009_mto

# Clear all
rm(list = ls())