* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID

log using "${dofile}/logs/0_0_import_map_and_kpp_codes.log", replace
di in red "Run 0_0_import_map_and_kpp_codes.do"

*****************
**** Toggles ****
*****************

local import_map_codes		= 1
local import_kpp_codes 		= 1

/* MAP codes are the codes associated with each type of taxes paid in MPN data */

if `import_map_codes'==1{
	
	import excel using "${raw}/auxiliary/mpn_map_variable.xlsx", ///
			sheet("for_stata") clear
	
	keep A D E
	ren A map
	ren D tax_type
	ren E tax_cat
	
	drop if _n==1
	keep if tax_type!=""
	destring map, replace
	
	saveold "${raw}/auxiliary/map_codes.dta", replace
}


if `import_kpp_codes'==1{	
	
	********************************************************************
	* Import ref_kanwil sheet first, from web, contains many small KPPs
	* that may show up in MPN but not in SIDJP
	********************************************************************
	
		import excel using "${raw}/auxiliary/MTO's number of WP and dates.xlsx", ///
			sheet("ref_kanwil") clear
			
		ren A kpp
		ren B kpp_name
		ren C region_name
		
		gen length = length(kpp)
		replace kpp = "0" + kpp if length ==2
		replace kpp = "00" + kpp if length ==1
		
		drop if _n==1
		
		keep kpp kpp_name region_name
		
		* Get region codes, on same column as kpp codes in this list
		preserve
			keep if region_name==""
			drop region_name
			
			keep kpp kpp_name
			
			ren kpp_name region_name
			ren kpp region
			
			tempfile reg_codes
			sa `reg_codes'
		restore
		
		drop if region_name==""
		merge m:1 region_name using `reg_codes', nogen
		
		*MTOs
		gen mto = (index(kpp_name, "Madya") >0 )
		
		*Flag KPP codes that have multiple actual offices sharing same code
		gen n = 1
		bys kpp: egen tot = sum(n)
		
		* Check each MTO code is unique
		assert mto==0 if tot>1
		
		duplicates drop kpp region tot, force
		
		tostring tot, replace
		replace kpp_name = kpp_name + " (" + tot + " locations)" if tot!="1"
		
		keep kpp kpp_name region region_name mto
		order kpp mto region kpp_name region_name
		
		gen source="MTO's number of WP and dates.xlsx/ref_kanwil"
		
		* There are 19 MTOs total, 31 regions total
		tab mto
		unique region
		
		tempfile kanwill
		sa `kanwill'
	
	********************************************************************************
	* Import kpp_codes tab, compiled by Jakarta team to include all STOs, MTOs, LTO
	********************************************************************************
	
		import excel using "${raw}/auxiliary/MTO's number of WP and dates.xlsx", ///
		sheet("kpp_codes") clear
	
		ren A kpp
		ren B kpp_name
		ren C region_name
		ren D region
		
		drop if _n==1
		
		gen length = length(region)
		replace region = "0" + region if length ==2
		replace region = "00" + region if length ==1
		
		gen mto = (index(kpp_name, "Madya") >0 )
		
		order kpp mto region kpp_name region_name
		
		gen source = "MTO's number of WP and dates.xlsx/kpp_codes"
		
		***** Append *****
		append using `kanwill'
		sort kpp source
		duplicates drop kpp region, force
		
		tab mto
		unique region
		unique kpp
		
		duplicates tag kpp, gen(dup)
		bys kpp: egen dups = max(dup)
		
		drop if dups>0 & index(source,"kpp_codes")>0
		
		keep kpp mto region kpp_name region_name source
		unique kpp
		
		****** Create region MTO name ********
		preserve
			keep if mto==1
			ren kpp_name region_mto
			
			keep region_name region_mto source
			
			* Region code 040 (Kanwil DJP Riau dan Kep. Riau) has 2 MTOs
			replace region_mto = "KPP Madya Pekanbaru and KPP Madya Batam" if ///
				region_mto=="KPP Madya Pekanbaru" | region_mto=="KPP Madya Batam" 

			duplicates drop 
			tempfile mto
			sa `mto'
		restore
		merge m:1 region_name using `mto'
		drop _merge
		
		order kpp mto region region_mto kpp_name region_name source
		
		saveold "${raw}/auxiliary/kpps_mtos_regions_codes.dta", replace
}

log close
