* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/0_1_clean_SIDJP.log", replace
di in red "Run 0_1_clean_SIDJP.do"

****** Toggles ******
local spt_1771 			= 1		/* SPT 1771 */
local spt_pph1721		= 1		/* SPT Masa PPh 1721 */

***************************************************************************************
**** Program to clean anonymized NPWP (raw may or may not include tax office code) ****
***************************************************************************************

cap program drop clean_npwp
program define clean_npwp

	* NPWP
	order npwp kpp cab
	sort npwp kpp cab
	tostring npwp, replace
	gen length = length(npwp)
	tab length
	replace npwp = "0" + npwp if length == 8
	replace npwp = "00" + npwp if length == 7
	replace npwp = "000" + npwp if length == 6
	replace npwp = "0000" + npwp if length == 5
	replace npwp = "00000" + npwp if length == 4
	replace npwp = "000000" + npwp if length == 3
	replace npwp = "0000000" + npwp if length == 2
	drop length
	assert length(npwp) == 9
	
	* Taxpayers ID
	tostring kpp, gen(id_kpp)
	tostring cab, gen(id_cab)
	
	replace id_kpp = "0" + id_kpp if length(id_kpp) == 2
	replace id_kpp = "00" + id_kpp if length(id_kpp) == 1
	assert length(id_kpp) == 3
	
	replace id_cab = "0" + id_cab if length(id_cab) == 2
	replace id_cab = "00" + id_cab if length(id_cab) == 1
	assert length(id_cab) == 3
	
	* Define Complete Tax IDS (NPWP + CAB, and NPWP + CAB + KPP)
	gen id_npwp_cab = npwp + id_cab
	gen id_full = npwp + id_kpp + id_cab
	order id_full id_npwp_cab id_kpp id_cab
	
	* Keep cleaned KPP and CAB only
	sort id_npwp_cab
	drop cab kpp
	renvars id_cab id_kpp, predrop(3)
	
	lab var npwp "Taxpayer Identification Number (NPWP)"
	lab var kpp "3 digit KPP code (part of NPWP)"
	lab var cab "3 digit branch code (part of NPWP)"

end

*****************************
**** SPT PPh 1721 file ******
*****************************

if `spt_pph1721'==1{
	
	* Annual file for 2002-2008
	u "${output}/dta_raw/SPT_1721_02to08.dta", clear
	
	ren npwp_e npwp
	tostring npwp, replace
	replace npwp = subinstr(npwp,"'","",.)
	
	gen length = length(npwp)
	assert length(npwp) == 9
	
	* Years: 2002-2008
	destring b1thpj, gen(tax_yr)
	
	**** Rename employee variables ****
	
	ren b1jptp num_perm			/* b6_3 + b7_3 */
	ren b1pbtp inc_perm			/* b6_4 + b7_4 */
	ren b121tp inctax_perm		/* b6_5 + b7_5 */
	ren	b1jptt num_temp			/* b8_3 + b19_3 */
	ren	b1pbtt inc_temp			/* b8_4 + b19_4 */
	ren b121tt inctax_temp		/* b8_5 + b19_5 */
	
	ren b1jpkob num_board		/* b13_3 */
	ren	b1pbkob inc_board		/* b13_4 */
	ren b121kob inctax_board	/* b13_5 */
	ren b1jptab num_experts		/* b12_3 */
	ren b1pbtab	inc_experts		/* b12_4 */
	ren b121tab inctax_experts	/* b12_5 */
	
	ren b1jpasb num_isomerch	/* b10_3 + b11_3 */
	ren b1pbasb inc_isomerch	/* b10_4 + b11_4 */
	ren b121asb inctax_isomerch	/* b10_5 + b11_5 */
	
	ren b1jplnb	num_foreign		/* b19_3 */
	ren b1pblnb	inc_foreign		/* b19_4 */
	ren b121lnb inctax_foreign	/* b19_5 */
	
	ren b1jpmpb num_former		/* b14_3 */
	ren b1pbmpb inc_former		/* b14_4 */
	ren b121mpb inctax_former 	/* b14_5 */
	
	ren b1jphlb num_freelance	/* b8_3 */
	ren b1pbhlb inc_freelance	/* b8_4 */
	ren b121hlb inctax_freelance /* b8_5 */
	
	keep npwp tax_yr num* inc*
	
	* First, remove real duplicates
	duplicates drop
	
	* Second, aggregate at NPWP level for each year (e.g. total across branches if there are any)
	foreach var of varlist num* inc*{
		destring `var', replace
		bys npwp tax_yr: egen double tot`var' = sum(`var')
	}
	keep npwp tax_yr tot*
	renvars tot*, predrop(3)
	
	* Keep if has any permanent or any temporary employees
	* (lots of entries that are just missing or zeros, might be artifact of data pull )
	keep if (num_perm>0 & !missing(num_perm) )| (num_temp>0 & !missing(num_temp))
	
	* Replace missing with zero if has any filing
	foreach var of varlist num* inc* inctax*{
		replace `var' = 0 if missing(`var')
	}
	
	keep npwp tax_yr num* inc*
	
	tempfile pre
	sa `pre'
	
	*** 2009 -2011 forms ****
	
	u "${output}/dta_raw/SPT_1721.dta", clear
	
	* NPWPs in this dataset are max 9-digits long
	* and there is no cabang code
	
	tostring npwp, replace
	gen length = length(npwp)
	tab length
	replace npwp = "0" + npwp if length == 8
	replace npwp = "00" + npwp if length == 7
	replace npwp = "000" + npwp if length == 6
	replace npwp = "0000" + npwp if length == 5
	replace npwp = "00000" + npwp if length == 4
	replace npwp = "000000" + npwp if length == 3
	replace npwp = "0000000" + npwp if length == 2
	drop length
	
	assert length(npwp) == 9

	* Destring
	foreach var of varlist masa_pajak tahun_pajak b6* b7* b8* b10* b11* b12* b13* b14* b19*{
		destring `var', replace
	}
	
	**** Rename employee variables ****
	
	ren masa_pajak	tax_month
	ren tahun_pajak tax_yr
	
	gen double num_perm 	= b6_3 + b7_3
	gen double inc_perm 	= b6_4 + b7_4
	gen double inctax_perm 	= b6_5 + b7_5
	
	gen double num_temp		= b8_3 + b19_3
	gen double inc_temp		= b8_4 + b19_4
	gen double inctax_temp	= b8_5 + b19_5
	
	gen double num_isomerch 	= b10_3 + b11_3
	gen double inc_isomerch 	= b10_4 + b11_4
	gen double inctax_isomerch 	= b10_5 + b11_5
	
	ren b19_3 num_foreign
	ren b19_4 inc_foreign
	ren b19_5 inctax_foreign
	
	ren b14_3 num_former
	ren b14_4 inc_former
	ren b14_5 inctax_former
	
	ren b13_3 num_board
	ren b13_4 inc_board
	ren b13_5 inctax_board
	
	ren b8_3 num_freelance
	ren b8_4 inc_freelance
	ren b8_5 inctax_freelance
	
	ren b12_3 num_experts
	ren b12_4 inc_experts
	ren b12_5 inctax_experts
	
	keep npwp tax_yr tax_month num* inc*
	
	* First, remove real duplicates
	duplicates drop
	
	* Second, aggregate at NPWP level for each month (e.g. total across branches if there are any)
	foreach var of varlist num* inc*{
		bys npwp tax_yr tax_month: egen double tot`var' = sum(`var')
	}
	keep npwp tax_yr tax_month tot*
	renvars tot*, predrop(3)
	
	* Keep if has any permanent or any temporary employees
	* (lots of entries that are just missing or zeros, might be artifact of data pull )
	keep if (num_perm>0 & !missing(num_perm) )| (num_temp>0 & !missing(num_temp))
	
	* Replace missing with zero if has any filing
	foreach var of varlist num* inc* inctax*{
		replace `var' = 0 if missing(`var')
	}
	
	** December filing is cumulative for tax amounts. Check
	** everyone has december filing. Impute if not filed for December **
	
	gen dec = (tax_month == 12)
	bys npwp tax_yr: egen double hasdec = max(dec)
	
	preserve
		keep if hasdec==0
		
		* Sum monthly tax amounts for annual tax ammount
		foreach var of varlist inc*{
		bys npwp tax_yr: egen double sum`var' = sum(`var')
		}
		
		* Use average number of employees if doesn't have annual at december
		foreach var of varlist num*{
			bys npwp tax_yr: egen double mean`var' = mean(`var')
			replace mean`var'=round(mean`var')
		}
		
		keep npwp tax_yr tax_month sum* mean*
		renvars sum*, predrop(3)
		renvars mean*, predrop(4)
		
		drop tax_month
		duplicates drop
		
		unique npwp tax_yr
		assert r(N) == r(unique)
		
		tempfile hasdec
		sa `hasdec'
	restore
	
	keep if hasdec==1
	keep if tax_month == 12
	drop tax_month hasdec
	
	keep npwp tax_yr num* inc*
	append using `hasdec'
	
	* 2002-2008 data
	append using `pre'
	
	* Small # taxpayers with 2007-2008 data in new form
	* Keep only one filing if there multiple
	duplicates tag npwp tax_yr, gen(dup)
	tab dup
	
	duplicates drop npwp tax_yr, force
	drop dup
	
	keep if inrange(tax_yr,2003,2011)
	
	tab tax_yr
	
	order npwp tax_yr *_perm *_temp *_freelance *_board *_experts *_foreign *_former
	sort npwp tax_yr
	
	*** Mistakes in filling out form ***
	
	* 1 dollar ~= 14,000 Rp. inc_perm is in Rp, num_perm is in # workers
	* This flag catches entries where num_perm looks like Rp denominated
	* value, misplaced in the number of workers columns
	gen flag_mistakes = ( inc_perm/num_perm<10^4 & inc_perm>0) | ///
						( inc_temp/num_temp<10^4 & inc_temp>0) 
	
	sum num_perm, detail
	local topperm = r(p99)
	
	sum num_temp, detail
	local toptemp = r(p99)
	
	* For cases when inc_perm is exactly zero and num_perm is too high
	replace flag_mistakes = 1 if num_perm> `topperm' & inc_perm/num_perm<10^4
	replace flag_mistakes = 1 if num_temp> `toptemp' & inc_temp/num_temp<10^4
	
	tab flag_mistakes
	saveold "${output}/analysis/SPT_1721_annual_clean.dta", replace
}

*************************
**** SPT 1771 file ******
*************************

if `spt_1771' == 1 {
	set seed 98765
	set sortseed 12345
	
	use "${output}/dta_raw/SPT_1771.dta", clear
	
	* Clean NPWP and define taxid
	clean_npwp
	
	* Generate tax filing year - (Different formatting than 2regions file)
	gen date = substr(a2tgms,1,10)
	split date, parse("/")
	destring date*, replace
	
	*list date1 thpj if date1<2006
	* Assume filing year is in the correct timing in the small occasions where
	* there are typos
	replace date1 = thpj +1 if date1<2003 | date1>2017
	
	gen double filing_dt = mdy(date2,date3,date1)
	gen double filing_yr = date1
	drop date*
	format filing_dt %td
	
	label var filing_dt "SPT filing date (Tanggal lapor SPT)"
	label var filing_yr "Filing year"

	* System date. If filing date not available, replace with system date
	gen date = substr(a2tgre,1,10)
	split date, parse("/")
	destring date*, replace
	gen double system_dt = mdy(date2,date3,date1)
	format system_dt %td
	drop a2tgre date* 
	
	gen double system_yr = year(system_dt)
	tab system_yr if missing(filing_yr)
	replace filing_yr = system_yr if missing(filing_yr)
	
	* Pembetulan == a2kspt as intended, drop one
	assert pembetulan == a2kspt
	drop a2kspt
	rename pembetulan correction
	label var correction "Number of SPT correction filing (Pembetulan)"
	
	* Tax year
	rename thpj tax_yr
	label var tax_yr 	"Tax year (Tahun Pajak)"
	
	* Add original variable label

	lab var a2tgms "Raw tax filing date"
	lab var a2tdok "Document type (balance / unbalance)"
	lab var a2audit "Financial statement (audited / unaudited)"
	lab var a2opini "Audit opinion based on financial statement"
	lab var a2jphn "1771 1. Fiscal net income (copied from 1771-I 8)"
	lab var a2kokr "1771 2. Compensation for fiscal loss carried forward"
	lab var a2pkp "1771 3. Taxable income (1 - 2)"
	lab var a2ps17 "1771 4. Income tax due"
	lab var a2pp24 "1771 5. Adjustment for foreign tax credit refunded that had been credited in the previous year's return (income tax article 24)"
	lab var a2ppht "1771 6. Total tax due (4 + 5)"
	lab var a2pdtp "1771 7. Income tax borned by the government (foreign aid project)"
	lab var a2krdn "1771 8a. Domestic tax credit"
	lab var a2ps24 "1771 8b. Foregin tax credit"
	lab var a2phk3 "1771 8c. Total tax credit (8a + 8b)"
	lab var a2kdbl "1771 9. PPh Type"
	lab var a2phbl "1771 9. PPh Total (6 - 7 - 8c)"
	lab var a2by25 "1771 10a. Prepaid tax: monthly PPh based on Tax Article 25"
	lab var a2st25 "1771 10b. Prepaid tax: based on notice of tax collection (principal only)"
	lab var a2by257 "1771 10 . Prepaid tax: foreign fiscal income (not in SPT)"
	lab var a2filn "1771 10 . Prepaid tax: PPh from transfer of land rights (not in SPT)"
	lab var a2bysd "1771 10c. Prepaid tax: total (10a + 10b)"
	lab var a2kdkl "1771 11. Underpaid or overpaid tax (type)"
	lab var a2phkl "1771 11. Underpaid or overpaid tax (value) (9 - 10c)"
	lab var a2tssp "1771 12. Underpaid tax was settled on (date)"
	lab var a2kdlb "1771 13. Overpaid tax amount would be …"
	lab var a2toak "1771 14a. Income base for calculation of monthly tax installment"
	lab var a2tohu "1771 14b. Compensation for fiscal loss carried forward"
	lab var a2pkp12 "1771 14c. Taxable income (14a - 14b)"
	lab var a2ppht12 "1771 14d. Tax due (Tax rate from 4 * 14c)"
	lab var a2kre12 "1771 14e. Withholding tax that has been paid based on monthly tax installment"
	lab var a2pph12 "1771 14f. Income tax must be paid (14d - 14e)"
	lab var a2as25 "1771 14g. Income tax article 25 (1/12 * 14f)"
	lab var a2pjkf "1771 15a. Final PPh tax"
	lab var a2phno "1771 15b. Non-taxable income: gross income"
	lab var a2tgup "Time updated"
	lab var a2jpru "1771-I 1a. Gross income"
	lab var a2hpp "1771-I 1b. Cost of good sold (production cost)"
	lab var a2byusl "1771-I 1c. Other expense"
	lab var a2jphnus "1771-I 1d. Net income from business (1a - 1b - 1c)"
	lab var a2jphlus "1771-I 1e. Income from side business"
	lab var a2bylus "1771-I 1f. Expense from side business"
	lab var a2jphnlus "1771-I 1g. Net income from side business (1e - 1f)"
	lab var a2jphndn "1771-I 1h. Total domestic commercial net income (1d + 1g)"
	lab var a2jphnkomln "1771-I 2. Foreign commercial net income"
	lab var a2jphnkom "1771-I 3. Total commercial net income (1h + 2)"
	lab var a2phfinal "1771-I 4. Income subject to final tax and non-taxable income"
	lab var a2byfsham "1771-I 5a. Expense charged for the personal benefit of shareholders, partnership or members"
	lab var a2danacad "1771-I 5b. Formation or accumulation of allowances"
	lab var a2natura "1771-I 5c. Consideration or remuneration related to employment or services given in the form of a benefit in kind"
	lab var a2jlbhfsham "1771-I 5d. Excessive compensation paid to shareholders or other associated parties as a consideration of work performed"
	lab var a2hibah "1771-I 5e. Gifts, aid or donations"
	lab var a2pph "1771-I 5f. Income tax"
	lab var a2gjangskut "1771-I 5g. Salaries paid to a member of an association, firma, or limited partnership which capital does not consist of stocks"
	lab var a2sankadm "1771-I 5h. Administration penalties"
	lab var a2selsutkompos "1771-I 5i. Less commercial depreciation over fiscal depreciation"
	lab var a2selamkompos "1771-I 5j. Less commercial amortization over fiscal amortization"
	lab var a2byguhpos "1771-I 5k. Deferred expenses"
	lab var a2penfispos "1771-I 5l. Other positive fiscal adjustments"
	lab var a2jmpenfispos "1771-I 5m. Total positive fiscal adjustment (total of 5a to 5l)"
	lab var a2selsutkomneg "1771-I 6a. Difference in commercial depreciation under fiscal depreciation"
	lab var a2selamkomneg "1771-I 6b. Difference in commercial amortization under fiscal amortization"
	lab var a2byguhneg "1771-I 6c. Deferred income"
	lab var a2penfisneg "1771-I 6d. Other negative fiscal adjustments"
	lab var a2jmpenfisneg "1771-I 6e. Total negative fiscal adjustment (total of 6a to 6d)"
	lab var a2thnke "1771-I 7a. Year of facilities of investment allowance"
	lab var a2nfpmod "1771-I 7. Facilities of investment allowance (as reduction of net income)"
	lab var a2jpnf "1771-I 8. Fiscal net income (3 - 4 + 5m - 6e - 7b)"
	
	destring a2opini, replace force
	
	lab define a2opini 1 "Unqualified Opinion (Wajar Tanpa Pengecualian)" 2 "Qualified Opinion (Wajar Dengan Pengecualian)" 3 "Adverse Opinion (Tidak Wajar)" 4 "Disclaimer of opinion (Tidak Ada Opini)"
	lab val a2opini a2opini
	lab define a2kdbl 1 "Tax due after credit" 2 "Tax overly withheld" 0 "Zero"
	lab val a2kdbl a2kdbl
	lab define a2kdkl 1 "Underpaid tax" 2 "Overpaid tax" 0 "Not underpaid / overpaid"
	lab val a2kdkl a2kdkl
	lab define a2kdlb 1 "Refunded" 2 "Compensated with outstanding tax payable" 0 "Missing"
	lab val a2kdlb a2kdlb
	
	compress
	order id_full id_npwp_cab npwp cab kpp tax_yr filing_dt filing_yr correction
	sort id_npwp_cab cab kpp tax_yr filing_dt
	label data "SPT 1771 for all regional offices"
	saveold "${output}/analysis/SPT_1771_clean.dta", replace
	
}


clear all
log close
