* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/0_2_clean_MPN.log", replace
di in red "Run 0_2_clean_MPN.do"

****** Toggles ******

local mpn_detailed			= 1		/* Cleans detailed MPN data */
local mpn_aggregate 		= 1		/* Cleans aggregate MPN data, aggregated at tax year, NPWP-KPP-CAB level */

*********************************
**** Clean detailed MPN data ****
*********************************

if `mpn_detailed'==1{
	
	u "${output}/dta_raw/MPN_detailed.dta", clear
	
	* NPWP already string
	gen length = length(npwp)
	tab length
	replace npwp = "0" + npwp if length == 8
	replace npwp = "00" + npwp if length == 7
	replace npwp = "000" + npwp if length == 6
	replace npwp = "0000" + npwp if length == 5
	replace npwp = "00000" + npwp if length == 4
	replace npwp = "000000" + npwp if length == 3
	replace npwp = "0000000" + npwp if length == 2
	drop length
	
	assert length(npwp) == 9
	
	* Tax year: few typos for what looks like it's years pre-2008
	tab thn_pjk
	forvalues i=1/7{
		replace thn_pjk = "200`i'" if ///
		regexm(thn_pjk,"`i'$")>0 & regexm(thn_pjk,"^20")==0
	}
	
	tab thn_pjk
	
	* TGL_BAYAR seems
	split tgl_bayar, parse("/")
	destring tgl_bayar?, replace
	gen payment_dt = mdy(tgl_bayar2,tgl_bayar1,tgl_bayar3+2000)
	format payment_dt %td
	
	* Payment date inputs
	tab tgl_bayar2
	tab tgl_bayar1
	tab tgl_bayar3
	
	drop tgl_bayar*
	destring thn_pjk, replace force
	ren thn_pjk tax_yr
	
	* Get tabulation of map variable for coding
	preserve
		keep map tax_yr
		gen n = 1
		collapse (count) n, by(map tax_yr)
		
		ren n observations
		
		format observations %15.0g
		
		sort map tax_yr
		outsheet using "${raw}/auxiliary/mpn_map_variable_by_year.csv", comma replace
	restore
	
	* Aggregate jumlah at npwp-tax type - date level
	ren jumlah taxpaid
	
	* Merge map with tax type data
	merge m:1 map using "${raw}/auxiliary/map_codes.dta"
	keep if _merge==1 | _merge==3
	drop _merge
	
	keep if !missing(tax_type)
	
	* Aggregate
	collapse (sum) taxpaid, by(npwp payment_dt tax_yr tax_type tax_cat)
	
	compress
	saveold "${output}/analysis/MPN_detailed_clean.dta", replace
}

***********************************************************
**** Clean aggregate MPN data (aggregated by tax year) ****
***********************************************************

cap program drop clean_npwp
program define clean_npwp

	* NPWP
	
	* Leading characters that apppear to be typos
	replace npwp = subinstr(npwp,"'","0",.)
	replace npwp = subinstr(npwp,"`","0",.)
	replace npwp = subinstr(npwp,"=","0",.)
	replace npwp = subinstr(npwp," ","0",.)
	
	gen length = length(npwp)
	tab length
	replace npwp = "0" + npwp if length == 8
	replace npwp = "00000000" + npwp if length == 1
	drop length
	assert length(npwp) == 9
	
	*KPP
		replace kpp = "0"  + kpp if length(kpp)==2
		replace kpp = "00" + kpp if length(kpp)==1
	*CAB
		replace cab = "0"  + cab if length(cab)==2
		replace cab = "00" + cab if length(cab)==1
	
	* Taxpayers ID
	gen id_npwp_cab = npwp + cab
	
	* Few observations that have NPWPs with letters and KPP numbers
	* are also not numbers. Too many typos. Drop.
	gen byte notnumeric = ( real(id_npwp_cab)==.)
	drop if notnumeric == 1
	drop notnumeric
	
	* Full ID
	gen id_full = npwp + kpp + cab
	order id_full id_npwp_cab npwp kpp cab 
	sort npwp kpp cab

end

if `mpn_aggregate'==1{
	
	u "${output}/dta_raw/MPN.dta", clear
	
	* Clean NPWP
	clean_npwp
	
	* Flag MTOs
	merge m:1 kpp using "${raw}/auxiliary/kpps_mtos_regions_codes.dta", ///
	keepusing(mto region region_mto kpp_name)
	
	keep if _merge!=2
	drop _merge
	order mto, after(kpp)
	
	* Flag if ever mto at NPWP level
	bys npwp: egen evermto = max(mto)
	count if evermto==1 & mto==0
	
	duplicates tag id_full, gen(dup)
	
	* Tiny number of id_full taxpayers have payments entered
	* in multiple observations. Aggregate so that can shape long
	preserve
		keep if dup>0
		foreach var of varlist p25* pph* ppn*{
			bys id_full: egen double t`var' = sum(`var')
		}
		drop p25* pph* ppn* dup
		renvars t*, predrop(1)
		
		duplicates drop id_full, force
		
		tempfile dupsfixed
		sa `dupsfixed'
	restore
	
	drop if dup >0
	drop dup
	append using `dupsfixed'
	
	unique id_full
	
	* Reshape long
	reshape long p25_ pph_ ppn_, i(id_full) j(tax_yr)
	renvars p25_ pph_ ppn_, postdrop(1)
	drop id_full
	
	egen double taxpaid = rowtotal(p25 pph ppn)
	
	* Keep if taxpaid > 0 (zeros = missing in the wide format database)
	 keep if taxpaid > 0
	
	* Keep starting from first year taxpayer appears in the data
	bys id_npwp_cab: egen first_year = min(cond(taxpaid>0,tax_yr,.))
	keep if tax_yr>= first_year
	drop first_year
	
	******* Taxpayer-CAB combination associated with 2 kpps for same tax year *******
	
	duplicates tag id_npwp_cab tax_yr, gen(dup)
	
	* 1) Keep non-MTO KPP if tax_yr + 1 is before creation of MTO
	
		preserve
			import excel using "${raw}/auxiliary/MTO selection numbers by year.xlsx", ///
			sheet("MTO_regulations_compiled") clear
			keep B C D
			ren B kpp
			ren D mto_creation_yr
			duplicates drop
			drop if _n==1
			
			destring mto_creation_yr, replace
			
			tempfile mto_creation
			sa `mto_creation'
		restore
		
		merge m:1 kpp using `mto_creation'
		keep if _merge==1 | _merge==3
		drop _merge
		drop if (tax_yr + 1 < mto_creation_yr) & mto==1
		drop mto_creation_yr dup

	* 2) Else if in MTO post MTO creation
		* Sum total taxes paid through each KPP
		* To decide which KPP to assign to the taxpayer for that year, assign
		*   the MTO if that is one of the KPPs. Else randomly pick one.
		
		bys id_npwp_cab tax_yr: egen maxmto = max(mto)
		foreach x in p25 pph ppn taxpaid{
			bys id_npwp_cab tax_yr: egen double sum`x' = sum(`x')
		}
		drop p25 pph ppn taxpaid
		renvars sum*, predrop(3)
		
		* Assign to MTO if that is one of KPPs
		drop if maxmto==1 & mto==0
		drop maxmto
		
	* 3) Else randomly sample the KPP
		gen double temprand = runiform()
		sort id_npwp_cab tax_yr temprand
		by id_npwp_cab tax_yr: gen ord = _n
		keep if ord==1
		isid id_npwp_cab tax_yr
		drop temprand ord
	
	* Flag first year taxpayer is in the MTO
	bys id_npwp_cab: egen mtoyear = min(cond(mto==1,tax_yr,.))
	
	label var evermto "Taxpayer pays tax in MTO for any tax year"
	label var mto "Taxpayer pays this tax year's tax in MTO"
	label var region_mto "Name of region's MTO. Some regions don't have MTO. One has two."
	label var mtoyear "First year after MTO creation for which taxpayer pays tax in MTO"
	label var kpp_name "KPP name"
	
	keep  id_npwp_cab npwp cab tax_yr evermto mtoyear kpp kpp_name mto region_mto region p25 pph ppn taxpaid
	order id_npwp_cab npwp cab tax_yr evermto mtoyear kpp kpp_name mto region_mto region p25 pph ppn taxpaid
	
	compress
	label data "MPN unique at NPWP+CAB tax year"
	saveold "${output}/analysis/MPN_clean.dta", replace
	
}


clear all
log close
