* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/0_3_clean_AUDIT.log", replace
di in red "Run 0_3_clean_AUDIT.do"

****** Toggles ******

local clean_audit 	= 1

if `clean_audit'==1{
	
	u "${output}/dta_raw/audits.dta", clear
	
	duplicates drop
	
	keep if a6!=""
	
	* Keep if has audit date
	keep if tgl_mulai_pmrk!=""
	
	split tgl, parse(" ")
	replace tgl_mulai_pmrk1="1/9/2004" if tgl_mulai_pmrk1=="1/9/6474"
	replace tgl_mulai_pmrk1="10/4/2015" if tgl_mulai_pmrk1=="10/4/5015"
	replace tgl_mulai_pmrk1="11/9/2014" if tgl_mulai_pmrk1=="11/9/2214"
	replace tgl_mulai_pmrk1="19/12/2016" if tgl_mulai_pmrk1=="19/12/2106"
	replace tgl_mulai_pmrk1="23/3/2016" if tgl_mulai_pmrk1=="23/3/2116"
	replace tgl_mulai_pmrk1="26/6/2017" if tgl_mulai_pmrk1=="26/6/2107"
	replace tgl_mulai_pmrk1="30/9/2009" if tgl_mulai_pmrk1=="30/9/3009"
	replace tgl_mulai_pmrk1="5/10/2003" if tgl_mulai_pmrk1=="5/10/2230"
	replace tgl_mulai_pmrk1="8/9/2009" if tgl_mulai_pmrk1=="8/9/2019"
	replace tgl_mulai_pmrk1="8/9/2008" if tgl_mulai_pmrk1=="8/9/2998"
	replace tgl_mulai_pmrk1="8/9/2008" if tgl_mulai_pmrk1=="8/9/7408"
	
	gen double audit_dt1 = date(tgl_mulai_pmrk1 ,"MDY")
	format audit_dt %td
	gen double audit_dt2 = date(tgl_mulai_pmrk1 ,"DMY")
	
	gen double audit_dt = audit_dt1
	replace audit_dt = audit_dt2 if missing(audit_dt1) 
	
	gen audit_yr = year(audit_dt)
	tab tgl_mulai_pmrk1 if missing(audit_yr) | audit_yr>2018
	
	drop tgl*
	
	ren npwp_enkripsi npwp
	
	* Masa pajak has range of audited taxes
	
	replace masapajak = "012017-072017" if masapajak=="012107-072017"
	replace masapajak = "012018-122008" if masapajak=="01S-18-122008"
	replace masapajak = "012009-122009" if masapajak=="011009-121009"
	replace masapajak = "012017-072017" if masapajak=="012107-072017"
	replace masapajak = "011992-121992" if masapajak=="011912-121912"
	replace masapajak = "012009-122009" if masapajak=="12009-122009"
	replace masapajak = "012009-122009" if masapajak=="12009-012009"
	replace masapajak = "012009-122009" if masapajak=="012009-12209"
	replace masapajak = "122013-122013" if masapajak=="122103-122013"
	replace masapajak = "123202-122007" if masapajak=="122103-122013"
	replace masapajak = "022008-112008" if masapajak=="22008-112008"
	replace masapajak = "082009-082010" if masapajak=="82009-82010"
	replace masapajak = "012012-122012" if masapajak=="002012-122012"
	replace masapajak = "122002-122007" if masapajak=="123202-122007"
	replace masapajak = "122002-122007" if masapajak=="123202-122007"
	
	replace masapajak = "012007-122007" if masapajak=="012007-12200"
	replace masapajak = "012009-122009" if masapajak=="012009-122099"
	replace masapajak = "012009-122009" if masapajak=="012009-32009"
	replace masapajak = "012015-122015" if masapajak=="012015-12215"
	
	replace masapajak = "032010-032010" if masapajak=="032010-"
	replace masapajak = "042010-042010" if masapajak=="042010-"
	replace masapajak = "052010-052010" if masapajak=="052010-"
	replace masapajak = "062009-062009" if masapajak=="062009-"
	replace masapajak = "082009-082009" if masapajak=="082009-"
	replace masapajak = "102009-102009" if masapajak=="102009-"
	replace masapajak = "112009-112009" if masapajak=="112009-"
	replace masapajak = "122008-122008" if masapajak=="122008-"
	replace masapajak = "082013-082013" if masapajak=="082013-08213"
	replace masapajak = "122009-122009" if masapajak=="122009-192009"
	replace masapajak = "012009-012009" if masapajak=="122009-"
	replace masapajak = "012009-012009" if masapajak=="012009-"
	
	foreach i in 001 002 003 004 005 006 007 008 009 010{
		replace masapajak = "012`i'-122`i'" if masapajak=="2`i'-"
	}
	forvalues i=2001/2018{
		replace masapajak = "01`i'-12`i'" if masapajak=="00`i'-00`i'"
	}
	
	split masapajak, parse("-")
	gen m1 = substr(masapajak1,1,2)	if length(masapajak1)==6
	gen y1 = substr(masapajak1,3,4)	if length(masapajak1)==6
	gen m2 = substr(masapajak2,1,2)	if length(masapajak2)==6
	gen y2 = substr(masapajak2,3,4)	if length(masapajak2)==6
	
	replace m1 = substr(masapajak1,1,2)	if length(masapajak1)==4
	replace y1 = "20"+substr(masapajak1,3,2)	if length(masapajak1)==4
	replace m2 = substr(masapajak2,1,2)	if length(masapajak2)==4
	replace y2 = "20"+substr(masapajak2,3,2)	if length(masapajak2)==4
	
	tab y1
	tab y2
	tab m1
	tab m2

	destring m1 m2 y1 y2, replace force
	
	gen double audited_month_first = ym(y1,m1)
	format audited_month_first %tm
	
	gen double audited_month_last = ym(y2,m2)
	format audited_month_last %tm
	
	tab masapajak if missing(audited_month_first) | ///
	(audited_month_first > ym(2018,06) & !missing(audited_month_first) ) | ///
	(audited_month_first < ym(1990,01) ) 
	
	tab masapajak if missing(audited_month_last) | ///
	(audited_month_last > ym(2018,06) & !missing(audited_month_last) ) | ///
	(audited_month_last < ym(1990,01) ) 

	tab audit_yr
	tab y1
	
	drop m1 m2 y1 y2 masapajak*
	
	keep npwp audit_dt audited_month_first audited_month_last a6 a4 kdpmrk4 skp* nskp*
	
	order npwp audit_dt audited_month_first audited_month_last a6 a4 kdpmrk4 skp* nskp*
	saveold "${output}/analysis/audits_clean.dta", replace
	
}


clear all
log close
