/*
All analyses are based on anonymized data
Variable "npwp" is a randomly generated taxpayer ID
*/
set seed 98765
log using "${dofile}/logs/0_4_clean_STPSKPKB_PPN.log", replace
di in red "Run 0_4_clean_STPSKPKB_PPN.do"

* Import tax type codes (KD_MAP maps this to the payments data)
preserve
	import excel using "${raw}/stp_skp_code.xlsx", clear
	keep if _n>=2
	
	ren B assessment_type_code
	ren C tax_type_des
	ren D assessment_type
	ren E tax_type_mpn
	
	
	destring tax_type_mpn, replace
	
	tempfile types
	sa `types'
restore

// * Append the two datasets received and remove the small # of duplicates between them
u "${raw}/STPSKPKB PPN/stpskp_ppn.dta", clear
append using "${raw}/STPSKPKB PPN/stpskp_ppn_skp_only.dta"
duplicates drop

*** Tax type codes (Per DGT instructions) **

gen assessment_type_code = substr(no_skp,7,3)
merge m:1 assessment_type_code using `types'
keep if _merge==1 | _merge==3
drop _merge
drop assessment_type_code

ren no_skp				assessment_letter_number
ren thpj 				tax_year
ren masa_pjk 			tax_month

tab tax_year
tab tax_month

destring tax_year tax_month, replace
replace tax_month = 12 if tax_month==112	/* 1 obs */
replace tax_month = 2 if tax_month==202
replace tax_month = 3 if tax_month==303

ren tunggakan_awal		arrears
ren nilai_wp_stj		arrears_agreed	 /* Arrears agreed by taxpayer */
ren nilai_wp_tdk_stj 	arreas_disagreed  /* Arrears disagreed by taxpayer */

ren no_srt_teguran		warning_letter_number
ren no_srt_paksa		enforcement_letter_number
ren no_lpsp				warrant_letter_number		/*  Laporan Pelaksanaan Surat Paksa */
ren no_srt_sita			confiscation_letter_number
ren no_keb				objection_letter_number
ren nil_putusan_keb		objection_verdit_value
ren no_banding			appeal_number
ren nil_banding			appeal_value
ren ssp					tax_payment_value
ren no_pk				judicial_review_number		
ren nilai_pk			judicial_review_value		/* PK - Peninjauan Kembali */

** Letter dates ***
gen assessment_letter_dt = date(substr(tgl_skp,1,10),"YMD",2000)
format assessment_letter_dt %td

// Typos in years on string date - some start with zero or 2051
replace assessment_letter_dt = mdy(month(assessment_letter_dt),day(assessment_letter_dt),tax_year+1) ///
if regexm(tgl_skp,"^0") | year(assessment_letter_dt)>2018
drop tgl_skp

gen warning_letter_dt = date(substr(tgl_srt_teguran,1,10),"YMD",2000)
format warning_letter_dt %td
drop tgl_srt_teguran

gen enforcement_letter_dt = date(substr(tgl_srt_paksa,1,10),"YMD",2000)
format enforcement_letter_dt %td
drop tgl_srt_paksa

gen warrant_letter_dt = date(substr(tgl_lpsp,1,10),"YMD",2000)
format warrant_letter_dt %td
drop tgl_lpsp

gen confiscation_letter_dt = date(substr(tgl_srt_sita,1,10),"YMD",2000)
format confiscation_letter_dt %td
drop tgl_srt_sita

gen objection_letter_dt = date(substr(tgl_keb,1,10),"YMD",2000)
format objection_letter_dt %td
drop tgl_keb

gen appeal_dt = date(substr(tgl_banding,1,10),"YMD",2000)
format appeal_dt %td
drop tgl_banding

gen judicial_review_dt = date(substr(tgl_pk,1,10),"YMD",2000)
format judicial_review_dt %td
drop tgl_pk

order npwp kpp cab 	assessment_letter_number assessment_letter_dt ///
					tax_payment_value ///
					assessment_type tax_type_des tax_type_mpn arrears* ///
					warning* enforcement* warrant* ///
					confiscation* objection* judicial* appeal* 

des
				
gen double assess_yr = year(assessment_letter_dt)
tab assess_yr
tab tax_year

destring appeal_value tax_payment_value arrears*, replace
		
saveold "${output}/analysis/stpskp_ppn_all_clean.dta", replace

clear all
log close
