* SIKKA are confidential anonymized data on DGT's employees
* NIP is the anonymized (randomly generated) employee ID
set seed 98765
log using "${dofile}/logs/0_5_clean_SIKKA.log", replace
di in red "Run 0_5_clean_SIKKA.do"

****** Toggles ******

local LK01		= 1			/*  Demographics */
local LK02		= 1			/*  Rank history */	
local LK03		= 1			/*  Position history */	
local LK03A 	= 1			/*  Change in position history */
local LK03C		= 1			/*  Change in grade history */
local LK03D 	= 1			/*  Function group history */	
local LK04		= 1			/*  Education history */
local LK16		= 1			/* DP3 history */
local NonLK		= 1			

******************************************************************
********* Understand each dataset and save clean versions ********
******************************************************************
 
**---------------------------------------------------------------------------
** LK01
**---------------------------------------------------------------------------
if `LK01' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use  "${output}/dta_raw/LK01_MIT.dta", clear
	
		duplicates tag nip, gen(dup)
		bys nip: egen max = max(dup)
		drop dup
		*br if max
		
		* Different employees with same NIP (occurs for 4 employees, 2 nips). Keep track
		ren max nip_flag
		label var nip_flag "NIP is not unique. Shared by these flagged obswevations"
		
		* Destring nip
		destring nip, replace
		sum nip
		
		* Date of birth
		gen dob = date(tanggal_lahir,"DMY",2050)
		format dob %td
		lab var dob "Date of birth (tanggal lahir)"
		
		* Some weird issues with date of birth. A few born since 2002
		gen yob = year(dob)
		tab yob
		replace dob = mdy(month(dob), day(dob),year(dob)+1000) if yob==961
		
		drop tanggal_lahir yob
		
		* Place of birth
		ren kota_lahir pob
		label var pob "Place of birth (kota lahir)"
		
		* Civil status
		gen single	 = 	(status_perkawina=="Belum Menikah")
		gen married  =	(status_perkawina=="Menikah")
		gen widow	 =	(status_perkawina=="Duda/Janda")
		drop status_perkawinan
		
		* Gender
		gen female = (jenis=="WANITA")
		drop jenis
		
		* Label
		lab var nip "NIP"
		lab var female "Gender = female"
		lab var single "Marital status = single"
		lab var married "Marital status = married"
		lab var widow "Marital status = widow"
		
		order nip dob pob female
		order *_flag, last
		
	compress
	label data "Employee Information"
	saveold "${output}/analysis/LK01_clean.dta", replace
	
}


**---------------------------------------------------------------------------
** LK02
**---------------------------------------------------------------------------
if `LK02' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use  "${output}/dta_raw/LK02_MIT.dta", clear
	unique nip tmt_pang_peg
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Date
			split tmt_pang_peg, parse(" ") gen(date_)
			gen rank_start_date = date(date_1,"MD20Y")
			format rank_start_date %td
			inspect rank_start_date
			gen rank_start_year = year(rank_start_date)
			tab rank_start_year
			sort nip rank_start_date
			// check potentially mistyped years
			* br if inrange(rank_start_year,1899,1908)
			gen flag1 = 1 if inrange(rank_start_year,1899,1908)
			by nip: egen flag2 = total(flag1)
			* br if flag2 > 0
			// no particular pattern, ignore for now
			drop tmt_pang_peg flag? date_?
			
			gen rank_start_month = month(rank_start_date)
			
			lab var rank_start_date "Rank start date"
			lab var rank_start_year "Rank start year"
			lab var rank_start_month "Rank start month"
			
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
			
		* Pangkat and Golongan (pangkat is the name of golongan)
			split nm_pangkat, parse("/") gen(golongan_)
			ren golongan_1 golongan_name
			ren golongan_2 golongan
			drop nm_pangkat
			gen     golongan_main = 1 if inlist(golongan,"Ia","Ib","Ic","Id")
			replace golongan_main = 2 if inlist(golongan,"IIa","IIb","IIc","IId")
			replace golongan_main = 3 if inlist(golongan,"IIIa","IIIb","IIIc","IIId")
			replace golongan_main = 4 if inlist(golongan,"IVa","IVb","IVc","IVd")
			lab define golongan_main 1 "I" 2 "II" 3 "III" 4 "IV"
			lab val golongan_main golongan_main
			
			gen     golongan_sorted = 1  if golongan == "Ia"
			replace golongan_sorted = 2  if golongan == "Ib"
			replace golongan_sorted = 3  if golongan == "Ic"
			replace golongan_sorted = 4  if golongan == "Id"
			replace golongan_sorted = 5  if golongan == "IIa"
			replace golongan_sorted = 6  if golongan == "IIb"
			replace golongan_sorted = 7  if golongan == "IIc"
			replace golongan_sorted = 8  if golongan == "IId"
			replace golongan_sorted = 9  if golongan == "IIIa"
			replace golongan_sorted = 10 if golongan == "IIIb"
			replace golongan_sorted = 11 if golongan == "IIIc"
			replace golongan_sorted = 12 if golongan == "IIId"
			replace golongan_sorted = 13 if golongan == "IVa"
			replace golongan_sorted = 14 if golongan == "IVb"
			replace golongan_sorted = 15 if golongan == "IVc"
			replace golongan_sorted = 16 if golongan == "IVd"
			replace golongan_sorted = 17 if golongan == "IVe"
			
			lab var golongan "Golongan"
			lab var golongan_name "Golongan name (pangkat)"
			lab var golongan_main "Main golongan code"
			lab var golongan_sorted "Golongan sorting number (1 to 17 that corresponds to Golongan Ia to IVd)"
			
		* Salary
			destring gaji_pokok_peg, gen(salary)
			lab var salary "Base salary (Gaji Pokok)"
			drop gaji_pokok_peg
			
		* Credit score
			destring jumlah_ak, gen(credit_score)
			lab var credit_score "Total credit score (Jumlah Angka Kredit - jumlah_ak)"
			drop jumlah_ak
			
		* Thn masa and bln masa
			destring thn_masa_kerja, replace
			destring bln_masa_kerja, replace
			rename thn_masa_kerja service_year
			rename bln_masa_kerja service_month
			lab var service_year "Duration of service (years)"
			lab var service_month "Duration of service (month)"
			
		* Degree
			gen     educ_degree = 1  if pendidikan == "Tk. Pddk. Sekolah Dasar (SD)/ Sederajat"
			replace educ_degree = 2  if pendidikan == "Tk. Pddk. Sekolah Pertama (SLTP) / Sederajat"
			replace educ_degree = 3  if pendidikan == "Tk. Pddk. Sekolah Menengah Umum (SMU)/ Sederajat"
			replace educ_degree = 4  if pendidikan == "Tk. Akademi (D1)"
			replace educ_degree = 5  if pendidikan == "Tk. Akademi (D2)"
			replace educ_degree = 6  if pendidikan == "Tk. Akademi (D3)"
			replace educ_degree = 7  if pendidikan == "Tk. Perguruan Tinggi (S1) / (D4)"
			replace educ_degree = 8  if pendidikan == "Tk. Pasca Sarjana (S2)"
			replace educ_degree = 9  if pendidikan == "Tk. Pasca Sarjana (S3)"
			replace educ_degree = 10 if pendidikan == "Belum ada kelompok"
			replace educ_degree = 11 if pendidikan == "Pendidikan Profesi"
			lab define educ_degree ///
				1  "Elementary (SD) / equivalent" ///
				2  "Junior secondary (SLTP) / equivalent" ///
				3  "Senior secondary (SMU) / equivalent" ///
				4  "Diploma (D1)" ///
				5  "Diploma (D2)" ///
				6  "Diploma (D3)" ///
				7  "Undergraduate (S1) / (D4)" ///
				8  "Masters (S2)" ///
				9  "Doctorate / PhD (S3)" ///
				10 "No classification (Belum ada kelompok)" ///
				11 "Professional education (Pendidikan Profesi)"
			lab val educ_degree educ_degree
			lab var educ_degree "Highest educational degree (Pendidikan)"
			drop pendidikan
			
		* Type of SK (Surat Keputusan) = type of decree (i.e. CPNS, PNS, Kepangkatan)
			gen     decree_type = 1 if jenis_sk == "CPNS"
			replace decree_type = 2 if jenis_sk == "PNS"
			replace decree_type = 3 if jenis_sk == "Kepangkatan"
			replace decree_type = 4 if jenis_sk == "Pangkat Pengabdian"
			lab define decree_type 1 "CPNS" 2 "PNS" 3 "Kepangkatan" 4 "Pangkat Pengabdian"
			lab val decree_type decree_type
			lab var decree_type "Decree based on which employee has golongan (Jenis Surat Keputusan - jenis_sk)"
			drop jenis_sk
			
		* Tidy up
			order nip rank_start_* service_* decree_type golongan_name golongan golongan_main golongan_sorted
			
	* Check for other duplicates
		unique nip rank_start_date
		
		// Check duplicates at nip, rank_start_date, decree_type, and golongan
		sort nip rank_start_date decree_type golongan
		duplicates tag nip rank_start_date decree_type golongan, gen(dup)
		by nip: egen dup2 = total(dup)
		unique nip if dup > 0
		* br if dup > 0
		sort nip rank_start_date service_year service_month
		
			// Fix duplicates
			// 1. Keep observations with longest service_year and service_month
			gen service_duration = service_year*12 + service_month
			move service_duration service_year
			* br nip rank_start_date decree_type golongan service_duration salary educ_degree credit_score dup if dup > 0
			bys nip rank_start_date decree_type golongan: gen flag1 = _N
			bys nip rank_start_date decree_type golongan service_duration: gen flag2 = _N
			gsort nip rank_start_date decree_type golongan -service_duration
			by nip rank_start_date decree_type golongan: gen flag3 = _n
			drop if flag1 == 2 & flag2 == 1 & flag3 == 2
			drop service_duration flag?
			
			// 2. Keep observations with non-missing education
			* br nip rank_start_date decree_type golongan salary educ_degree credit_score dup if dup > 0
			bys nip rank_start_date decree_type golongan: gen flag1 = _N
			bys nip rank_start_date decree_type golongan educ_degree: gen flag2 = _N
			sort nip rank_start_date decree_type golongan educ_degree
			* br nip rank_start_date decree_type golongan salary educ_degree credit_score dup flag1 flag2 if flag1 > 1
			drop if flag1 == 2 & flag2 == 1 & educ_degree == .
			drop flag?
				// check
				bys nip rank_start_date decree_type golongan: gen flag1 = _N
				bys nip rank_start_date decree_type golongan educ_degree: gen flag2 = _N
				tab flag1 flag2
				drop flag?
				// OK, all duplicates obs with missing education have been dropped
				
			// 3. Keep observations with highest non-missing salary
			* br nip rank_start_date decree_type golongan salary educ_degree credit_score dup if dup > 0
			bys nip rank_start_date decree_type golongan: gen flag1 = _N
			bys nip rank_start_date decree_type golongan salary: gen flag2 = _N
			gsort nip rank_start_date decree_type golongan -salary
			* br nip rank_start_date decree_type golongan salary educ_degree credit_score dup flag1 flag2 if flag1 > 1
			by nip rank_start_date decree_type golongan: gen flag3 = _n
			drop if flag1 == 2 & flag2 == 1 & flag3 == 2
			drop flag?
			
			// Check if there's still more duplicates
			drop dup dup2
			bys nip rank_start_date decree_type golongan: gen flag1 = _N
			assert flag1 == 1
			drop flag1
			// All duplicates in terms of nip rank_start_date decree_type golongan have been addressed
			
		// Check duplicates at nip - rank_start_date level
		sort nip rank_start_date
		duplicates tag nip rank_start_date, gen(dup)
		by nip: egen dup2 = total(dup)
		unique nip if dup > 0
		* br if dup2 > 0
		* br if dup > 0
		// Some of the obs with same NIP and start date have different SK and/or golongan
		drop dup dup2
		
			// Fix duplicates
			// 1. Keep observations with highest decree_type and golongan
			sort nip rank_start_date decree_type golongan_sorted
			by nip rank_start_date: gen flag1 = _N
			by nip rank_start_date: gen flag2 = _n
			drop if flag1 == 2 & flag2 == 1
			* br if flag1 == 3
			drop if flag1 == 3 & inlist(flag2,1,2)
			drop flag?
			
			// check
			by nip rank_start_date: gen flag1 = _N
			tab flag1
			assert flag1 == 1
			drop flag1
		
	* Save
		sort nip rank_start_date
		compress
		label data "Rank History"
		saveold "${output}/analysis/LK02_clean.dta", replace
		
}

**---------------------------------------------------------------------------
** LK03
**---------------------------------------------------------------------------
if `LK03' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use  "${output}/dta_raw/LK03_MIT.dta", clear
	unique nip terhitung_mulai_tanggal
	sort nip terhitung_mulai_tanggal
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Date
			split terhitung_mulai_tanggal, parse(" ") gen(date_)
			gen position_start_date = date(date_1,"MD20Y")
			format position_start_date %td
			inspect position_start_date
			gen position_start_year = year(position_start_date)
			tab position_start_year
			sort nip position_start_date
			// check potentially mistyped years
			* br if position_start_year == 1900
			gen flag1 = 1 if position_start_year == 1900
			by nip: egen flag2 = total(flag1)
			* br if flag2 > 0
			// it seems that 1990 or 2000 are mistyped to 1900, ignore for now
			drop terhitung_mulai_tanggal flag? date_?
			
			lab var position_start_date "Position starting date"
			lab var position_start_year "Position starting year"
			
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
			
		* Issued by
			encode diterbitkan_oleh, gen(issued_by)
			lab var issued_by "Unit that issued the decree"
			
		* Eselon
			rename eselon_ii eselon_2
			lab var eselon_2 "Unit name (eselon II)"
			rename nama_kantor eselon_3
			lab var eselon_3 "Office name (eselon III)"
			
		* Golongan
			split pangkat, parse("/") gen(golongan_)
			ren golongan_1 golongan_name
			ren golongan_2 golongan
			drop pangkat
			gen     golongan_main = 1 if inlist(golongan,"Ia","Ib","Ic","Id")
			replace golongan_main = 2 if inlist(golongan,"IIa","IIb","IIc","IId")
			replace golongan_main = 3 if inlist(golongan,"IIIa","IIIb","IIIc","IIId")
			replace golongan_main = 4 if inlist(golongan,"IVa","IVb","IVc","IVd")
			lab define golongan_main 1 "I" 2 "II" 3 "III" 4 "IV"
			lab val golongan_main golongan_main
			
			gen     golongan_sorted = 1  if golongan == "Ia"
			replace golongan_sorted = 2  if golongan == "Ib"
			replace golongan_sorted = 3  if golongan == "Ic"
			replace golongan_sorted = 4  if golongan == "Id"
			replace golongan_sorted = 5  if golongan == "IIa"
			replace golongan_sorted = 6  if golongan == "IIb"
			replace golongan_sorted = 7  if golongan == "IIc"
			replace golongan_sorted = 8  if golongan == "IId"
			replace golongan_sorted = 9  if golongan == "IIIa"
			replace golongan_sorted = 10 if golongan == "IIIb"
			replace golongan_sorted = 11 if golongan == "IIIc"
			replace golongan_sorted = 12 if golongan == "IIId"
			replace golongan_sorted = 13 if golongan == "IVa"
			replace golongan_sorted = 14 if golongan == "IVb"
			replace golongan_sorted = 15 if golongan == "IVc"
			replace golongan_sorted = 16 if golongan == "IVd"
			replace golongan_sorted = 17 if golongan == "IVe"
			
			lab var golongan "Golongan"
			lab var golongan_name "Golongan name (pangkat)"
			lab var golongan_main "Main golongan code"
			lab var golongan_sorted "Golongan sorting number (1 to 17 that corresponds to Golongan Ia to IVd)"
			
		* Position
			tab jenis_jabatan
			gen     position_type = 1 if jenis_jabatan == "Struktural"
			replace position_type = 2 if jenis_jabatan == "Fungsional"
			lab define position_type 1 "Struktural" 2 "Fungsional"
			lab val position_type position_type
			lab var position_type "Type of position (structural / functional)"
			
			rename unit_organisasi structural_organization
			rename jabatan_struktural structural_position
			rename grup_fungsional functional_group
			rename jabatan_fungsional functional_position
			
			lab var structural_organization "Structural position organization name (eselon IV)"
			lab var structural_position "Structural position name"
			lab var functional_group "Functional position group"
			lab var functional_position "Functional position name"
			
			gen     functional_role_in_team = 1 if posisi_di_kelompok == "Anggota"
			replace functional_role_in_team = 2 if posisi_di_kelompok == "Ketua Tim"
			replace functional_role_in_team = 2 if posisi_di_kelompok == "Supervisor /Ketua Kelompok"
			lab define functional_role_in_team 1 "Team member (anggota)" 2 "Team leader (ketua tim)" 3 "Supervisor/group leader (supervisor/ketua kelompok)"
			lab val functional_role_in_team functional_role_in_team
			lab var functional_role_in_team "Position in the team (only for tax auditor functional position)"
			
		* Tidy up
			order nip position_* issued_by eselon_? structural_* functional_*
			keep nip position_* issued_by eselon_? structural_* functional_* golongan*
			
	* Check for other duplicates
		unique nip position_start_date
		
		// Check duplicates at nip position_start_date
		bys nip position_start_date: gen flag1 = _N
		* br if flag1 > 1
		
		// Check duplicates at nip position_start_date issued_by
		bys nip position_start_date issued_by: gen flag2 = _N
		* br if flag2 > 1
		* br if flag1 != flag2
		
		bys nip position_start_date issued_by functional_group: gen flag3 = _N
		* br if flag2 != flag3
		
		/*
		On the same date, staff can be assigned to more than 1 new:
			- position_type
			- structural_organization
			- structural_position
			- functional_position
			- functional_role_in_team
			- golongan
		
		*/
		
		// leave duplicates as it is for now
		drop flag?
		
	* Save
		sort nip position_start_date issued_by golongan
		compress
		label data "Position History"
		saveold "${output}/analysis/LK03_clean.dta", replace
		
}

**---------------------------------------------------------------------------
** LK03A
**---------------------------------------------------------------------------
if `LK03A' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use  "${output}/dta_raw/LK03A_MIT.dta", clear
	unique nip terhitung_mulai_tanggal
	sort nip terhitung_mulai_tanggal
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Date
			split terhitung_mulai_tanggal, parse(" ") gen(date_)
			gen position_start_date = date(date_1,"DM20Y")
			format position_start_date %td
			inspect position_start_date
			gen position_start_year = year(position_start_date)
			tab position_start_year
			sort nip position_start_date
			// year looks OK
			drop terhitung_mulai_tanggal date_?
			
			lab var position_start_date "Position starting date"
			lab var position_start_year "Position starting year"
			
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
			
		* Golongan
			split pangkat, parse("/") gen(golongan_)
			ren golongan_1 golongan_name
			ren golongan_2 golongan
			drop pangkat
			gen     golongan_main = 1 if inlist(golongan,"Ia","Ib","Ic","Id")
			replace golongan_main = 2 if inlist(golongan,"IIa","IIb","IIc","IId")
			replace golongan_main = 3 if inlist(golongan,"IIIa","IIIb","IIIc","IIId")
			replace golongan_main = 4 if inlist(golongan,"IVa","IVb","IVc","IVd")
			lab define golongan_main 1 "I" 2 "II" 3 "III" 4 "IV"
			lab val golongan_main golongan_main
			
			gen     golongan_sorted = 1  if golongan == "Ia"
			replace golongan_sorted = 2  if golongan == "Ib"
			replace golongan_sorted = 3  if golongan == "Ic"
			replace golongan_sorted = 4  if golongan == "Id"
			replace golongan_sorted = 5  if golongan == "IIa"
			replace golongan_sorted = 6  if golongan == "IIb"
			replace golongan_sorted = 7  if golongan == "IIc"
			replace golongan_sorted = 8  if golongan == "IId"
			replace golongan_sorted = 9  if golongan == "IIIa"
			replace golongan_sorted = 10 if golongan == "IIIb"
			replace golongan_sorted = 11 if golongan == "IIIc"
			replace golongan_sorted = 12 if golongan == "IIId"
			replace golongan_sorted = 13 if golongan == "IVa"
			replace golongan_sorted = 14 if golongan == "IVb"
			replace golongan_sorted = 15 if golongan == "IVc"
			replace golongan_sorted = 16 if golongan == "IVd"
			replace golongan_sorted = 17 if golongan == "IVe"
			
			lab var golongan "Golongan"
			lab var golongan_name "Golongan name (pangkat)"
			lab var golongan_main "Main golongan code"
			lab var golongan_sorted "Golongan sorting number (1 to 17 that corresponds to Golongan Ia to IVd)"
			
		* Position
			rename grup_fungsional functional_group
			rename jabatan_fungsional functional_position
			rename keterangan_ralat notes_for_correction
			
			lab var functional_group "Functional position group"
			lab var functional_position "Functional position name"
			lab var notes_for_correction "Notes for any correction"
			
		* Tidy up
			order nip position_* functional_* golongan_name golongan golongan_main golongan_sorted notes_for_correction
			keep nip position_* functional_* golongan_name golongan golongan_main golongan_sorted notes_for_correction
			
	* Save
		sort nip position_start_date
		unique nip position_start_date
		compress
		label data "Change in Position History (for functional position only)"
		saveold "${output}/analysis/LK03A_clean.dta", replace
		
}

**---------------------------------------------------------------------------
** LK03C
**---------------------------------------------------------------------------
if `LK03C' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use  "${output}/dta_raw/LK03C_MIT.dta", clear
	unique nip tmt_jab_grade
	sort nip tmt_jab_grade
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Date
			split tmt_jab_grade, parse(" ") gen(date_)
			gen grade_start_date = date(date_1,"DM20Y")
			format grade_start_date %td
			inspect grade_start_date
			
				// fix some dates
				* br if grade_start_date == .
				split date_1, parse("/") gen(fix_)
				destring fix_?, replace force
				* br if fix_3 != .
				replace fix_3 = 2000 + fix_3 if fix_3 <= 10
				replace fix_3 = 2001 if fix_3 == 201
				replace fix_3 = 2007 if fix_3 == 207
				replace fix_3 = 2008 if fix_3 == 208
				* br if grade_start_date == .
				replace grade_start_date = mdy(fix_1, fix_2, fix_3) if fix_3 != .
				inspect grade_start_date
				drop fix_?
				
			gen grade_start_year = year(grade_start_date)
			tab grade_start_year
			sort nip grade_start_date
			// year looks good
			drop tmt_jab_grade date_?
			
			lab var grade_start_date "Grade start date"
			lab var grade_start_year "Grade start year"
			
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
			
		* Eselon
			rename eselon_ii eselon_2
			lab var eselon_2 "Unit name (eselon II)"
			rename kantor eselon_3
			lab var eselon_3 "Office name (eselon III)"
			rename unit_organisasi organization_unit
			lab var organization_unit "Organization unit"
			
		* Peringkat
			destring peringkat, replace
			rename peringkat grade
			lab var grade "Grade (peringkat)"
			
		* Tidy up
			order nip grade_* eselon_*
			
	* Check for other duplicates
		
		
	* Save
		sort nip grade_start_date
		unique nip grade_start_date
		compress
		label data "Change in Grade History"
		saveold "${output}/analysis/LK03C_clean.dta", replace
		
}

**---------------------------------------------------------------------------
** LK03D
**---------------------------------------------------------------------------
if `LK03D' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use "${output}/dta_raw/LK03D_MIT.dta", clear
	unique nip terhitung_mulai_tanggal
	sort nip terhitung_mulai_tanggal
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Date
			split terhitung_mulai_tanggal, parse(" ") gen(date_)
			gen functional_start_date = date(date_1,"DM20Y")
			format functional_start_date %td
			inspect functional_start_date
			
				// fix some dates
				* br if functional_start_date == .
				split date_1, parse("/") gen(fix_)
				destring fix_?, replace force
				* br if fix_3 != .
				replace fix_3 = 2000 + fix_3 if fix_3 <= 10
				* br if functional_start_date == .
				replace functional_start_date = mdy(fix_1, fix_2, fix_3) if fix_3 != .
				inspect functional_start_date
				drop fix_?
				
			gen functional_start_year = year(functional_start_date)
			tab functional_start_year
			sort nip functional_start_date
			// year looks good
			drop terhitung_mulai_tanggal date_?
			
			lab var functional_start_date "Functional start date"
			lab var functional_start_year "Functional start year"
			
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
			
		* Kanwil
			rename kanwil regional_office
			rename nama_kantor regional_office_name
			
			lab var regional_office "Regional office"
			lab var regional_office_name "Regional office name"
			
		* Position
			gen     functional_role_in_team = 1 if nama_jabatan_kelompok == "Anggota"
			replace functional_role_in_team = 2 if nama_jabatan_kelompok == "Ketua Tim"
			replace functional_role_in_team = 2 if nama_jabatan_kelompok == "Ketua Kelompok"
			lab define functional_role_in_team 1 "Team member (anggota)" 2 "Team leader (ketua tim)" 3 "Supervisor/group leader (ketua kelompok)"
			lab val functional_role_in_team functional_role_in_team
			lab var functional_role_in_team "Position in the team (only for tax auditor functional position)"
			
		* Others
			destring nomor_kelompok, gen(group_number)
			destring nomor_tim, gen(team_number)
			drop nomor_kelompok nomor_tim
			
			lab var group_number "Group number"
			lab var team_number "Team number"
			
		* Tidy up
			order nip functional_start_* 
			
	* Check for other duplicates
		
		
	* Save
		sort nip functional_start_date
		unique nip functional_start_date
		compress
		label data "Functional Group History"
		saveold "${output}/analysis/LK03D_clean.dta", replace
		
}

**---------------------------------------------------------------------------
** LK04
**---------------------------------------------------------------------------
if `LK04' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use "${output}/dta_raw/LK04_MIT.dta", clear
	unique nip tanggal_ijasah_sertifikat
	sort nip tanggal_ijasah_sertifikat
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Date
			split tanggal_ijasah_sertifikat, parse(" ") gen(date_)
			gen certificate_date = date(date_1,"DM20Y")
			format certificate_date %td
			inspect certificate_date
			
				// fix some dates
				* br if certificate_date == . & tanggal_ijasah_sertifikat != ""
				// OK - missing date is because missing tanggal_ijasah_sertifikat
				
			gen certificate_year = year(certificate_date)
			tab certificate_year
			// some years in 1900
			drop tanggal_ijasah_sertifikat date_?
			sort nip certificate_date
			
			lab var certificate_date "Certificate date"
			lab var certificate_year "Certificate year"
			
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
		
		* Education
			gen     educ_degree = 1  if jenis_pendidikan == "Tk. Pddk. Sekolah Dasar (SD)/ Sederajat"
			replace educ_degree = 2  if jenis_pendidikan == "Tk. Pddk. Sekolah Pertama (SLTP) / Sederajat"
			replace educ_degree = 3  if jenis_pendidikan == "Tk. Pddk. Sekolah Menengah Umum (SMU)/ Sederajat"
			replace educ_degree = 4  if jenis_pendidikan == "Tk. Akademi (D1)"
			replace educ_degree = 5  if jenis_pendidikan == "Tk. Akademi (D2)"
			replace educ_degree = 6  if jenis_pendidikan == "Tk. Akademi (D3)"
			replace educ_degree = 7  if jenis_pendidikan == "Tk. Perguruan Tinggi (S1) / (D4)"
			replace educ_degree = 8  if jenis_pendidikan == "Tk. Pasca Sarjana (S2)"
			replace educ_degree = 9  if jenis_pendidikan == "Tk. Pasca Sarjana (S3)"
			replace educ_degree = 10 if jenis_pendidikan == "Belum ada kelompok"
			replace educ_degree = 11 if jenis_pendidikan == "Pendidikan Profesi"
			lab define educ_degree ///
				1  "Elementary (SD) / equivalent" ///
				2  "Junior secondary (SLTP) / equivalent" ///
				3  "Senior secondary (SMU) / equivalent" ///
				4  "Diploma (D1)" ///
				5  "Diploma (D2)" ///
				6  "Diploma (D3)" ///
				7  "Undergraduate (S1) / (D4)" ///
				8  "Masters (S2)" ///
				9  "Doctorate / PhD (S3)" ///
				10 "No classification (Belum ada kelompok)" ///
				11 "Professional education (jenis_pendidikan Profesi)"
			lab val educ_degree educ_degree
			lab var educ_degree "Highest educational degree (jenis_pendidikan)"
			drop jenis_pendidikan
			
			rename pendidkan educ_program
			rename nama_lembaga_pendidikan educ_name
			lab var educ_program "Education program"
			lab var educ_name "School / university name"
			
			tab gelar
			drop gelar // no observation
			
			rename nomor_ijasah_sertifikat certificate_number
			lab var certificate_number "Certificate number"
			
			gen     educ_fund = 1 if biaya_belajar == "Biaya Sendiri"
			replace educ_fund = 2 if biaya_belajar == "Tugas Belajar"
			replace educ_fund = 3 if biaya_belajar == "Lain-Lain"
			lab define educ_fund 1 "Self-financed (biaya sendiri)" 2 "Scholarship (tugas belajar)" 3 "Others (lain-lain)"
			lab val educ_fund educ_fund
			lab var educ_fund "Source of fund for study"
			drop biaya_belajar
			
		* Tidy up
			order nip certificate_date certificate_year certificate_number educ_degree
			
	* Check for other duplicates
		bys nip certificate_date certificate_number: gen flag1 = _N
		// XXX create wide data by educ_funding
		// XXX drop duplicates by nip certificate_date educ_degree
		
	* Save
		sort nip certificate_date
		unique nip certificate_date
		compress
		label data "Formal Education History"
		saveold "${output}/analysis/LK04_clean.dta", replace
		
}
**---------------------------------------------------------------------------
** LK16
**---------------------------------------------------------------------------
if `LK16' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use "${output}/dta_raw/LK16_MIT.dta", clear
	unique nip thn_dp3
	sort nip thn_dp3
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
			
		* DP3
			destring thn_dp3-total_dp3, replace
			rename thn_dp3 dp3_year
			
			lab var dp3_year "DP3 year"
			lab var kesetiaan "Loyalty"
			lab var prestasi_kerja "Work performance"
			lab var tanggung_jawab "Responsibility"
			lab var ketaatan "Obedience"
			lab var kejujuran "Honesty"
			lab var kerjasama "Cooperation"
			lab var prakarsa "Initiative"
			lab var kepemimpinan "Leadership"
			lab var total_dp3 "Total DP3 score"
			
		* Tidy up
			
	* Check for other duplicates
		// no duplicates
		
	* Save
		sort nip dp3_year
		unique nip dp3_year
		compress
		label data "DP3 History"
		saveold "${output}/analysis/LK16_clean.dta", replace
		
}
**---------------------------------------------------------------------------
** NonLK
**---------------------------------------------------------------------------
if `NonLK' == 1 {	
	set seed 98765
	set sortseed 12345
	
	use "${output}/dta_raw/NONLK_KeaktifanPegawai_MIT.dta", clear
	unique nip tmt_pensiun_tidak_aktif
	sort nip tmt_pensiun_tidak_aktif
	
	* Drop true duplicates
		duplicates drop
		
	* Clean data
		* Destring nip
			destring nip, replace
			lab var nip "NIP"
			su nip
			
		* Status
			gen     active_duty_status = 1 if status_keaktifan == "Aktif"
			replace active_duty_status = 2 if status_keaktifan == "Tidak Aktif"
			lab define active_duty_status 1 "Active" 2 "Inactive"
			lab val active_duty_status active_duty_status
			lab var active_duty_status "Active duty status (active/inactive)"
			
			gen     inactive_type = 1 if jenis_status_ketidakatifan == "Tetap"
			replace inactive_type = 2 if jenis_status_ketidakatifan == "Sementara"
			replace inactive_type = 3 if jenis_status_ketidakatifan == "Re-Aktif"
			lab define inactive_type 1 "Permanent (tetap)" 2 "Temporary (sementara)" 3 "Re-active (re-aktif)"
			lab val inactive_type inactive_type
			lab var inactive_type "Inactive duty type"
			
			rename status_keaktifan2 inactive_status
			lab var inactive_status "Inactive duty status"
			
			rename keterangan_pensiun inactive_notes
			
			drop status_keaktifan jenis_status_ketidakatifan
			
		* Date
			split tmt_pensiun_tidak_aktif, parse("/") gen(date_)
			destring date_?, replace
			tab date_3
			tab tmt_pensiun_tidak_aktif if date_3 == 11
			tab tmt_pensiun_tidak_aktif if date_3 == 12
			tab tmt_pensiun_tidak_aktif if date_3 == 1900
			tab tmt_pensiun_tidak_aktif if date_3 == 1901
			replace date_3 = 2011 if date_3 == 11
			replace date_3 = 2012 if date_3 == 12
			replace date_3 = . if inlist(date_3,1900,1901)
			
			gen inactive_date = mdy(date_2, date_1, date_3)
			format inactive_date %td
			inspect inactive_date
			tab tmt_pensiun_tidak_aktif if inactive_date == ., m
			// OK
			drop date_? tmt_pensiun_tidak_aktif
			
			gen inactive_year = year(inactive_date)
			
			lab var inactive_date "Inactive date"
			lab var inactive_year "Inactive year"
			
		* Tidy up
			order nip active_duty_status inactive_type inactive_status inactive_date inactive_year inactive_notes
			
	* Check for other duplicates
		duplicates drop nip active_duty_status inactive_type inactive_status inactive_date, force
		
		sort nip inactive_date
		by nip inactive_date: gen flag1 = _N
		tab flag1
		* br if flag1 > 1
		by nip inactive_date: gen flag2 = _n
		drop if flag1 == 2 & flag2 == 2
		drop flag*
		
	* Save
		sort nip inactive_date
		unique nip inactive_date
		compress
		label data "Non LK Keaktifan Pegawai"
		save "${output}/analysis/LKnon_clean.dta", replace
		
}

clear
log close
