* SIKKA are confidential anonymized data on DGT's employees
* NIP is the anonymized (randomly generated) employee ID
set seed 98765
log using "${dofile}/logs/0_6_SIKKA_panels.log", replace
di in red "Run 0_6_SIKKA_panels.do"

**---------------------------------------------------------------------------
** Set toggles
**---------------------------------------------------------------------------

local template 		= 1
local create_panels = 1

	local lk01		= 1			/* Demographics */
	local lk02		= 1			/* Rank history */
	local lk03		= 1			/* Position history */	
	local lk03A 	= 1			/* Change in position history */
	local lk03C		= 1			/* Change in grade history */
	local lk03D 	= 1			/* Function group history */
	local lk04		= 1			/* Education */
	local NonLK		= 1			/* Status */
	
local combine_panels = 1
			

set seed 98765
set sortseed 12345

	**---------------------------------------------------------------------------
	** Create template data
	**---------------------------------------------------------------------------

if `template'==1{

* Create template data at the NIP, start year, start month level
* Create unique NIP
	use "${output}/analysis/LK01_clean.dta", clear
	unique nip
	sort nip dob
	by nip: keep if _n == 1
	isid nip
	keep nip
	saveold "${output}/temp_data/LK_nip_list", replace
	
* Expand by 15 years * 12 month (2002-2016)
	qui forvalues y = 2002/2016 {
		noi di "year = `y'"
		forvalues m = 1/12 {
			use "${output}/temp_data/LK_nip_list", clear
			gen year = `y'
			gen month = `m'
			tempfile data_`y'_`m'
			saveold `data_`y'_`m'', replace
		}
	}
	
	qui forvalues y = 2002/2016 {
		noi di "year = `y'"
		forvalues m = 1/12 {
			if `y' == 2002 & `m' == 1 {
				use `data_`y'_`m'', clear
			}
			else {
				append using `data_`y'_`m''
			}
		}
	}
	
	sort nip year month
	saveold "${output}/temp_data/LK_nip_balanced_panel", replace
}

	**---------------------------------------------------------------------------
	** Create balanced panel data from historical SIKKA datasets
	**---------------------------------------------------------------------------

if `create_panels'==1{

	* LK02 - Rank history
	if `lk02' == 1 {
		// drop NIP that are only available in template data
		local data "${output}/analysis/LK02_clean.dta"
		local start_date = "rank_start_date"
		
		use "${output}/temp_data/LK_nip_list", clear
		merge 1:m nip using `data'
		keep if _m == 1
		keep nip
		merge 1:m nip using "${output}/temp_data/LK_nip_balanced_panel"
		drop if _m == 3
		drop _m
		tempfile nip_panel
		saveold `nip_panel', replace
		
		use `data', clear
		rename rank_start_year year
		rename rank_start_month month
		
		// there are some duplicates at the nip, year, month level
		// keep the latest obs based on `start_date'
		gsort nip year month -`start_date'
		by nip year month: gen flag = _N
		tab flag
		by nip year month: keep if _n == 1
		drop flag
		tempfile a1
		saveold `a1', replace
		
		// combine with NIP, year, month level data
		use `nip_panel', clear
		merge 1:m nip year month using `a1'
		
		// keep last observation before 2002
		tempfile a2
		saveold `a2', replace
		
		keep if _m == 2
		assert year < 2002
		gsort nip -`start_date'
		by nip: keep if _n == 1
		tempfile a3
		saveold `a3', replace
		
		use `a2', clear
		drop if _m == 2
		append using `a3'
		
		// replace missing values by copying previous non-missing values downward by NIP (cascade effect)
		sort nip year month
		ds nip year month _m, not
		qui foreach x of varlist `r(varlist)' {
			local type1: type `x'
			local type2 = substr("`type1'",1,3)
			if "`type2'" != "str" {
				noi di "Numeric : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == .
			}
			else {
				noi di "String  : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == ""
			}
		}
		
		// drop last observation before 2002
		drop if _m == 2
		drop _m
		
		// assert that there are no NIP with missing data for all year-month
		gen flag1 = `start_date' != .
		egen flag2 = total(flag1), by(nip)
		assert flag2 != 0
		drop flag?
		
		// assert balance panel data (12 months * 15 years = 180)
		count
		local n = r(N)
		assert mod(`n',180) == 0
		
		compress
		saveold "${output}/analysis/LK02_panel.dta", replace
	}		
	
	if `lk03' == 1 {
		// drop NIP that are only available in template data
		local data "${output}/analysis/LK03_clean.dta"
		local start_date = "position_start_date"
		
		* Data check: consistency between structural and functional position
			use `data', clear
			tab structural_position if position_type == 2
			// OK, all functional_group == "" for structural staffs
			
			tab structural_organization if position_type == 2
			replace structural_organization = "" if position_type == 2 & structural_organization != ""
			
			tab functional_group if position_type == 1
			tab functional_position if position_type == 1
			tab functional_role_in_team if position_type == 1
			replace functional_group = "" if position_type == 1 & functional_group != ""
			replace functional_position = "" if position_type == 1 & functional_position != ""
			replace functional_role_in_team = . if position_type == 1 & functional_role_in_team != .
			
		* Add value label
			foreach x of varlist structural_position functional_group functional_position {
				rename `x' `x'_
				encode `x'_, gen(`x')
				numlabel `x', add
				drop `x'_
			}
			
			tempfile data
			saveold `data', replace
			
		use "${output}/temp_data/LK_nip_list", clear
		merge 1:m nip using `data'
		keep if _m == 1
		keep nip
		merge 1:m nip using "${output}/temp_data/LK_nip_balanced_panel"
		drop if _m == 3
		drop _m
		tempfile nip_panel
		saveold `nip_panel', replace
		
		use `data', clear
		rename position_start_year year
		gen month = month(`start_date')
		
		// there are some duplicates at the nip, year, month level
		// keep the latest obs based on golongan and `start_date'
		gsort nip year month -golongan_sorted -`start_date'
		by nip year month: gen flag = _N
		tab flag
		by nip year month: keep if _n == 1
		drop flag
		tempfile a1
		saveold `a1', replace
		
		// combine with NIP, year, month level data
		use `nip_panel', clear
		merge 1:m nip year month using `a1'
		
		// keep last observation before 2002
		tempfile a2
		saveold `a2', replace
		
		keep if _m == 2
		gsort nip -`start_date'
		by nip: keep if _n == 1
		tempfile a3
		saveold `a3', replace
		
		use `a2', clear
		drop if _m == 2
		append using `a3'
		
		// replace missing values by copying previous non-missing values downward by NIP (cascade effect)
		sort nip year month
		ds nip year month _m, not
		qui foreach x of varlist `r(varlist)' {
			local type1: type `x'
			local type2 = substr("`type1'",1,3)
			if "`type2'" != "str" {
				noi di "Numeric : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == .
			}
			else {
				noi di "String  : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == ""
			}
		}
		
		// drop last observation before 2002
		drop if _m == 2
		drop _m
		
		// assert that there are no NIP with missing data for all year-month
		gen flag1 = `start_date' != .
		egen flag2 = total(flag1), by(nip)
		assert flag2 != 0
		drop flag?
		
		// assert balance panel data (12 months * 15 years = 180)
		count
		local n = r(N)
		assert mod(`n',180) == 0
		
		* fixes
			// Consistency between structural and functional position.
			// New panel data might not be consistent due to the way the panel data was created
			// using cascade effect to replace missing value with previous observations
			
			replace structural_position = . if position_type == 2
			replace structural_organization = "" if position_type == 2
			
			replace functional_group = . if position_type == 1
			replace functional_position = . if position_type == 1
			replace functional_role_in_team = . if position_type == 1
			
		compress
		saveold "${output}/analysis/LK03_panel.dta", replace
	}
	
* LK03A - Position history (for functional staffs)
	if `lk03A' == 1 {
		// drop NIP that are only available in template data
		local data "${output}/analysis/LK03A_clean.dta"
		local start_date = "position_start_date"
		
		* Add value label
			use `data', clear
			foreach x of varlist functional_group functional_position {
				rename `x' `x'_
				encode `x'_, gen(`x')
				numlabel `x', add
				drop `x'_
			}
			
			tempfile data
			saveold `data', replace
			
		use "${output}/temp_data/LK_nip_list", clear
		merge 1:m nip using `data'
		keep if _m == 1
		keep nip
		merge 1:m nip using "${output}/temp_data/LK_nip_balanced_panel"
		drop if _m == 3
		drop _m
		tempfile nip_panel
		saveold `nip_panel', replace
		
		use `data', clear
		rename position_start_year year
		gen month = month(`start_date')
		
		// there are some duplicates at the nip, year, month level
		// keep the latest obs based on golongan and `start_date'
		gsort nip year month -golongan_sorted -`start_date'
		by nip year month: gen flag = _N
		tab flag
		by nip year month: keep if _n == 1
		drop flag
		tempfile a1
		saveold `a1', replace
		
		// combine with NIP, year, month level data
		use `nip_panel', clear
		merge 1:m nip year month using `a1'
		
		// keep last observation before 2002
		tempfile a2
		saveold `a2', replace
		
		keep if _m == 2
		gsort nip -`start_date'
		by nip: keep if _n == 1
		tempfile a3
		saveold `a3', replace
		
		use `a2', clear
		drop if _m == 2
		append using `a3'
		
		// replace missing values by copying previous non-missing values downward by NIP (cascade effect)
		sort nip year month
		ds nip year month _m, not
		qui foreach x of varlist `r(varlist)' {
			local type1: type `x'
			local type2 = substr("`type1'",1,3)
			if "`type2'" != "str" {
				noi di "Numeric : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == .
			}
			else {
				noi di "String  : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == ""
			}
		}
		
		// drop last observation before 2002
		drop if _m == 2
		drop _m
		
		// assert that there are no NIP with missing data for all year-month
		gen flag1 = `start_date' != .
		egen flag2 = total(flag1), by(nip)
		assert flag2 != 0
		drop flag?
		
		// assert balance panel data (12 months * 15 years = 180)
		count
		local n = r(N)
		assert mod(`n',180) == 0
		
		compress
		saveold "${output}/analysis/LK03A_panel.dta", replace
	}
	
* LK03C - Grade history
	if `lk03C' == 1 {
		// drop NIP that are only available in template data
		local data "${output}/analysis/LK03C_clean.dta"
		local start_date = "grade_start_date"
		
		use "${output}/temp_data/LK_nip_list", clear
		merge 1:m nip using `data'
		keep if _m == 1
		keep nip
		merge 1:m nip using "${output}/temp_data/LK_nip_balanced_panel"
		drop if _m == 3
		drop _m
		tempfile nip_panel
		saveold `nip_panel', replace
		
		use `data', clear
		rename grade_start_year year
		gen month = month(`start_date')
		
		// there are some duplicates at the nip, year, month level
		// keep the latest obs based on `start_date'
		gsort nip year month -`start_date'
		by nip year month: gen flag = _N
		tab flag
		by nip year month: keep if _n == 1
		drop flag
		tempfile a1
		saveold `a1', replace
		
		// combine with NIP, year, month level data
		use `nip_panel', clear
		merge 1:m nip year month using `a1'
		
		// keep last observation before 2002
		tempfile a2
		saveold `a2', replace
		
		keep if _m == 2
		gsort nip -`start_date'
		by nip: keep if _n == 1
		tempfile a3
		saveold `a3', replace
		
		use `a2', clear
		drop if _m == 2
		append using `a3'
		
		// replace missing values by copying previous non-missing values downward by NIP (cascade effect)
		sort nip year month
		ds nip year month _m, not
		qui foreach x of varlist `r(varlist)' {
			local type1: type `x'
			local type2 = substr("`type1'",1,3)
			if "`type2'" != "str" {
				noi di "Numeric : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == .
			}
			else {
				noi di "String  : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == ""
			}
		}
		
		// drop last observation before 2002
		drop if _m == 2
		drop _m
		
		// assert that there are no NIP with missing data for all year-month
		gen flag1 = `start_date' != .
		egen flag2 = total(flag1), by(nip)
		* assert flag2 != 0
		// assertion is false because there are some obs with missing `start_date', drop NIP with all missing data
		drop if flag2 == 0
		drop flag?
		
		// assert balance panel data (12 months * 15 years = 180)
		count
		local n = r(N)
		assert mod(`n',180) == 0
		
		compress
		saveold "${output}/analysis/LK03C_panel.dta", replace
	}
	
* LK03D - Functional group history
	if `lk03D' == 1 {
		// drop NIP that are only available in template data
		local data "${output}/analysis/LK03D_clean.dta"
		local start_date = "functional_start_date"
		
		use "${output}/temp_data/LK_nip_list", clear
		merge 1:m nip using `data'
		keep if _m == 1
		keep nip
		merge 1:m nip using "${output}/temp_data/LK_nip_balanced_panel"
		drop if _m == 3
		drop _m
		tempfile nip_panel
		saveold `nip_panel', replace
		
		use `data', clear
		rename functional_start_year year
		gen month = month(`start_date')
		
		// there are some duplicates at the nip, year, month level
		// keep the latest obs based on `start_date'
		gsort nip year month -`start_date'
		by nip year month: gen flag = _N
		tab flag
		by nip year month: keep if _n == 1
		drop flag
		tempfile a1
		saveold `a1', replace
		
		// combine with NIP, year, month level data
		use `nip_panel', clear
		merge 1:m nip year month using `a1'
		
		// keep last observation before 2002
		tempfile a2
		saveold `a2', replace
		
		keep if _m == 2
		gsort nip -`start_date'
		by nip: keep if _n == 1
		tempfile a3
		saveold `a3', replace
		
		use `a2', clear
		drop if _m == 2
		append using `a3'
		
		// replace missing values by copying previous non-missing values downward by NIP (cascade effect)
		sort nip year month
		ds nip year month _m, not
		qui foreach x of varlist `r(varlist)' {
			local type1: type `x'
			local type2 = substr("`type1'",1,3)
			if "`type2'" != "str" {
				noi di "Numeric : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == .
			}
			else {
				noi di "String  : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == ""
			}
		}
		
		// drop last observation before 2002
		drop if _m == 2
		drop _m
		
		// assert that there are no NIP with missing data for all year-month
		gen flag1 = `start_date' != .
		egen flag2 = total(flag1), by(nip)
		* assert flag2 != 0
		// assertion is false because there are some obs with missing `start_date', drop NIP with all missing data
		drop if flag2 == 0
		drop flag?
		
		// assert balance panel data (12 months * 15 years = 180)
		count
		local n = r(N)
		assert mod(`n',180) == 0
		
		compress
		saveold "${output}/analysis/LK03D_panel.dta", replace
	}
	
* LK04 - Formal education history
	if `lk04' == 1 {
		// drop NIP that are only available in template data
		local data "${output}/analysis/LK04_clean.dta"
		local start_date = "certificate_date"
		
		use "${output}/temp_data/LK_nip_list", clear
		merge 1:m nip using `data'
		keep if _m == 1
		keep nip
		merge 1:m nip using "${output}/temp_data/LK_nip_balanced_panel"
		drop if _m == 3
		drop _m
		tempfile nip_panel
		saveold `nip_panel', replace
		
		use `data', clear
		drop flag1
		rename certificate_year year
		gen month = month(`start_date')
		
		// drop no classification and professional education
		drop if inlist(educ_degree,10,11)
		
		// there are some duplicates at the nip, year, month level (also in nip-date level)
		// keep the latest obs based on highest education degree
		order nip year month
		gsort nip year month -educ_degree -`start_date'
		by nip year month: gen flag = _N
		tab flag
		by nip year month: keep if _n == 1
		drop flag
		tempfile a1
		saveold `a1', replace
		
		// combine with NIP, year, month level data
		use `nip_panel', clear
		merge 1:m nip year month using `a1'
		
		// keep last observation before 2002
		tempfile a2
		saveold `a2', replace
		
		keep if _m == 2
		gsort nip -`start_date'
		by nip: keep if _n == 1
		tempfile a3
		saveold `a3', replace
		
		use `a2', clear
		drop if _m == 2
		append using `a3'
		
		// replace missing values by copying previous non-missing values downward by NIP (cascade effect)
		sort nip year month
		ds nip year month _m, not
		qui foreach x of varlist `r(varlist)' {
			local type1: type `x'
			local type2 = substr("`type1'",1,3)
			if "`type2'" != "str" {
				noi di "Numeric : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == .
			}
			else {
				noi di "String  : `x'"
				by nip: replace `x' = `x'[_n-1] if `x' == ""
			}
		}
		
		// drop last observation before 2002
		drop if _m == 2
		drop _m
		
		// assert that there are no NIP with missing data for all year-month
		gen flag1 = `start_date' != .
		egen flag2 = total(flag1), by(nip)
		* assert flag2 != 0
		// assertion is false because there are some obs with missing `start_date', drop NIP with all missing data
		drop if flag2 == 0
		drop flag?
		
		// assert balance panel data (12 months * 15 years = 180)
		count
		local n = r(N)
		assert mod(`n',180) == 0
		
		compress
		saveold "${output}/analysis/LK04_panel.dta", replace
	}

	
* Non-LK - Active duty status history
	if `NonLK' == 1 {
		use "${output}/analysis/LKnon_clean.dta", clear
		
		/*
			We are only interested for the people who exit DJP permanently
		*/
		
		// drop missing date
		drop if inactive_date == .
		drop inactive_notes
		
		// Inactive status
		encode inactive_status, gen(status)
		numlabel active_duty_status inactive_type status, add
		drop inactive_status
		
		// keep people who exit permanently
		keep if inactive_type == 1
		drop inactive_type
		
		tab status active_duty_status
		drop active_duty_status
		
		// drop deceased
		drop if status == 6
		
		// create panel data
		rename inactive_date date
		rename inactive_year year
		gen month = month(date)
		
		// for duplicates, keep the earliest date of exit
		order nip year month date status
		sort nip year month date
		by nip: gen flag1 = _N
		tab flag1
		* br if flag1 > 1
		by nip: keep if _n == 1
		drop flag1
		
		tempfile a1
		saveold `a1', replace
		
		// create template for panel data
		use "${output}/temp_data/LK_nip_list", clear
		merge 1:m nip using `a1'
		keep if _m == 1
		keep nip
		merge 1:m nip using "${output}/temp_data/LK_nip_balanced_panel"
		drop if _m == 3
		drop _m
		tempfile nip_panel
		saveold `nip_panel', replace
		
		merge 1:1 nip year month using `a1'
		tab year if _m == 2
		// OK, year < 2002 in using only data
		drop if _m == 2
		drop _m
		
		lab var year "Year"
		lab var month "Month"
		
		// dummy of different exit status
		sort nip year month
		by nip: egen d1 = total(date)
		gen d2 = mdy(month, 1, year)
		format d1 d2 %td
		gen flag1 = d2 <= d1
		
		tab status
		label list status
		
		gen let_go = inlist(status,7,12) if !mi(status)
		gen resign = inlist(status,8,9) if !mi(status)
		gen retired = status == 13 if !mi(status)
		gen moved = status == 14 if !mi(status)
		gen exit = 1 if status != .
		
		foreach x of varlist let_go-exit {
			replace `x' = 0 if `x' == . & flag1 == 1
		}
		drop d1 d2 flag1
		
		lab var let_go "Fired"
		lab var resign "Resign"
		lab var retired "Retired"
		lab var moved "Moved to outside unit"
		lab var exit "Exit from DJP (any reason)"
		
		// Save
		compress
		label data "Exit status"
		saveold "${output}/analysis/NONLK_panel.dta", replace
		
	}

	
} /* Close create panels boolean */

	**---------------------------------------------------------------------------
	** Combine important variables related to salary and tunjangan
	**---------------------------------------------------------------------------

if `combine_panels'==1{

* LK02 - Rank history
	use "${output}/analysis/LK02_panel.dta", clear
	keep nip year month golongan golongan_sorted credit_score service_year salary rank_start_date
	ds nip year month, not
	foreach x of varlist `r(varlist)' {
		rename `x' `x'_lk02
	}
	gen data_lk02 = 1
	lab var data_lk02 "In LK02   data (rank history)"
	
	by nip: egen data_lk02_first_date = min(rank_start_date)
	format data_lk02_first_date %td
	drop rank_start_date
	
	saveold "${output}/temp_data/create_balanced_panel_LK02", replace
	
* LK03 - Position history
	use "${output}/analysis/LK03_panel.dta", clear
	keep nip year month position_type eselon_3 structural_organization structural_position functional_group functional_position functional_role_in_team golongan golongan_sorted position_start_date
	ds nip year month, not
	foreach x of varlist `r(varlist)' {
		rename `x' `x'_lk03
	}
	gen data_lk03 = 1
	lab var data_lk03 "In LK03   data (position history)"
	
	by nip: egen data_lk03_first_date = min(position_start_date)
	format data_lk03_first_date %td
	drop position_start_date
	
	saveold "${output}/temp_data/create_balanced_panel_LK03", replace
	
* LK03A - Position history (for functional staffs)
	use "${output}/analysis/LK03A_panel.dta", clear
	keep nip year month functional_group functional_position golongan golongan_sorted
	ds nip year month, not
	foreach x of varlist `r(varlist)' {
		rename `x' `x'_lk03a
	}
	gen data_lk03a = 1
	lab var data_lk03a "In LK03A  data (position history for functional staff)"
	saveold "${output}/temp_data/create_balanced_panel_LK03A", replace
	
* LK03C - Grade history
	use "${output}/analysis/LK03C_panel.dta", clear
	keep nip year month eselon_3 grade
	ds nip year month, not
	foreach x of varlist `r(varlist)' {
		rename `x' `x'_lk03c
	}
	gen data_lk03c = 1
	lab var data_lk03c "In LK03C  data (grade history)"
	saveold "${output}/temp_data/create_balanced_panel_LK03C", replace
	
* LK03D - Functional group history
	use "${output}/analysis/LK03D_panel.dta", clear
	keep nip year month group_number team_number functional_role_in_team regional_office
	rename regional_office eselon_3
	ds nip year month, not
	foreach x of varlist `r(varlist)' {
		rename `x' `x'_lk03d
	}
	gen data_lk03d = 1
	lab var data_lk03d "In LK03D  data (functional group history)"
	saveold "${output}/temp_data/create_balanced_panel_LK03D", replace
	
* Combine data
	use "${output}/temp_data/create_balanced_panel_LK02", clear
	merge 1:1 nip year month using "${output}/temp_data/create_balanced_panel_LK03"
	drop _m
	merge 1:1 nip year month using "${output}/temp_data/create_balanced_panel_LK03A"
	drop _m
	merge 1:1 nip year month using "${output}/temp_data/create_balanced_panel_LK03C"
	drop _m
	merge 1:1 nip year month using "${output}/temp_data/create_balanced_panel_LK03D"
	drop _m
	
	foreach x of varlist data_* {
		recode `x' .=0
	}
	
	saveold "${output}/temp_data/create_balanced_panel_LK", replace
	
	* Combine same variables that come from different datasets
	* order *, alpha
	* order nip year month
	
	* functional_group from LK03 and LK03A
		// make sure there is no conflicting value for structural and functional staffs
		* br nip year month position_type* functional_group* functional_position* functional_role* if position_type_lk03 == 1 & functional_group_lk03a != .
		replace functional_group_lk03a = . if position_type_lk03 == 1
		
		// assign missing value in LK03 from LK03A
		* br nip year month position_type* functional_group* functional_position* functional_role*
		tab functional_group_lk03
		tab functional_group_lk03a
		recode functional_group_lk03a (4=5)
		tab functional_group_lk03 functional_group_lk03a, m
		* br nip year month position_type* functional_group* functional_position* functional_role* if functional_group_lk03 == . & functional_group_lk03a != .
		gen     functional_group = functional_group_lk03
		replace functional_group = functional_group_lk03a if functional_group == . & functional_group_lk03a != .
		lab val functional_group functional_group
		lab var functional_group "Functional position group"
		
		// drop original variables
		drop functional_group_lk03 functional_group_lk03a
		
	* functional_position from LK03 and LK03A
		// make sure there is no conflicting value for structural and functional staffs
		* br nip year month position_type* functional_group* functional_position* functional_role* if position_type_lk03 == 1 & functional_position_lk03a != .
		replace functional_position_lk03a = . if position_type_lk03 == 1
		
		// assign missing value in LK03 from LK03A
		* br nip year month position_type* functional_group* functional_position* functional_role*
		tab functional_position_lk03
		tab functional_position_lk03a
		recode functional_position_lk03a ///
			     (1=1)   (2=2)   (3=3)   (4=7)   (5=9)  (6=10)  (7=11) ( 8=12)  (9=13) (10=14) (11=15) ///
			   (12=16) (13=17) (14=18) (15=19) (16=20) (17=24) (18=25) (19=26) (20=27) (21=28) (22=29) ///
			   (23=30) (24=31) (25=33) (26=36) (27=37) (28=38) (29=39) (30=40) (31=41) (32=42) (33=43) ///
			   (34=44) (35=45) (36=46) (37=47) (38=48) (39=52) (40=53) (41=54) (42=55) (43=56) (44=58) (45=59)
		* br nip year month position_type* functional_group* functional_position* functional_role* if functional_position_lk03 == . & functional_position_lk03a != .
		gen     functional_position = functional_position_lk03
		replace functional_position = functional_position_lk03a if functional_position == . & functional_position_lk03a != .
		lab val functional_position functional_position
		lab var functional_position "Functional position name"
		
		// drop original variables
		drop functional_position_lk03 functional_position_lk03a
		
	* functional_role_in_team from LK03 and LK03D
		// make sure there is no conflicting value for structural and functional staffs
		* br nip year month position_type* functional_group* functional_position* functional_role* if position_type_lk03 == 1 & functional_role_in_team_lk03d != .
		replace functional_role_in_team_lk03d = . if position_type_lk03 == 1
		
		// assign missing value in LK03 from LK03A
		* br nip year month position_type* functional_group* functional_position* functional_role*
		tab functional_role_in_team_lk03
		tab functional_role_in_team_lk03d
		tab functional_role_in_team_lk03 functional_role_in_team_lk03d, m
		* br nip year month position_type* functional_group* functional_position* functional_role* if functional_role_in_team_lk03 == . & functional_role_in_team_lk03d != .
		gen     functional_role_in_team = functional_role_in_team_lk03
		replace functional_role_in_team = functional_role_in_team_lk03d if functional_role_in_team == . & functional_role_in_team_lk03d != .
		lab val functional_role_in_team functional_role_in_team
		lab var functional_role_in_team "Position in the team (only for tax auditor functional position)"
		
		// drop original variables
		drop functional_role_in_team_lk03 functional_role_in_team_lk03d
		
	* position_type from LK03
		// position type
		* br nip year month position_type* functional_group* functional_position* functional_role*
		gen position_type = position_type_lk03
		numlabel position_type, add
		lab val position_type position_type
		replace position_type = 2 if position_type == . & functional_group != .
		replace position_type = 2 if position_type == . & functional_position != .
		replace position_type = 2 if position_type == . & functional_role_in_team != .
		lab var position_type "Type of position (structural / functional)"
		
		// final check
		assert position_type == 2 if functional_group != .
		assert position_type == 2 if functional_position != .
		assert position_type == 2 if functional_role_in_team != .
		
		// drop original variables
		drop position_type_lk03
		
	* golongan from LK02, LK03, LK03A
	// follow mainly from LK02, which is the dataset for golongan (rank) history
	* br nip year month golongan*
	
		// get non-missing golongan from all datasets
		gen     golongan = golongan_lk02
		gen     golongan_sorted = golongan_sorted_lk02
		replace golongan = golongan_lk03 if golongan == ""
		replace golongan_sorted = golongan_sorted_lk03 if golongan_sorted == .
		replace golongan = golongan_lk03a if golongan == ""
		replace golongan_sorted = golongan_sorted_lk03a if golongan_sorted == .
		
		// keep highest golongan from all datasets
		* br nip year month golongan* if golongan_sorted_lk03 > golongan_sorted_lk02 & !mi(golongan_sorted_lk03)
		replace golongan        = golongan_lk03         if golongan_sorted_lk03  > golongan_sorted & !mi(golongan_sorted_lk03)
		replace golongan_sorted = golongan_sorted_lk03  if golongan_sorted_lk03  > golongan_sorted & !mi(golongan_sorted_lk03)
		replace golongan        = golongan_lk03a        if golongan_sorted_lk03a > golongan_sorted & !mi(golongan_sorted_lk03a)
		replace golongan_sorted = golongan_sorted_lk03a if golongan_sorted_lk03a > golongan_sorted & !mi(golongan_sorted_lk03a)
		lab define golongan_sorted 1 "Ia" 2 "Ib" 3 "Ic" 4 "Id" 5 "IIa" 6 "IIb" 7 "IIc" 8 "IId" ///
			9 "IIIa" 10 "IIIb" 11 "IIIc" 12 "IIId" 13 "IVa" 14 "IVb" 15 "IVc" 16 "IVd" 17 "IVe"
		lab val golongan_sorted golongan_sorted
		numlabel golongan_sorted, add
		
		lab var golongan "Golongan (string)"
		lab var golongan_sorted "Golongan (numeric)"
		
		// drop original variables
		drop golongan_lk* golongan_sorted_lk*
		
	* Office name (eselon 3) from LK03, LK03C, and LK03D
		gen     eselon_3 = eselon_3_lk03
		replace eselon_3 = eselon_3_lk03c if eselon_3 == "" & eselon_3_lk03c != ""
		replace eselon_3 = eselon_3_lk03d if eselon_3 == "" & eselon_3_lk03d != ""
		drop eselon_3_lk03 eselon_3_lk03c eselon_3_lk03d
		lab var eselon_3 "Office name (eselon 3 level)"
		
* Save
	lab var year "Year"
	lab var month "Month"
	
	order nip year month position_type functional_group functional_position functional_role_in_team golongan golongan_sorted eselon_3
	order data_*, last
	sort nip year month
	compress
	saveold "${output}/analysis/LK_panel.dta", replace
}


clear
log close
shell erase "${output}/temp_data/create_balanced_panel_*.dta"
