* SIKKA are confidential anonymized data on DGT's employees
* NIP is the anonymized (randomly generated) employee ID
set seed 98765
log using "${dofile}/logs/0_7_SIKKA_compile_salary_schedules.log", replace
di in red "Run 0_8_SIKKA_compile_salary_schedules.do"

**---------------------------------------------------------------------------
** Import Data
**---------------------------------------------------------------------------
* Base salary data
	qui forvalues year = 2003/2011 {
		// import data
		noi di `year'
		import excel "${raw}/auxiliary/All Year_clean.xlsx", sheet("`year'") firstrow clear
		drop var* mkg
		
		// assert value
		su gol_1a
		local min = r(min)
		su gol_4e
		local max = r(max)
		foreach x of varlist gol_1a-gol_4e {
			su `x' if `x' != 0
			cap assert r(min) >= `min'
			if _rc == 9 {
				noi di "year = `year', var = `x' below allowed minimum"
			}
			cap assert r(max) <= `max'
			if _rc == 9 {
				noi di "year = `year', var = `x' above allowed maximum"
			}
		}
		
		// save as matrix
		mkmat *, mat(salary_`year')
		
	}
	
* Grade data for functional staff
	import excel "${raw}/auxiliary/List of Jabatan Fungsional.xlsx", sheet("clean") firstrow clear
	rename grade grade_functional
	saveold "${output}/temp_data/salary_bonus_schedule_grade_functional", replace
	
* TKPKN 2007
	import excel "${raw}/auxiliary/TKPKN.xlsx", sheet("clean_2007") firstrow clear
	saveold "${output}/temp_data/salary_bonus_schedule_tunjangan_2007", replace
	
* Implied grade based on golongan
	import excel "${raw}/auxiliary/Peringkat-Golongan Matrix.xlsx", sheet("clean") firstrow clear
	drop golongan
	drop if implied_grade == .
	saveold "${output}/temp_data/salary_bonus_schedule_golongan_grade_matrix", replace
	
* Month and year
	import excel "${raw}/auxiliary/All Year_clean.xlsx", sheet("year_month") firstrow clear
	saveold "${output}/temp_data/year_month", replace
	
**---------------------------------------------------------------------------
** Apply salary and bonus schedule to SIKKA data
**---------------------------------------------------------------------------
* Create base salary
	use "${output}/analysis/LK_panel", clear
	keep if inrange(year,2003,2011)
	
	// calculate salary based on MKG and Golongan
	gen     mkg = service_year
	replace mkg = mkg + 1
	replace mkg = 34 if mkg > 34 & !mi(mkg)
	lab var mkg "Masa Kerja Golongan (MKG) + 1 (1-34)"
	
	forvalues year = 2003/2011 {
		gen salary_calc_`year' = salary_`year'[mkg,golongan_sorted] if year == `year'
	}
	
	egen flag1 = rownonmiss(salary_calc_2003-salary_calc_2011)
	tab year flag1
	tab mkg if flag1 == 0, m
	tab golongan_sorted if flag1 == 0 & mkg != .
	* br if flag1 == 0 & mkg != .
	// OK, salary is missing if mkg and/or golongan is missing
	drop flag1
	egen salary_calc = rowtotal(salary_calc_2003-salary_calc_2011), missing
	drop salary_calc_*
	
	lab var salary_calc "Base salary (calculated from salary schedule)"
	
	// replace with original values for missing or zero
	inspect salary_calc
	replace salary_calc = salary_lk02 if salary_calc == . | salary_calc == 0
	inspect salary_calc
		
	saveold "${output}/temp_data/salary_bonus_schedule_LK_panel_salary.dta", replace
		
	* Check and create grade for pelaksana staff
	use "${output}/temp_data/salary_bonus_schedule_LK_panel_salary.dta", clear
	gen grade = grade_lk03c
	lab var grade "Grade"
	move grade functional_group
	
	tab grade
	
	// check people who have grade 15
	tab golongan_sorted if grade == 15
	tab structural_position_lk03 if grade == 15
	// these are "Kepala Seksi" (Eselon IV equivalent position)
	
	tab golongan_sorted grade, m
	tab golongan_sorted grade if position_type == 1, m
	tab structural_position grade, m
	tab structural_position grade if position_type == 1, m
	
	* Check grade
		gen structural_1 = position_type == 1
		gen functional_1 = position_type == 2
		by nip: egen ever_been_in_structural = total(structural_1)
		by nip: egen ever_been_in_functional = total(functional_1)
		replace ever_been_in_structural = 1 if ever_been_in_structural > 1 & !mi(ever_been_in_structural)
		replace ever_been_in_functional = 1 if ever_been_in_functional > 1 & !mi(ever_been_in_functional)
		lab var ever_been_in_structural "Ever worked in structural position"
		lab var ever_been_in_functional "Ever worked in functional position"
		drop structural_1 functional_1
			
	* Remove grade for people with Eselon
		replace grade = . if inlist(structural_position,3,4,28)
		replace grade = . if inrange(structural_position,6,17)
		
	* Remove grade for functional staffs
		replace grade = . if position_type == 2
		
	* Create new grade for functional staffs
		merge m:1 functional_position using "${output}/temp_data/salary_bonus_schedule_grade_functional"
		drop if _m == 2
		drop _m
				
		count if grade_functional != .
		replace grade = grade_functional if grade == . & grade_functional != .
		drop grade_functional
		
	* Remove grade for all people before July 2007
		tab year grade, m
		
		replace grade = . if year < 2007
		replace grade = . if year == 2007 & inrange(month,1,6)
		tab year grade, m
		
	* Missing grade imputation: estimate missing grade using information on golongan
		gen grade_imputed = grade
		lab var grade_imputed "Missing grades were imputed using information on golongan"
		
		gen ar = structural_position_lk03 == 1 if !mi(structural_position_lk03)
		lab var ar "Dummy for account representative"
		
		gen pelaksana = inlist(structural_position_lk03,2,5,18,20,21,22,23,24,25,26,27,29) if !mi(structural_position_lk03)
		lab var pelaksana "Dummy for pelaksana (without AR)"
		
		// impute missing grade using golongan for pelaksana and AR
		merge m:1 golongan_sorted using "${output}/temp_data/salary_bonus_schedule_golongan_grade_matrix"
		drop if _m == 2
		drop _m
		move grade_imputed functional_group
		move implied_grade functional_group
		sort nip year month
		
		replace grade_imputed = implied_grade if grade_imputed == . & position_type == 1 & (ar == 1 | pelaksana == 1)
		replace grade_imputed = implied_grade if grade_imputed == . & position_type == 2
		
		* Check
			tab structural_position if grade_imputed == . & position_type == 1, m
			tab structural_position if grade_imputed == . & position_type == 1 & (ar == 1 | pelaksana == 1), m
			tab golongan_sorted if grade_imputed == . & position_type == 1 & (ar == 1 | pelaksana == 1), m
			// OK, grade_imputed is missing for:
			//   - staffs with eselon, or
			//   - AR or pelaksana with golongan IIId or higher
			
			tab functional_position if grade_imputed == . & position_type == 2, m
			tab golongan_sorted if grade_imputed == . & position_type == 2, m
			// OK, grade_imputed is missing for:
			//   - functional staffs with golongan IIId or higher
			drop implied_grade
			
* Create Tunjangan schedule
	* 2007
		merge m:1 grade using "${output}/temp_data/salary_bonus_schedule_tunjangan_2007"
		drop if _m == 2
		drop _m
		rename tunjangan tunjangan_2007
		
	* Combine tunjangan schedule
		order nip year month position_type grade grade_imputed ar pelaksana
		sort nip year month
		* br nip-pelaksana tunjangan*
		gen double tunjangan = .
		replace tunjangan = tunjangan_2007            if year == 2007 & inrange(month,7,12)
		replace tunjangan = tunjangan_2007            if inrange(year,2008,2011)
		lab var tunjangan "Tunjangan (calculated from schedule)"
		drop tunjangan_*
		
		tempfile a
		save `a', replace
		
* Create Tunjangan schedule from grade_imputed
	rename grade grade_original
	rename grade_imputed grade
	rename tunjangan tunjangan_original
	
	* 2007
		merge m:1 grade using "${output}/temp_data/salary_bonus_schedule_tunjangan_2007"
		drop if _m == 2
		drop _m
		rename tunjangan tunjangan_2007
		
	* Combine tunjangan schedule
		sort nip year month
		gen double tunjangan = .
		replace tunjangan = tunjangan_2007            if year == 2007 & inrange(month,7,12)
		replace tunjangan = tunjangan_2007            if inrange(year,2008,2011)
		lab var tunjangan "Tunjangan (calculated from schedule using grade_imputed)"
		
	* Finalize
		rename tunjangan tunjangan_imputed
		rename tunjangan_original tunjangan
		rename grade grade_imputed
		rename grade_original grade
		
		drop tunjangan_20*
		
	* Check
		inspect grade grade_imputed tunjangan tunjangan_imputed
		
* Save data
	compress
	saveold "${output}/analysis/LK_panel_tunjangan.dta", replace
clear
log close
